@@ -106,6 +106,8 @@ int main(
   char *pc;
   int i;
   int u_cnt, o_cnt, s_cnt, n_cnt;
+  int asynch = FALSE;
+  int rc = 0;
 
   struct attrl *attrib = NULL;
   char *keyword;
@@ -121,7 +123,7 @@ int main(
   char rmt_server[MAXSERVERNAME];
   char path_out[MAXPATHLEN + 1];
 
-#define GETOPT_ARGS "a:A:c:e:h:j:k:l:m:M:N:o:p:r:S:u:v:W:x:"
+#define GETOPT_ARGS "a:A:c:e:h:j:k:l:m:M:N:o:p:qr:S:u:v:W:x:"
 
   while ((c = getopt(argc, argv, GETOPT_ARGS)) != EOF)
     {
@@ -210,8 +212,9 @@ int main(
         break;
 
       case 'e':
-
-        if (prepare_path(optarg, path_out) == 0)
+ 
+        rc = prepare_path(optarg, path_out);
+        if ((rc == 0) || (rc == 3))
           {
           set_attr(&attrib, ATTR_e, path_out);
           }
@@ -403,8 +406,9 @@ int main(
       case 'o':
 
         /* output */
-
-        if (prepare_path(optarg, path_out) == 0)
+ 
+        rc = prepare_path(optarg, path_out);
+        if ((rc == 0) || (rc == 3))
           {
           set_attr(&attrib, ATTR_o, path_out);
           }
@@ -467,6 +471,14 @@ int main(
 
         break;
 
+      case 'q':
+
+        /* quick - asynchronous */
+
+        asynch = TRUE;
+
+        break;
+
       case 'r':
 
         /* rerun */
@@ -549,21 +561,12 @@ int main(
           {
           if (strcmp(keyword, ATTR_depend) == 0)
             {
-            int rtn = 0;
             pdepend = malloc(PBS_DEPEND_LEN);
 
             if ((pdepend == NULL) ||
-                 (rtn = parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN)))
+                 parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN))
               {
-              if (rtn == 2)
-                {
-                fprintf(stderr,"qalter: -W value exceeded max length (%d)\n",
-                  PBS_DEPEND_LEN);
-                }
-              else
-                {
-                fprintf(stderr,"qalter: illegal -W value\n");
-                }
+              fprintf(stderr, "qalter: illegal -W value\n");
 
               errflg++;
 
@@ -572,7 +575,7 @@ int main(
 
             valuewd = pdepend;
             }
-          else if (!strcmp(keyword,ATTR_stagein))
+          else if (strcmp(keyword, ATTR_stagein) == 0)
             {
             if (parse_stage_list(valuewd))
               {
@@ -583,22 +586,22 @@ int main(
               break;
               }
             }
-          else if (strcmp(keyword,ATTR_stageout) == 0)
+          else if (strcmp(keyword, ATTR_stageout) == 0)
             {
             if (parse_stage_list(valuewd))
               {
-              fprintf(stderr,"qalter: illegal -W value\n");
+              fprintf(stderr, "qalter: illegal -W value\n");
 
               errflg++;
 
               break;
               }
             }
-          else if (strcmp(keyword,ATTR_g) == 0)
+          else if (strcmp(keyword, ATTR_g) == 0)
             {
-            if (parse_at_list(valuewd,TRUE,FALSE))
+            if (parse_at_list(valuewd, TRUE, FALSE))
               {
-              fprintf(stderr,"qalter: illegal -W value\n");
+              fprintf(stderr, "qalter: illegal -W value\n");
 
               errflg++;
 
@@ -643,7 +646,7 @@ int main(
     static char usage[] = "usage: qalter \
                           [-a date_time] [-A account_string] [-c interval] [-e path] \n\
                           [-h hold_list] [-j y|n] [-k keep] [-l resource_list] [-m mail_options] \n\
-                          [-M user_list] [-N jobname] [-o path] [-p priority] [-r y|n] [-S path] \n\
+                          [-M user_list] [-N jobname] [-o path] [-p priority] [-q] [-r y|n] [-S path] \n\
                           [-u user_list] [-v variable_list] [-W dependency_list] [-x exec_host] \n\
                           job_identifier...\n";
 
@@ -686,7 +689,14 @@ cnt:
       continue;
       }
 
-    stat = pbs_alterjob(connect, job_id_out, attrib, NULL);
+    if (asynch)
+      {
+      stat = pbs_alterjob_async(connect, job_id_out, attrib, NULL);
+      }
+    else
+      {
+      stat = pbs_alterjob(connect, job_id_out, attrib, NULL);
+      }
 
     if ((stat != 0) && (pbs_errno != PBSE_UNKJOBID))
       {
