@@ -108,6 +108,7 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <grp.h>
+#include <csv.h>
 
 #ifdef sun
 #include <sys/stream.h>
@@ -125,7 +126,6 @@
 #  include <sys/select.h>
 #endif
 
-
 #include "cmds.h"
 #include "net_connect.h"
 #include "log.h"
@@ -149,17 +149,22 @@ static char PBS_DPREFIX_DEFAULT[] = "#PBS";
 char PBS_Filter[256];
 char PBS_InitDir[256];
 char PBS_RootDir[256];
+char PBS_WorkDir[256];
 
 char xauth_path[256];
 char default_ckpt[256];
 
 int validate_path = 1;
+int rerunnable_by_default = 1;
+int fault_tolerant_by_default = 0;
 int interactivechild = 0;
 int x11child = 0;
 
 int do_dir(char *);
 int process_opts(int, char **, int);
+int have_terminal = TRUE;
 
+char *checkpoint_strings = "n,c,s,u,none,shutdown,periodic,enabled,interval,depth,dir";
 
 
 /* adapted from openssh */
@@ -325,8 +330,6 @@ static char *x11_get_proto(
 
 
 
-
-
 char *set_dir_prefix(
 
   char *prefix,
@@ -380,9 +383,7 @@ int isexecutable(
     }
 
   return(FALSE);
-  }  /* END isexecutable() */
-
-
+  }
 
 
 
@@ -866,7 +867,7 @@ int do_dir(
 
 /* globals */
 
-int inter_sock;
+int inter_sock = -1;
 
 struct termios oldtio;
 
@@ -887,6 +888,7 @@ int a_opt = FALSE;
 int b_opt = FALSE;
 int c_opt = FALSE;
 int e_opt = FALSE;
+int f_opt = FALSE;
 int h_opt = FALSE;
 int j_opt = FALSE;
 int k_opt = FALSE;
@@ -897,12 +899,12 @@ int p_opt = FALSE;
 int q_opt = FALSE;
 int r_opt = FALSE;
 int t_opt = FALSE;
-int T_opt = FALSE;
 int u_opt = FALSE;
 int v_opt = FALSE;
 int z_opt = FALSE;
 int A_opt = FALSE;
 int C_opt = FALSE;
+int F_opt = FALSE;
 int M_opt = FALSE;
 int N_opt = FALSE;
 int S_opt = FALSE;
@@ -1085,7 +1087,10 @@ int set_job_env(
     len += strlen("PBS_O_ROOTDIR=") + strlen(PBS_RootDir) + 1;
     }
 
-  len += strlen("PBS_O_WORKDIR=") + 1;
+  if (PBS_WorkDir[0] != '\0')
+    {
+    len += strlen("PBS_O_WORKDIR=") + strlen(PBS_WorkDir) + 1;
+    }
 
   len += strlen("PBS_SERVER=") + 1;
 
@@ -1102,77 +1107,77 @@ int set_job_env(
 
   c = getenv("HOME");
 
-  strcat(job_env,"PBS_O_HOME=");
+  strcat(job_env, "PBS_O_HOME=");
 
   if (c != NULL)
-    strcat(job_env,c);
+    strcat(job_env, c);
   else
-    strcat(job_env,"/");
+    strcat(job_env, "/");
 
   c = getenv("LANG");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_LANG=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_LANG=");
+    strcat(job_env, c);
     }
 
   c = getenv("LOGNAME");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_LOGNAME=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_LOGNAME=");
+    strcat(job_env, c);
     }
 
   c = getenv("PATH");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_PATH=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_PATH=");
+    strcat(job_env, c);
     }
 
   c = getenv("MAIL");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_MAIL=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_MAIL=");
+    strcat(job_env, c);
     }
 
   c = getenv("SHELL");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_SHELL=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_SHELL=");
+    strcat(job_env, c);
     }
 
   c = getenv("TZ");
 
   if (c != NULL)
     {
-    strcat(job_env,",PBS_O_TZ=");
-    strcat(job_env,c);
+    strcat(job_env, ",PBS_O_TZ=");
+    strcat(job_env, c);
     }
 
   if (qsub_host[0] != '\0' ||
-      (rc = gethostname(qsub_host, PBS_MAXHOSTNAME + 1)) == 0)
+     (rc = gethostname(qsub_host, PBS_MAXHOSTNAME + 1)) == 0)
     {
     if ((rc = get_fullhostname(qsub_host, qsub_host, PBS_MAXHOSTNAME, NULL)) == 0)
       {
-      strcat(job_env,",PBS_O_HOST=");
-      strcat(job_env,qsub_host);
-      }
+      strcat(job_env, ",PBS_O_HOST=");
+      strcat(job_env, qsub_host);
+      }   
     }
-
+    
   if (rc != 0)
     {
-    fprintf(stderr,"qsub: cannot get (full) local host name\n");
+    fprintf(stderr, "qsub: cannot get (full) local host name\n");
     exit(3);
     }
-
+    
   if (server_host[0] != '\0')
     {
     if (get_fullhostname(server_host, server_host, PBS_MAXHOSTNAME, NULL) == 0)
@@ -1204,8 +1209,8 @@ int set_job_env(
 
   if (owner_uid[0] != '\0')
     {
-    strcat(job_env,",PBS_O_UID=");
-    strcat(job_env,owner_uid);
+    strcat(job_env, ",PBS_O_UID=");
+    strcat(job_env, owner_uid);
     }
 
   /* load init dir into env if specified */
@@ -1214,72 +1219,85 @@ int set_job_env(
     {
     /* load init dir into env */
 
-    strcat(job_env,",PBS_O_INITDIR=");
+    strcat(job_env, ",PBS_O_INITDIR=");
 
-    strcat(job_env,PBS_InitDir);
+    strcat(job_env, PBS_InitDir);
     }
 
   if (PBS_RootDir[0] != '\0')
     {
     /* load init dir into env */
 
-    strcat(job_env,",PBS_O_ROOTDIR=");
+    strcat(job_env, ",PBS_O_ROOTDIR=");
 
-    strcat(job_env,PBS_RootDir);
+    strcat(job_env, PBS_RootDir);
     }
 
   /* get current working directory, use $PWD if available, it is more */
   /* NFS automounter "friendly".  But must double check that is right */
 
-  s = job_env + strlen(job_env);
+  /* load work dir into env if specified */
 
-  strcat(job_env,",PBS_O_WORKDIR=");
-
-  c = getenv("PWD");
-
-  if (c != NULL)
+  if (PBS_WorkDir[0] != '\0')
     {
+    /* load work dir into env */
 
-    struct stat statbuf;
-    dev_t dev;
-    ino_t ino;
+    strcat(job_env, ",PBS_O_WORKDIR=");
 
-    if (stat(c, &statbuf) < 0)
+    strcat(job_env, PBS_WorkDir);
+    }
+  else
+    {
+    s = job_env + strlen(job_env);
+
+    strcat(job_env, ",PBS_O_WORKDIR=");
+
+    c = getenv("PWD");
+
+    if (c != NULL)
       {
-      c = NULL; /* cannot stat, cannot trust it */
-      }
-    else
-      {
-      dev = statbuf.st_dev;
-      ino = statbuf.st_ino;
 
-      if (stat(".", &statbuf) < 0)
+      struct stat statbuf;
+      dev_t dev;
+      ino_t ino;
+
+      if (stat(c, &statbuf) < 0)
         {
-        /* compare against "." */
-
-        perror("qsub: cannot stat current directory: ");
-        exit(3);
-        }
-
-      if (!memcmp(&dev, &statbuf.st_dev, sizeof(dev_t)) &&
-          !memcmp(&ino, &statbuf.st_ino, sizeof(ino_t)))
-        {
-        strcat(job_env, c);
+        c = NULL; /* cannot stat, cannot trust it */
         }
       else
         {
-        c = NULL;
+        dev = statbuf.st_dev;
+        ino = statbuf.st_ino;
+
+        if (stat(".", &statbuf) < 0)
+          {
+          /* compare against "." */
+
+          perror("qsub: cannot stat current directory: ");
+          exit(3);
+          }
+
+        if (!memcmp(&dev, &statbuf.st_dev, sizeof(dev_t)) &&
+            !memcmp(&ino, &statbuf.st_ino, sizeof(ino_t)))
+          {
+          strcat(job_env, c);
+          }
+        else
+          {
+          c = NULL;
+          }
         }
+      }    /* END if (c != NULL) */
+
+    if (c == NULL)
+      {
+      /* fall back to using the cwd */
+      c = job_env + strlen(job_env);
+
+      if (getcwd(c, MAXPATHLEN + 1) == NULL)
+        *s = '\0';
       }
-    }    /* END if (c != NULL) */
-
-  if (c == NULL)
-    {
-    /* fall back to using the cwd */
-    c = job_env + strlen(job_env);
-
-    if (getcwd(c, MAXPATHLEN + 1) == NULL)
-      *s = '\0';
     }
 
   /* Send these variables with the job. */
@@ -1380,26 +1398,22 @@ state3:         /* No value - get it from qsub environment */
 
     if (strlen(job_env) + 2 + strlen(s) + 2*strlen(env) >= len)
       {
-      char *tmpJobEnv;
-
       /* increase size of job env buffer */
 
       len += 2 * strlen(env) + 1;
 
-      tmpJobEnv = (char *)realloc(job_env,len);
+      job_env = (char *)realloc(job_env, len);
 
-      if (tmpJobEnv == NULL)
+      if (job_env == NULL)
         {
         return(FALSE);
         }
- 
-      job_env = tmpJobEnv;
       }
 
-    strcat(job_env,",");
+    strcat(job_env, ",");
 
-    strcat(job_env,s);
-    strcat(job_env,"=");
+    strcat(job_env, s);
+    strcat(job_env, "=");
 
     if (copy_env_value(job_env, env, 1) == NULL)
       {
@@ -1417,26 +1431,22 @@ state4:         /* goto label - Value specified */
 
     if (strlen(job_env) + 2 + strlen(s) + 2*strlen(c) >= len)
       {
-      char *tmpJobEnv;
-
       /* increase size of job env buffer */
 
       len += 2 * strlen(c) + 1;
 
-      tmpJobEnv = (char *)realloc(job_env,len);
+      job_env = (char *)realloc(job_env, len);
 
-      if (tmpJobEnv == NULL)
+      if (job_env == NULL)
         {
         return(FALSE);
         }
-
-      job_env = tmpJobEnv;
       }
 
-    strcat(job_env,",");
+    strcat(job_env, ",");
 
-    strcat(job_env,s);
-    strcat(job_env,"=");
+    strcat(job_env, s);
+    strcat(job_env, "=");
 
     if ((c = copy_env_value(job_env, c, 0)) == NULL)
       {
@@ -1470,24 +1480,20 @@ final:
 
       *s = '\0';  /* NOTE: *s is clobbering our current, real, environ */
 
-      if ((strlen(job_env) + 2 + strlen(*evp) + 2 * strlen(s + 1)) >= len)
+      if (strlen(job_env) + 2 + strlen(*evp) + 2*strlen(s + 1) >= len)
         {
-        char *tmpJobEnv;
-
         /* increase size of job env buffer */
 
         len += 2 * strlen(s + 1) + 1;
 
-        tmpJobEnv = (char *)realloc(job_env,len);
+        job_env = (char *)realloc(job_env, len);
 
-        if (tmpJobEnv == NULL)
+        if (job_env == NULL)
           {
           *s = '='; /* restore our existing environ */
 
           return(FALSE);
           }
-
-        job_env = tmpJobEnv; 
         }
 
       strcat(job_env, ",");
@@ -1534,12 +1540,6 @@ char *interactive_port(int *sock)
   struct sockaddr_in myaddr;
   unsigned short port;
 
-  if ((isatty(0) == 0) || (isatty(1) == 0))
-    {
-    fprintf(stderr, "qsub:\tstandard input and output must be a terminal for \n\tinteractive job submission\n");
-    exit(1);
-    }
-
   *sock = socket(AF_INET, SOCK_STREAM, 0);
 
   if (*sock < 0)
@@ -2020,7 +2020,8 @@ void catchchild(
 
   /* reset terminal to cooked mode */
 
-  tcsetattr(0, TCSANOW, &oldtio);
+  if(have_terminal)
+    tcsetattr(0, TCSANOW, &oldtio);
 
   exit(0);
 
@@ -2261,7 +2262,7 @@ interactive(void)
 
   /* save the old terminal setting */
 
-  if (tcgetattr(0, &oldtio) < 0)
+  if (have_terminal && tcgetattr(0, &oldtio) < 0)
     {
     perror("qsub: unable to get terminal settings");
 
@@ -2270,7 +2271,7 @@ interactive(void)
 
   /* Get the current window size, to be sent to MOM later */
 
-  if (getwinsize(&wsz))
+  if (!have_terminal || getwinsize(&wsz))
     {
     wsz.ws_row = 20; /* unable to get actual values */
     wsz.ws_col = 80; /* set defaults   */
@@ -2278,6 +2279,7 @@ interactive(void)
     wsz.ws_ypixel = 0;
     }
 
+
   printf("qsub: waiting for job %s to start\n",
 
          new_jobname);
@@ -2402,6 +2404,8 @@ interactive(void)
     exit(1);
     }
 
+  fflush(NULL);
+
   interactivechild = fork();
 
   if (interactivechild == 0)
@@ -2411,13 +2415,15 @@ interactive(void)
      *     set terminal into raw mode
      */
 
-    settermraw(&oldtio);
+    if (have_terminal)
+      settermraw(&oldtio);
 
     reader(news, fileno(stdout));
 
     /* reset terminal */
 
-    tcsetattr(0, TCSANOW, &oldtio);
+    if (have_terminal)
+      tcsetattr(0, TCSANOW, &oldtio);
 
     printf("\nqsub: job %s completed\n",
            new_jobname);
@@ -2461,7 +2467,8 @@ interactive(void)
 
     close(inter_sock);
 
-    tcsetattr(0, TCSANOW, &oldtio);
+    if (have_terminal)
+      tcsetattr(0, TCSANOW, &oldtio);
 
     exit(0);
     }
@@ -2523,9 +2530,11 @@ int process_opts(
   struct stat sfilter;
 
   int tmpfd;
+  int nitems;
+  char search_string[256];
 
 #if !defined(PBS_NO_POSIX_VIOLATION)
-#define GETOPT_ARGS "a:A:b:c:C:d:D:e:hIj:k:l:m:M:N:o:p:q:r:S:t:T:u:v:VW:Xz-:"
+#define GETOPT_ARGS "a:A:b:c:C:d:D:e:fhIj:k:l:m:M:N:o:p:q:r:S:t:T:u:v:Vw:W:Xz-:"
 #else
 #define GETOPT_ARGS "a:A:c:C:e:hj:k:l:m:M:N:o:p:q:r:S:u:v:VW:z"
 #endif /* PBS_NO_POSIX_VIOLATION */
@@ -2553,6 +2562,7 @@ int process_opts(
     {
     switch (c)
       {
+
       case '-':
 
         if ((optarg != NULL) && !strcmp(optarg, "version"))
@@ -2654,7 +2664,11 @@ int process_opts(
 
           pc = optarg;
 
-          /* FORMAT:  -c { n | s | c | c=X } */
+          /* OLD FORMAT:  -c { n | s | c | c=X }
+           * New format: -c [ { <old format items> | <new items> } ',' ]
+           * new items: none | shutdown | checkpoint | name=xyz | dir=xyz | interval=X
+           */
+#if 0
 
           if (strlen(optarg) == 1)
             {
@@ -2699,6 +2713,34 @@ int process_opts(
               }
             }
 
+#else
+          nitems = csv_length(optarg);
+
+          for (i = 0; i < nitems; i++)
+            {
+            if ((ptr = csv_nth(optarg, i)) != NULL)
+              {
+              strcpy(search_string, ptr);
+              ptr = strchr(search_string, '=');
+
+              if (ptr)
+                *ptr = 0;
+              else
+                ptr = &search_string[strlen(search_string)];
+
+              while (ptr > search_string && *(ptr - 1) == ' ')
+                *--ptr = 0;
+
+              if (csv_find_string(checkpoint_strings, search_string) == NULL)
+                {
+                fprintf(stderr, "qsub: illegal -c value \"%s\"\n", ptr);
+                errflg++;
+                goto err;
+                }
+              }
+            }
+
+#endif
           set_attr(&attrib, ATTR_c, optarg);
           }  /* END if_cmd_line() */
 
@@ -2815,9 +2857,11 @@ int process_opts(
 
         if_cmd_line(e_opt)
           {
+          int rc = 0;
           e_opt = passet;
 
-          if (prepare_path(optarg, path_out) == 0)
+          rc = prepare_path(optarg, path_out);
+          if ((rc == 0) || (rc == 3))
             {
             set_attr(&attrib, ATTR_e, path_out);
             }
@@ -2830,6 +2874,21 @@ int process_opts(
           }
 
         break;
+        
+#if !defined(PBS_NO_POSIX_VIOLATION)
+      
+      case 'f':
+      
+        if_cmd_line(f_opt)
+          {
+          f_opt = passet;
+          
+          set_attr(&attrib, ATTR_f, "TRUE");
+          }
+          
+        break;
+      
+#endif
 
       case 'h':
 
@@ -3075,9 +3134,11 @@ int process_opts(
 
         if_cmd_line(o_opt)
           {
+          int rc = 0;
           o_opt = passet;
 
-          if (prepare_path(optarg, path_out) == 0)
+          rc = prepare_path(optarg, path_out);
+          if ((rc == 0) || (rc == 3))
             {
             set_attr(&attrib, ATTR_o, path_out);
             }
@@ -3219,9 +3280,9 @@ int process_opts(
 
       case 'T':
 
-        if_cmd_line(T_opt)
+        if_cmd_line(t_opt)
           {
-          T_opt = passet;
+          t_opt = passet;
 
           /* validate before sending request to server? */
 
@@ -3286,6 +3347,21 @@ int process_opts(
 
         break;
 
+      case 'w':
+
+        if (optarg != NULL)
+          {
+          strncpy(PBS_WorkDir, optarg, sizeof(PBS_WorkDir));
+          }
+        else
+          {
+          fprintf(stderr, "qsub: illegal -w value\n");
+
+          errflg++;
+          }
+
+        break;
+
       case 'W':
 
         while (isspace((int)*optarg))
@@ -3322,32 +3398,22 @@ int process_opts(
             {
             if_cmd_line(Depend_opt)
               {
-              int rtn = 0;
               Depend_opt = passet;
 
               pdepend = malloc(PBS_DEPEND_LEN);
 
               if ((pdepend == NULL) ||
-                   (rtn = parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN)))
+                   parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN))
                 {
                 /* cannot parse 'depend' value */
 
-                if (rtn == 2)
-                  {
-                  fprintf(stderr,"qsub: -W value exceeded max length (%d)\n",
-                    PBS_DEPEND_LEN);
-                  }
-                else
-                  {
-                  fprintf(stderr,"qsub: illegal -W value\n");
-                  }
-
+                fprintf(stderr, "qsub: illegal -W value\n");
                 errflg++;
 
                 break;
                 }
 
-              set_attr(&attrib,ATTR_depend,pdepend);
+              set_attr(&attrib, ATTR_depend, pdepend);
               }
             }
           else if (!strcmp(keyword, ATTR_stagein))
@@ -3473,6 +3539,37 @@ int process_opts(
               set_attr(&attrib,ATTR_umask,valuewd);
               }
             }
+          else if (!strcmp(keyword, ATTR_f))
+            {
+            
+            switch (valuewd[0])
+              {
+            
+              /*accept 1, TRUE,true,YES,yes, 0, FALSE, false, NO, no */
+              case 1:
+              case 'T':
+              case 't':
+              case 'Y':
+              case 'y':
+                f_opt = passet;
+                set_attr(&attrib, ATTR_f, "TRUE");
+                break;
+                
+              case 0:
+              case 'F':
+              case 'f':
+              case 'N':
+              case 'n':
+                f_opt = passet;
+                set_attr(&attrib, ATTR_f, "FALSE");
+                break;
+              
+              default:
+                fprintf(stderr, "invalid %s value: %s\n", ATTR_f, valuewd);
+                errflg++;
+              }
+              
+            }
           else
             {
             /* generic job attribute specified */
@@ -3817,8 +3914,19 @@ set_opt_defaults(void)
     set_attr(&attrib, ATTR_p, "0");
 
   if (r_opt == FALSE)
-    set_attr(&attrib, ATTR_r, "TRUE");
-
+    {
+    if (rerunnable_by_default)
+      set_attr(&attrib, ATTR_r, "TRUE");
+    else
+      set_attr(&attrib, ATTR_r, "FALSE");
+    }
+  if (f_opt == FALSE)
+    {
+    if (fault_tolerant_by_default)
+      set_attr(&attrib, ATTR_f, "TRUE");
+    else
+      set_attr(&attrib, ATTR_f, "FALSE");
+    }
   return;
   }  /* END set_opt_defaults() */
 
@@ -3965,6 +4073,8 @@ int main(
 
   char *submit_args_str = NULL;       /* buffer to hold args */
   int   argi, argslen = 0;
+  int   idx;
+  int   have_intr_cmd = FALSE;
 
   if ((param_val = getenv("PBS_CLIENTRETRY")) != NULL)
     {
@@ -4091,23 +4201,39 @@ int main(
       if (!strcasecmp(param_val, "false"))
         validate_path = 0;
       }
+    if ((param_val = get_param("RERUNNABLEBYDEFAULT", config_buf)) != NULL)
+      {
+      if (!strcasecmp(param_val, "false"))
+        rerunnable_by_default = 0;
+      }
+    if ((param_val = get_param("FAULT_TOLERANT_BY_DEFAULT", config_buf)) != NULL)
+      {
+      if (!strcasecmp(param_val, "true"))
+        fault_tolerant_by_default = 1;
+      }
     }    /* END if (load_config(config_buf,sizeof(config_buf)) == 0) */
 
   /* NOTE:  load config before processing opts since config may modify how opts are handled */
 
   errflg = process_opts(argc, argv, 0); /* get cmd-line options */
 
-  if (errflg || ((optind + 1) < argc))
+  if (errflg || (((optind + 1) < argc) && !Interact_opt))
     {
     static char usage[] =
       "usage: qsub [-a date_time] [-A account_string] [-b secs]\n\
-      [-c { c[=<INTERVAL>] | s | n }] [-C directive_prefix] [-d path] [-D path]\n\
+      [-c [ none | { enabled | periodic | shutdown |\n\
+      depth=<int> | dir=<path> | interval=<minutes>}... ]\n\
+      [-C directive_prefix] [-d path] [-D path]\n\
       [-e path] [-h] [-I] [-j oe] [-k {oe}] [-l resource_list] [-m n|{abe}]\n\
       [-M user_list] [-N jobname] [-o path] [-p priority] [-q queue] [-r y|n]\n\
-      [-S path] [-t number_to_submit] [-T type] [-u user_list] [-X]\n\
-      [-W otherattributes=value...] [-v variable_list] [-V ] [-z] [script]\n";
+      [-S path] [-t number_to_submit] [-T type]  [-u user_list] [-X] [-w] path\n";
 
-    fprintf(stderr,"%s", usage);
+    /* need secondary usage since there appears to be a 512 byte size limit */
+
+    static char usage2[] =
+      "      [-W otherattributes=value...] [-v variable_list] [-V ] [-z] [script]\n";
+      
+    fprintf(stderr,"%s%s", usage, usage2);
 
     exit(2);
     }
@@ -4122,6 +4248,16 @@ int main(
   if (optind < argc)
     strcpy(script, argv[optind]);
 
+  argi = argc - optind;
+  if (Interact_opt)
+    {
+    for (idx = 1; idx < argi; idx++)
+      {
+      strcat(script," ");
+      strcat(script, argv[optind + idx]);
+      }
+    }
+
   /* store the saved args string in "submit_args" attribute */
 
   if (submit_args_str != NULL)
@@ -4186,6 +4322,11 @@ int main(
         }
       }
     }    /* END if (!strcmp(script,"") || !strcmp(script,"-")) */
+  else if (Interact_opt != FALSE)
+    {
+      set_attr(&attrib, ATTR_intcmd, script);
+      have_intr_cmd = TRUE;
+    }
   else
     {
     /* non-empty script, read it for directives */
@@ -4267,6 +4408,24 @@ int main(
     exit(2);
     }
 
+  if (Interact_opt && ((isatty(0) == 0) || (isatty(1) == 0)))
+    {
+      if (have_intr_cmd)
+      {
+        have_terminal = FALSE;
+      }
+      else
+      {
+      fprintf(stderr, "qsub:\tstandard input and output must be a terminal for \n\tinteractive job submission\n");
+
+      unlink(script_tmp);
+
+      close(inter_sock);
+
+      exit(1);
+      }
+    }
+
   set_opt_defaults();  /* set option default values */
 
   server_out[0] = '\0';
