@@ -260,6 +260,8 @@ struct rq_authen
 
 #define STAGE_DIR_IN  0
 #define STAGE_DIR_OUT 1
+#define CKPT_DIR_IN  2
+#define CKPT_DIR_OUT 3
 
 struct rq_cpyfile
   {
@@ -267,7 +269,7 @@ struct rq_cpyfile
   char   rq_owner[PBS_MAXUSER + 1];   /* used in Copy only    */
   char    rq_user[PBS_MAXUSER + 1];   /* used in Copy & Delete */
   char    rq_group[PBS_MAXGRPN + 1];   /* used in Copy only     */
-  int   rq_dir;     /* used in Copy only     */
+  int   rq_dir;     /* used in Copy & checkpoint restart delete   */
   tlist_head rq_pair;                        /* list of rqfpair,  used in Copy & Delete */
   };
 
@@ -279,6 +281,13 @@ struct rqfpair
   char  *fp_rmt; /* used in Copy only     */
   };
 
+struct rq_returnfiles
+  {
+  char rq_jobid[PBS_MAXSVRJOBID + 1];
+  int  rq_return_stdout;
+  int  rq_return_stderr;
+  };
+
 /* Job Obituary (MOM -> Server Only) */
 
 struct rq_jobobit
@@ -358,6 +367,8 @@ struct batch_request
 
     struct rq_cpyfile rq_cpyfile;
 
+    struct rq_returnfiles rq_returnfiles;
+
     struct rq_jobobit rq_jobobit;
     } rq_ind;
   };
@@ -396,6 +407,7 @@ extern void  req_trackjob A_((struct batch_request *req));
 #else
 extern void  req_cpyfile A_((struct batch_request *req));
 extern void  req_delfile A_((struct batch_request *req));
+extern void req_returnfiles A_((struct batch_request *req));
 #endif
 
 #ifdef SERVER_LIMITS_H
@@ -415,6 +427,7 @@ extern int decode_DIS_MoveJob A_((int socket, struct batch_request *));
 extern int decode_DIS_MessageJob A_((int socket, struct batch_request *));
 extern int decode_DIS_QueueJob A_((int socket, struct batch_request *));
 extern int decode_DIS_Register A_((int socket, struct batch_request *));
+extern int decode_DIS_ReturnFiles A_((int socket, struct batch_request *));
 extern int decode_DIS_ReqExtend A_((int socket, struct batch_request *));
 extern int decode_DIS_ReqHdr A_((int socket, struct batch_request *, int *tp, int *pv));
 extern int decode_DIS_Rescl A_((int socket, struct batch_request *));
@@ -430,10 +443,43 @@ extern int decode_DIS_svrattrl A_((int socket, tlist_head *));
 extern int encode_DIS_CopyFiles A_((int socket, struct batch_request *));
 extern int encode_DIS_JobObit A_((int socket, struct batch_request *));
 extern int encode_DIS_Register A_((int socket, struct batch_request *));
+extern int encode_DIS_ReturnFiles A_((int socket, struct batch_request *));
 extern int encode_DIS_TrackJob A_((int socket, struct batch_request *));
 extern int encode_DIS_reply A_((int socket, struct batch_reply *));
 extern int encode_DIS_svrattrl A_((int socket, svrattrl *));
 
+/* tcp decode and encode routines */
+extern int tcp_decode_DIS_Authen A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_CopyFiles A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_JobCred A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_JobFile A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_JobObit A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_Manage A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_MoveJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_MessageJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_QueueJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_Register A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_ReqExtend A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_ReqHdr A_((int socket, struct batch_request *, int *tp, int *pv));
+extern int tcp_decode_DIS_Rescl A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_Rescq A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_ReturnFiles A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_RunJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_ShutDown A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_SignalJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_Status A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_TrackJob A_((int socket, struct batch_request *));
+extern int tcp_decode_DIS_replySvr A_((int socket, struct batch_reply *));
+extern int tcp_decode_DIS_svrattrl A_((int socket, tlist_head *));
+
+extern int tcp_encode_DIS_CopyFiles A_((int socket, struct batch_request *));
+extern int tcp_encode_DIS_JobObit A_((int socket, struct batch_request *));
+extern int tcp_encode_DIS_Register A_((int socket, struct batch_request *));
+extern int tcp_encode_DIS_ReturnFiles A_((int socket, struct batch_request *));
+extern int tcp_encode_DIS_TrackJob A_((int socket, struct batch_request *));
+extern int tcp_encode_DIS_reply A_((int socket, struct batch_reply *));
+extern int tcp_encode_DIS_svrattrl A_((int socket, svrattrl *));
+
 extern int dis_request_read A_((int socket, struct batch_request *));
 extern int dis_reply_read A_((int socket, struct batch_reply *));
 
