@@ -117,6 +117,7 @@
 #define volatile
 #endif
 
+
 unsigned long disrul A_((int stream, int *retval));
 
 /*#if UINT_MAX == ULONG_MAX*/
@@ -202,13 +203,14 @@ float disrf A_((int stream, int *retval));
 
 int diswul A_((int stream, unsigned long value));
 /*#if UINT_MAX == ULONG_MAX*/
-#if SIZEOF_UNSIGNED_INT == SIZEOF_UNSIGNED_LONG
+#if SIZEOF_UNSIGNED_INT == SIZEOF_UNSIGNED_LONG 
 #define diswui(stream, value) diswul(stream, (unsigned long)(value))
 #else
 int diswui A_((int stream, unsigned value));
 #endif
 #define diswus(stream, value) diswui(stream, (unsigned)(value))
 #define diswuc(stream, value) diswui(stream, (unsigned)(value))
+#define tcp_diswuc(stream, value) tcp_diswui(stream, (unsigned)(value))
 
 int diswsl A_((int stream, long value));
 /*#if INT_MIN == LONG_MIN && INT_MAX == LONG_MAX*/
@@ -229,6 +231,7 @@ int diswsi A_((int stream, int value));
 
 int diswcs A_((int stream, const char *value, size_t nchars));
 #define diswst(stream, value) diswcs(stream, value, strlen(value))
+#define tcp_diswst(stream, value) tcp_diswcs(stream, value, strlen(value))
 
 int diswl_ A_((int stream, dis_long_double_t value, unsigned int ndigs));
 #define diswl(stream, value) diswl_(stream, (value), LDBL_DIG)
@@ -240,6 +243,7 @@ int diswl_ A_((int stream, dis_long_double_t value, unsigned int ndigs));
 int diswf A_((int stream, double value));
 #endif
 
+
 extern const char *dis_emsg[];
 
 /* the following routines set/control DIS over tcp */
@@ -250,6 +254,22 @@ extern int  DIS_tcp_wflush A_((int fd));
 extern void DIS_tcp_settimeout A_((long timeout));
 extern int  DIS_tcp_istimeout A_((int fd));
 
+extern unsigned tcp_disrui(int stream, int *retval);
+extern int tcp_disrsi(int stream, int *retval);
+extern int tcp_disrfst(int stream, size_t  achars, char *value);
+extern char *tcp_disrcs(int stream, size_t *nchars, int *retval);
+extern char *tcp_disrst(int  stream, int *retval);
+extern long tcp_disrsl(int  stream, int *retval);
+extern int tcp_disrfcs(int stream, size_t  *nchars, size_t  achars, char  *value);
+extern unsigned char tcp_disruc(int stream, int *retval);
+
+extern int tcp_diswui_(int stream, unsigned value, char *buf);
+extern int tcp_diswcs(int stream, const char *value, size_t nchars);
+extern int tcp_diswul(int stream, unsigned long value);
+extern int tcp_diswsi(int stream, int value);
+extern int tcp_diswsl(int stream, long value);
+extern int tcp_diswui(int stream, unsigned value);
+
 extern int  PConnTimeout(int);
 
 /* NOTE:  increase THE_BUF_SIZE to 131072 for systems > 5k nodes */
@@ -261,10 +281,11 @@ extern int  PConnTimeout(int);
 
 struct tcpdisbuf
   {
+  unsigned long tdis_bufsize;
   char *tdis_leadp;
   char *tdis_trailp;
   char *tdis_eod;
-  char  tdis_thebuf[THE_BUF_SIZE];
+  char  *tdis_thebuf;
   };
 
 struct tcp_chan
