@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: libpbs.h 3266 2009-12-01 23:38:21Z knielson $
+ * @(#) $Id: libpbs.h 3172 2009-10-20 17:18:40Z ataufer $
  */
 
 /* libpbs.h
@@ -125,7 +125,7 @@ enum job_file
   StdIn,
   StdOut,
   StdErr,
-  Chkpt
+  Checkpoint
   };
 
 #define MH(type) (type *)malloc(sizeof(type))
@@ -231,54 +231,23 @@ struct batch_reply
     } brp_un;
   };
 
-
-/* The Batch Request ID numbers (sync w/PBatchReqType[]) */
-
+/* This construct pulls the constant parts from the batch types definitions
+ *
+ * @note dis_request_read() is using the PBS_BATCH_CEILING for valid message testing
+ * @see pbs_batchreqtype_db.h for more info
+ */
+#define PbsBatchReqType(id,text) id,
 enum PBatchReqTypeEnum
   {
-  PBS_BATCH_Connect   = 0,
-  PBS_BATCH_QueueJob = 1,
-  PBS_BATCH_JobCred = 2,
-  PBS_BATCH_jobscript = 3,
-  PBS_BATCH_RdytoCommit = 4,
-  PBS_BATCH_Commit = 5,
-  PBS_BATCH_DeleteJob = 6,
-  PBS_BATCH_HoldJob = 7,
-  PBS_BATCH_LocateJob = 8,
-  PBS_BATCH_Manager = 9,
-  PBS_BATCH_MessJob = 10,
-  PBS_BATCH_ModifyJob = 11,
-  PBS_BATCH_MoveJob = 12,
-  PBS_BATCH_ReleaseJob = 13,
-  PBS_BATCH_Rerun = 14,
-  PBS_BATCH_RunJob = 15,
-  PBS_BATCH_SelectJobs = 16,
-  PBS_BATCH_Shutdown = 17,
-  PBS_BATCH_SignalJob = 18,
-  PBS_BATCH_StatusJob = 19,
-  PBS_BATCH_StatusQue = 20,
-  PBS_BATCH_StatusSvr = 21,
-  PBS_BATCH_TrackJob = 22,
-  PBS_BATCH_AsyrunJob = 23,
-  PBS_BATCH_Rescq = 24,
-  PBS_BATCH_ReserveResc = 25,
-  PBS_BATCH_ReleaseResc = 26,
-  PBS_BATCH_StageIn = 48,
-  PBS_BATCH_AuthenUser = 49,
-  PBS_BATCH_OrderJob = 50,
-  PBS_BATCH_SelStat = 51,
-  PBS_BATCH_RegistDep = 52,
-  PBS_BATCH_CopyFiles = 54,
-  PBS_BATCH_DelFiles = 55,
-  PBS_BATCH_JobObit = 56,
-  PBS_BATCH_MvJobFile = 57,
-  PBS_BATCH_StatusNode = 58,
-  PBS_BATCH_Disconnect = 59
+  #include "pbs_batchreqtype_db.h"
+  PBS_BATCH_CEILING
   };
+#undef PbsBatchReqType
+
 /* DIAGTODO: define PBS_BATCH_StatusDiag */
-#define PBS_BATCH_FileOpt_Default 0
-#define PBS_BATCH_FileOpt_OFlg  1
-#define PBS_BATCH_FileOpt_EFlg  2
+#define PBS_BATCH_FileOpt_Default  0
+#define PBS_BATCH_FileOpt_OFlg     1
+#define PBS_BATCH_FileOpt_EFlg     2
 
 #define PBS_credentialtype_none 0
 const char *reqtype_to_txt(int);
@@ -351,6 +320,27 @@ extern int encode_DIS_Status A_((int socket, char *objid, struct attrl *));
 extern int encode_DIS_attrl A_((int socket, struct attrl *));
 extern int encode_DIS_attropl A_((int socket, struct attropl *));
 
+extern int tcp_decode_DIS_JobId A_((int socket, char *jobid));
+extern int tcp_decode_DIS_replyCmd A_((int socket, struct batch_reply *));
+
+extern int tcp_encode_DIS_JobCred A_((int socket, int type, char *cred, int len));
+extern int tcp_encode_DIS_JobFile A_((int socket, int, char *, int, char *, int));
+extern int tcp_encode_DIS_JobId A_((int socket, char *));
+extern int tcp_encode_DIS_Manage A_((int socket, int cmd, int objt, char *, struct attropl *));
+extern int tcp_encode_DIS_MoveJob A_((int socket, char *jid, char *dest));
+extern int tcp_encode_DIS_MessageJob A_((int socket, char *jid, int fopt, char *m));
+extern int tcp_encode_DIS_QueueJob A_((int socket, char *jid, char *dest, struct attropl *));
+extern int tcp_encode_DIS_ReqExtend A_((int socket, char *extend));
+extern int tcp_encode_DIS_ReqHdr A_((int socket, int reqt, char *user));
+extern int tcp_encode_DIS_Rescq A_((int socket, char **rlist, int num));
+extern int tcp_encode_DIS_RunJob A_((int socket, char *jid, char *where, unsigned int resch));
+extern int tcp_encode_DIS_ShutDown A_((int socket, int manner));
+extern int tcp_encode_DIS_SignalJob A_((int socket, char *jid, char *sig));
+extern int tcp_encode_DIS_Status A_((int socket, char *objid, struct attrl *));
+extern int tcp_encode_DIS_attrl A_((int socket, struct attrl *));
+extern int tcp_encode_DIS_attropl A_((int socket, struct attropl *));
+
+
 extern int DIS_reply_read A_((int socket, struct batch_reply *preply));
 
 #endif /* LIBPBS_H */
