@@ -125,7 +125,10 @@ int cnt2server_conf(
 
 
 
-int cnt2server(char *SpecServer)    /* I (optional) */
+int cnt2server(
+
+  char *SpecServer)    /* I (optional) */
+
   {
   int connect;
   time_t firsttime = 0, thistime = 0;
@@ -140,12 +143,14 @@ int cnt2server(char *SpecServer)    /* I (optional) */
 
   memset(Server, 0, sizeof(Server));
 
-  if (SpecServer && SpecServer[0])
+  if ((SpecServer != NULL) && (SpecServer[0] != '\0'))
     {
     strncpy(Server, SpecServer, sizeof(Server));
     Server[sizeof(Server) - 1] = '\0';
     }
 
+  /* NOTE:  env vars PBS_DEFAULT and PBS_SERVER will be checked and applied w/in pbs_connect() */
+
 start:
 
   connect = pbs_connect(Server);
@@ -156,18 +161,17 @@ start:
       {
       switch (pbs_errno)
         {
-
         case PBSE_BADHOST:
 
           if ((Server == NULL) || (Server[0] == '\0'))
             {
             fprintf(stderr, "Cannot resolve default server host '%s' - check server_name file.\n",
-                    pbs_default());
+              pbs_default());
             }
           else
             {
             fprintf(stderr, "Cannot resolve specified server host '%s'.\n",
-                    Server);
+              Server);
             }
 
           break;
@@ -242,7 +246,7 @@ start:
               if (getenv("PBSDEBUG") != NULL)
                 {
                 fprintf(stderr, "attempting fallback server %s\n",
-                        fbserver);
+                  fbserver);
                 }
 
               goto start;
@@ -250,12 +254,12 @@ start:
 
             fprintf(stderr, "Cannot connect to default server host '%s' - check pbs_server daemon.\n",
 
-                    pbs_default());
+              pbs_default());
             }
           else
             {
             fprintf(stderr, "Cannot connect to specified server host '%s'.\n",
-                    Server);
+              Server);
             }
           }
         else
@@ -291,7 +295,7 @@ retry:
     if (getenv("PBSDEBUG") != NULL)
       {
       fprintf(stderr, "seconds remaining: %d\n",
-              (int)(cnt2server_retry - (thistime - firsttime)));
+        (int)(cnt2server_retry - (thistime - firsttime)));
       }
     }
   else
