@@ -1,45 +1,45 @@
 /*
 *         OpenPBS (Portable Batch System) v2.3 Software License
-* 
+*
 * Copyright (c) 1999-2000 Veridian Information Solutions, Inc.
 * All rights reserved.
-* 
+*
 * ---------------------------------------------------------------------------
 * For a license to use or redistribute the OpenPBS software under conditions
 * other than those described below, or to purchase support for this software,
 * please contact Veridian Systems, PBS Products Department ("Licensor") at:
-* 
+*
 *    www.OpenPBS.org  +1 650 967-4675                  sales@OpenPBS.org
 *                        877 902-4PBS (US toll-free)
 * ---------------------------------------------------------------------------
-* 
+*
 * This license covers use of the OpenPBS v2.3 software (the "Software") at
 * your site or location, and, for certain users, redistribution of the
 * Software to other sites and locations.  Use and redistribution of
 * OpenPBS v2.3 in source and binary forms, with or without modification,
 * are permitted provided that all of the following conditions are met.
 * After December 31, 2001, only conditions 3-6 must be met:
-* 
+*
 * 1. Commercial and/or non-commercial use of the Software is permitted
 *    provided a current software registration is on file at www.OpenPBS.org.
 *    If use of this software contributes to a publication, product, or
 *    service, proper attribution must be given; see www.OpenPBS.org/credit.html
-* 
+*
 * 2. Redistribution in any form is only permitted for non-commercial,
 *    non-profit purposes.  There can be no charge for the Software or any
 *    software incorporating the Software.  Further, there can be no
 *    expectation of revenue generated as a consequence of redistributing
 *    the Software.
-* 
+*
 * 3. Any Redistribution of source code must retain the above copyright notice
 *    and the acknowledgment contained in paragraph 6, this list of conditions
 *    and the disclaimer contained in paragraph 7.
-* 
+*
 * 4. Any Redistribution in binary form must reproduce the above copyright
 *    notice and the acknowledgment contained in paragraph 6, this list of
 *    conditions and the disclaimer contained in paragraph 7 in the
 *    documentation and/or other materials provided with the distribution.
-* 
+*
 * 5. Redistributions in any form must be accompanied by information on how to
 *    obtain complete source code for the OpenPBS software and any
 *    modifications and/or additions to the OpenPBS software.  The source code
@@ -47,23 +47,23 @@
 *    than the cost of distribution plus a nominal fee, and all modifications
 *    and additions to the Software must be freely redistributable by any party
 *    (including Licensor) without restriction.
-* 
+*
 * 6. All advertising materials mentioning features or use of the Software must
 *    display the following acknowledgment:
-* 
+*
 *     "This product includes software developed by NASA Ames Research Center,
-*     Lawrence Livermore National Laboratory, and Veridian Information 
+*     Lawrence Livermore National Laboratory, and Veridian Information
 *     Solutions, Inc.
 *     Visit www.OpenPBS.org for OpenPBS software support,
 *     products, and information."
-* 
+*
 * 7. DISCLAIMER OF WARRANTY
-* 
+*
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND. ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT
 * ARE EXPRESSLY DISCLAIMED.
-* 
+*
 * IN NO EVENT SHALL VERIDIAN CORPORATION, ITS AFFILIATED COMPANIES, OR THE
 * U.S. GOVERNMENT OR ANY OF ITS AGENCIES BE LIABLE FOR ANY DIRECT OR INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
@@ -72,7 +72,7 @@
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-* 
+*
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
@@ -86,12 +86,12 @@
 #include "libpbs.h"
 #include "dis.h"
 
-/*	PBSD_submit.c
+/* PBSD_submit.c
 
         PBSD_rdytocmt()
 
-	This function does the Ready To Commit sub-function of
-	the Queue Job request.
+ This function does the Ready To Commit sub-function of
+ the Queue Job request.
 */
 
 
@@ -104,16 +104,17 @@ int PBSD_rdytocmt(
   char *jobid)
 
   {
-  int	rc;
+  int rc;
+
   struct batch_reply *reply;
-  int	sock;
+  int sock;
 
   sock = connection[connect].ch_socket;
   DIS_tcp_setup(sock);
 
-  if ((rc = encode_DIS_ReqHdr(sock,PBS_BATCH_RdytoCommit,pbs_current_user)) ||
-      (rc = encode_DIS_JobId(sock,jobid)) ||
-      (rc = encode_DIS_ReqExtend(sock,NULL))) 
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_RdytoCommit, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_JobId(sock, jobid)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, NULL)))
     {
     connection[connect].ch_errtxt = strdup(dis_emsg[rc]);
 
@@ -122,16 +123,17 @@ int PBSD_rdytocmt(
     return(pbs_errno);
     }
 
-  if (DIS_tcp_wflush(sock)) 
+  if (DIS_tcp_wflush(sock))
     {
     pbs_errno = PBSE_PROTOCOL;
 
     return(pbs_errno);
     }
-	
+
   /* read reply */
 
   reply = PBSD_rdrpy(connect);
+
   PBSD_FreeReply(reply);
 
   return(connection[connect].ch_errno);
@@ -141,10 +143,10 @@ int PBSD_rdytocmt(
 
 
 
-/*	PBS_commit.c
+/* PBS_commit.c
 
-	This function does the Commit sub-function of
-	the Queue Job request.
+ This function does the Commit sub-function of
+ the Queue Job request.
 */
 
 int PBSD_commit(
@@ -153,17 +155,18 @@ int PBSD_commit(
   char *jobid)    /* I */
 
   {
+
   struct batch_reply *reply;
   int rc;
   int sock;
-	
+
   sock = connection[connect].ch_socket;
 
   DIS_tcp_setup(sock);
 
-  if ((rc = encode_DIS_ReqHdr(sock,PBS_BATCH_Commit,pbs_current_user)) ||
-      (rc = encode_DIS_JobId(sock,jobid)) ||
-      (rc = encode_DIS_ReqExtend(sock,NULL))) 
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_Commit, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_JobId(sock, jobid)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, NULL)))
     {
     connection[connect].ch_errtxt = strdup(dis_emsg[rc]);
 
@@ -171,8 +174,8 @@ int PBSD_commit(
 
     return(pbs_errno);
     }
-	
-  if (DIS_tcp_wflush(sock)) 
+
+  if (DIS_tcp_wflush(sock))
     {
     pbs_errno = PBSE_PROTOCOL;
 
@@ -191,24 +194,25 @@ int PBSD_commit(
 
 
 
-/*	PBS_scbuf.c
+/* PBS_scbuf.c
  *
- *	Send a chunk of a of the job script to the server.
- *	Called by pbs_submit.  The buffer length could be
- *	zero; the server should handle that case...
+ * Send a chunk of a of the job script to the server.
+ * Called by pbs_submit.  The buffer length could be
+ * zero; the server should handle that case...
 */
 
 static int PBSD_scbuf(
 
-  int   c,		/* connection handle     */
-  int   reqtype,	/* request type */
-  int   seq,		/* file chunk sequence number */
-  char *buf,		/* file chunk */
-  int   len,		/* length of chunk */
-  char *jobid,		/* job id (for types 1 and 2 only) */
-  enum job_file which)	/* standard file type, see libpbs.h */
+  int   c,  /* connection handle     */
+  int   reqtype, /* request type */
+  int   seq,  /* file chunk sequence number */
+  char *buf,  /* file chunk */
+  int   len,  /* length of chunk */
+  char *jobid,  /* job id (for types 1 and 2 only) */
+  enum job_file which) /* standard file type, see libpbs.h */
 
   {
+
   struct batch_reply *reply;
 
   int rc;
@@ -219,11 +223,11 @@ static int PBSD_scbuf(
   DIS_tcp_setup(sock);
 
   if (jobid == NULL)
-    jobid = "";	/* use null string for null pointer */
+    jobid = ""; /* use null string for null pointer */
 
-  if ((rc = encode_DIS_ReqHdr(sock,reqtype,pbs_current_user)) ||
-      (rc = encode_DIS_JobFile(sock,seq,buf,len,jobid,which)) ||
-      (rc = encode_DIS_ReqExtend(sock,NULL))) 
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, reqtype, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_JobFile(sock, seq, buf, len, jobid, which)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, NULL)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
@@ -232,17 +236,17 @@ static int PBSD_scbuf(
     return(pbs_errno);
     }
 
-  if (DIS_tcp_wflush(sock)) 
+  if (DIS_tcp_wflush(sock))
     {
     pbs_errno = PBSE_PROTOCOL;
 
     return(pbs_errno);
     }
-				
+
   /* read reply */
 
   reply = PBSD_rdrpy(c);
-	
+
   PBSD_FreeReply(reply);
 
   return(connection[c].ch_errno);
@@ -252,46 +256,53 @@ static int PBSD_scbuf(
 
 
 
-/*	PBS_jscript.c
+/* PBS_jscript.c
  *
- *	The Job Script subfunction of the Queue Job request
- *	-- the function PBS_scbuf is called repeatedly to
- *	transfer chunks of the script to the server.
+ * The Job Script subfunction of the Queue Job request
+ * -- the function PBS_scbuf is called repeatedly to
+ * transfer chunks of the script to the server.
 */
 
 int PBSD_jscript(int c, char *script_file, char *jobid)
-{
-	int i;
-	int fd;
-	int cc;
-	char s_buf[SCRIPT_CHUNK_Z];
-	
-	if( (fd = open(script_file, O_RDONLY, 0)) < 0 ) {
-		return (-1);
-	}
-	i = 0;
-	cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
-	while ((cc > 0) && (PBSD_scbuf(c,PBS_BATCH_jobscript,i,s_buf,cc,jobid,JScript) == 0)) {
-		i++;
-		cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
-	}
+  {
+  int i;
+  int fd;
+  int cc;
+  char s_buf[SCRIPT_CHUNK_Z];
 
-	close(fd);
-	if (cc < 0)	/* read failed */
-		return (-1);
-	return connection[c].ch_errno;
-}
+  if ((fd = open(script_file, O_RDONLY, 0)) < 0)
+    {
+    return (-1);
+    }
+
+  i = 0;
+
+  cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
+
+  while ((cc > 0) && (PBSD_scbuf(c, PBS_BATCH_jobscript, i, s_buf, cc, jobid, JScript) == 0))
+    {
+    i++;
+    cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
+    }
+
+  close(fd);
+
+  if (cc < 0) /* read failed */
+    return (-1);
+
+  return connection[c].ch_errno;
+  }
 
 
 
 
 
-/*	PBS_jobfile.c
+/* PBS_jobfile.c
  *
- *	The Job File function used to move files related to
- *	a job between servers.
- *	-- the function PBS_scbuf is called repeatedly to
- *	transfer chunks of the script to the server.
+ * The Job File function used to move files related to
+ * a job between servers.
+ * -- the function PBS_scbuf is called repeatedly to
+ * transfer chunks of the script to the server.
 */
 
 int PBSD_jobfile(
@@ -307,8 +318,8 @@ int PBSD_jobfile(
   int   cc;
   int   fd;
   char  s_buf[SCRIPT_CHUNK_Z];
-	
-  if ((fd = open(path,O_RDONLY,0)) < 0) 
+
+  if ((fd = open(path, O_RDONLY, 0)) < 0)
     {
     return(-1);
     }
@@ -317,17 +328,17 @@ int PBSD_jobfile(
 
   cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
 
-  while ((cc > 0) && 
-         (PBSD_scbuf(c,req_type,i,s_buf,cc,jobid,which) == 0)) 
+  while ((cc > 0) &&
+         (PBSD_scbuf(c, req_type, i, s_buf, cc, jobid, which) == 0))
     {
     i++;
 
-    cc = read(fd,s_buf,SCRIPT_CHUNK_Z);
+    cc = read(fd, s_buf, SCRIPT_CHUNK_Z);
     }
 
   close(fd);
 
-  if (cc < 0)	/* read failed */
+  if (cc < 0) /* read failed */
     {
     return(-1);
     }
@@ -338,9 +349,9 @@ int PBSD_jobfile(
 
 
 
-/*	PBS_queuejob.c
+/* PBS_queuejob.c
 
-	This function sends the first part of the Queue Job request
+ This function sends the first part of the Queue Job request
 */
 
 char *PBSD_queuejob(
@@ -352,20 +363,21 @@ char *PBSD_queuejob(
   char           *extend)
 
   {
+
   struct batch_reply *reply;
   char  *return_jobid = (char *)NULL;
   int    rc;
   int    sock;
-	
+
   sock = connection[connect].ch_socket;
 
   DIS_tcp_setup(sock);
 
   /* first, set up the body of the Queue Job request */
-	
-  if ((rc = encode_DIS_ReqHdr(sock,PBS_BATCH_QueueJob,pbs_current_user)) ||
-      (rc = encode_DIS_QueueJob(sock,jobid,destin,attrib)) ||
-      (rc = encode_DIS_ReqExtend(sock,extend))) 
+
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_QueueJob, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_QueueJob(sock, jobid, destin, attrib)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, extend)))
     {
     connection[connect].ch_errtxt = strdup(dis_emsg[rc]);
 
@@ -374,7 +386,7 @@ char *PBSD_queuejob(
     return(return_jobid);
     }
 
-  if (DIS_tcp_wflush(sock)) 
+  if (DIS_tcp_wflush(sock))
     {
     pbs_errno = PBSE_PROTOCOL;
 
@@ -385,7 +397,7 @@ char *PBSD_queuejob(
 
   reply = PBSD_rdrpy(connect);
 
-  if (reply == NULL) 
+  if (reply == NULL)
     {
     if (PConnTimeout(sock) == 1)
       {
@@ -395,10 +407,10 @@ char *PBSD_queuejob(
       {
       pbs_errno = PBSE_PROTOCOL;
       }
-    } 
+    }
   else if (reply->brp_choice &&
-	   reply->brp_choice != BATCH_REPLY_CHOICE_Text &&
-	   reply->brp_choice != BATCH_REPLY_CHOICE_Queue) 
+           reply->brp_choice != BATCH_REPLY_CHOICE_Text &&
+           reply->brp_choice != BATCH_REPLY_CHOICE_Queue)
     {
     pbs_errno = PBSE_PROTOCOL;
     }
