@@ -98,10 +98,20 @@
 #include "batch_request.h"
 #include "dis.h"
 
-int decode_DIS_Authen(int sock, struct batch_request *preq)
+int
+decode_DIS_Authen(int sock, struct batch_request *preq)
   {
   int rc;
 
   preq->rq_ind.rq_authen.rq_port = disrui(sock, &rc);
   return rc;
   }
+
+int tcp_decode_DIS_Authen(int sock, struct batch_request *preq)
+  {
+  int rc;
+
+  preq->rq_ind.rq_authen.rq_port = tcp_disrui(sock, &rc);
+  return rc;
+  }
+
