@@ -104,3 +104,10 @@ decode_DIS_JobId(int sock, char *jobid)
   {
   return (disrfst(sock, PBS_MAXSVRJOBID + 1, jobid));
   }
+
+int
+tcp_decode_DIS_JobId(int sock, char *jobid)
+  {
+  return (tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, jobid));
+  }
+
