@@ -100,7 +100,8 @@
 #include "batch_request.h"
 #include "dis.h"
 
-int decode_DIS_MoveJob(int sock, struct batch_request *preq)
+int
+decode_DIS_MoveJob(int sock, struct batch_request *preq)
   {
   int rc;
 
@@ -112,3 +113,17 @@ int decode_DIS_MoveJob(int sock, struct batch_request *preq)
 
   return rc;
   }
+
+int tcp_decode_DIS_MoveJob(int sock, struct batch_request *preq)
+  {
+  int rc;
+
+  rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, preq->rq_ind.rq_move.rq_jid);
+
+  if (rc) return rc;
+
+  rc = tcp_disrfst(sock, PBS_MAXDEST + 1, preq->rq_ind.rq_move.rq_destin);
+
+  return rc;
+  }
+
