@@ -112,3 +112,18 @@ decode_DIS_SignalJob(int sock, struct batch_request *preq)
 
   return rc;
   }
+
+int
+tcp_decode_DIS_SignalJob(int sock, struct batch_request *preq)
+  {
+  int rc;
+
+  rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, preq->rq_ind.rq_signal.rq_jid);
+
+  if (rc) return rc;
+
+  rc = tcp_disrfst(sock, PBS_SIGNAMESZ + 1, preq->rq_ind.rq_signal.rq_signame);
+
+  return rc;
+  }
+
