@@ -122,3 +122,25 @@ decode_DIS_TrackJob(int sock, struct batch_request *preq)
 
   return rc;
   }
+
+int
+tcp_decode_DIS_TrackJob(int sock, struct batch_request *preq)
+  {
+  int rc;
+
+  rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, preq->rq_ind.rq_track.rq_jid);
+
+  if (rc) return rc;
+
+  preq->rq_ind.rq_track.rq_hopcount = tcp_disrui(sock, &rc);
+
+  if (rc) return rc;
+
+  rc = tcp_disrfst(sock, PBS_MAXDEST + 1, preq->rq_ind.rq_track.rq_location);
+
+  if (rc) return rc;
+
+  preq->rq_ind.rq_track.rq_state[0] = tcp_disruc(sock, &rc);
+
+  return rc;
+  }
