@@ -262,3 +262,169 @@ int decode_DIS_replySvr(
 
   return rc;
   }
+
+
+int tcp_decode_DIS_replySvr(
+
+  int                 sock,   /* I */
+  struct batch_reply *reply)  /* I (modified) */
+
+  {
+  int        ct;
+  int        i;
+
+  struct brp_select    *psel;
+
+  struct brp_select   **pselx;
+
+  struct brp_status    *pstsvr;
+  int        rc = 0;
+
+  /* first decode "header" consisting of protocol type and version */
+
+  i = tcp_disrui(sock, &rc);
+
+  if (rc != 0) return rc;
+
+  if (i != PBS_BATCH_PROT_TYPE) return DIS_PROTO;
+
+  i = tcp_disrui(sock, &rc);
+
+  if (rc != 0) return rc;
+
+  if (i != PBS_BATCH_PROT_VER) return DIS_PROTO;
+
+  /* next decode code, auxcode and choice (union type identifier) */
+
+  reply->brp_code    = tcp_disrsi(sock, &rc);
+
+  if (rc) return rc;
+
+  reply->brp_auxcode = tcp_disrsi(sock, &rc);
+
+  if (rc) return rc;
+
+  reply->brp_choice  = tcp_disrui(sock, &rc);
+
+  if (rc) return rc;
+
+
+  switch (reply->brp_choice)
+    {
+
+    case BATCH_REPLY_CHOICE_NULL:
+      break; /* no more to do */
+
+    case BATCH_REPLY_CHOICE_Queue:
+
+    case BATCH_REPLY_CHOICE_RdytoCom:
+
+    case BATCH_REPLY_CHOICE_Commit:
+
+      if ((rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, reply->brp_un.brp_jid)))
+        return (rc);
+
+      break;
+
+    case BATCH_REPLY_CHOICE_Select:
+
+      /* have to get count of number of strings first */
+
+      reply->brp_un.brp_select = (struct brp_select *)0;
+
+      pselx = &reply->brp_un.brp_select;
+
+      ct = tcp_disrui(sock, &rc);
+
+      if (rc) return rc;
+
+      while (ct--)
+        {
+        psel = (struct brp_select *)malloc(sizeof(struct brp_select));
+
+        if (psel == 0) return DIS_NOMALLOC;
+
+        psel->brp_next = (struct brp_select *)0;
+
+        psel->brp_jobid[0] = '\0';
+
+        rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1, psel->brp_jobid);
+
+        if (rc)
+          {
+          (void)free(psel);
+          return rc;
+          }
+
+        *pselx = psel;
+
+        pselx = &psel->brp_next;
+        }
+
+      break;
+
+    case BATCH_REPLY_CHOICE_Status:
+
+      /* have to get count of number of status objects first */
+
+      CLEAR_HEAD(reply->brp_un.brp_status);
+      ct = tcp_disrui(sock, &rc);
+
+      if (rc) return rc;
+
+      while (ct--)
+        {
+        pstsvr = (struct brp_status *)malloc(sizeof(struct brp_status));
+
+        if (pstsvr == 0) return DIS_NOMALLOC;
+
+        CLEAR_LINK(pstsvr->brp_stlink);
+
+        pstsvr->brp_objname[0] = '\0';
+
+        CLEAR_HEAD(pstsvr->brp_attr);
+
+        pstsvr->brp_objtype = tcp_disrui(sock, &rc);
+
+        if (rc == 0)
+          {
+          rc = tcp_disrfst(sock, PBS_MAXSVRJOBID + 1,
+                       pstsvr->brp_objname);
+          }
+
+        if (rc)
+          {
+          (void)free(pstsvr);
+          return rc;
+          }
+
+        append_link(&reply->brp_un.brp_status,
+
+                    &pstsvr->brp_stlink, pstsvr);
+        rc = tcp_decode_DIS_svrattrl(sock, &pstsvr->brp_attr);
+        }
+
+      break;
+
+    case BATCH_REPLY_CHOICE_Text:
+
+      /* text reply */
+
+      reply->brp_un.brp_txt.brp_str = tcp_disrcs(sock,
+                                             &reply->brp_un.brp_txt.brp_txtlen,
+                                             &rc);
+      break;
+
+    case BATCH_REPLY_CHOICE_Locate:
+
+      /* Locate Job Reply */
+
+      rc = tcp_disrfst(sock, PBS_MAXDEST + 1, reply->brp_un.brp_locate);
+      break;
+
+    default:
+      return -1;
+    }
+
+  return rc;
+  }
