@@ -183,6 +183,86 @@ int encode_DIS_attrl(
   return(rc);
   }  /* END encode_DIS_attrl() */
 
+int tcp_encode_DIS_attrl(
+
+  int         sock,
+  struct attrl *pattrl)
+
+  {
+  unsigned int ct = 0;
+  unsigned int name_len;
+
+  struct attrl *ps;
+  int rc;
+
+  /* count how many */
+
+  for (ps = pattrl;ps != NULL;ps = ps->next)
+    {
+    ++ct;
+    }
+
+  if ((rc = tcp_diswui(sock, ct)))
+    {
+    return(rc);
+    }
+
+  for (ps = pattrl;ps != NULL;ps = ps->next)
+    {
+    /* length of three strings */
+
+    name_len = 0;
+
+    if (ps->name != NULL)
+      {
+      name_len += (int)strlen(ps->name) + 1;
+      }
+
+    if (ps->value != NULL)
+      {
+      name_len += (int)strlen(ps->value) + 1;
+      }
+
+    if (ps->resource != NULL)
+      name_len += strlen(ps->resource) + 1;
+
+    rc = tcp_diswui(sock, name_len);
+
+    if (rc != 0)
+      break;
+
+    rc = tcp_diswst(sock, ps->name);
+
+    if (rc != 0)
+      break;
+
+    if (ps->resource != NULL)
+      {
+      /* has a resource name */
+
+      if ((rc = tcp_diswui(sock, 1)) != 0)
+        break;
+
+      if ((rc = tcp_diswst(sock, ps->resource)) != 0)
+        break;
+      }
+    else
+      {
+      if ((rc = tcp_diswui(sock, 0)) != 0) /* no resource name */
+        break;
+      }
+
+    if ((rc = tcp_diswst(
+                sock,
+                (ps->value != NULL) ? ps->value : "")) ||
+        (rc = tcp_diswui(sock, (unsigned int)SET)))
+      break;
+    }  /* END for (ps) */
+
+  return(rc);
+  }  /* END tcp_encode_DIS_attrl() */
+
+
 
 /* END enc_attrl() */
 
