@@ -187,4 +187,89 @@ int encode_DIS_attropl(
   }  /* END encode_DIS_attropl() */
 
 
+int tcp_encode_DIS_attropl(
+
+  int   sock,
+  struct attropl *pattropl)
+
+  {
+  unsigned int ct = 0;
+  unsigned int name_len;
+
+  struct attropl *ps;
+  int rc;
+
+  /* count how many */
+
+  for (ps = pattropl;ps;ps = ps->next)
+    {
+    ++ct;
+    }
+
+  if ((rc = tcp_diswui(sock, ct)))
+    {
+    return(rc);
+    }
+
+  for (ps = pattropl;ps;ps = ps->next)
+    {
+    /* length of three strings */
+
+    if (ps->name == NULL)
+      {
+      /* Continue if attribute has no name (CRI 2005-04-22). */
+
+      continue;
+      }
+
+    name_len = strlen(ps->name) + 1;
+
+    if (ps->value != NULL)
+      name_len += strlen(ps->value) + 1;
+
+    if (ps->resource != NULL)
+      name_len += strlen(ps->resource) + 1;
+
+    if ((rc = tcp_diswui(sock, name_len)))
+      break;
+
+    if ((rc = tcp_diswst(sock, ps->name)))
+      break;
+
+    if (ps->resource != NULL)
+      {
+      /* has a resource name */
+
+      if ((rc = tcp_diswui(sock, 1)))
+        break;
+
+      if ((rc = tcp_diswst(sock, ps->resource)))
+        break;
+      }
+    else
+      {
+      if ((rc = tcp_diswui(sock, 0))) /* no resource name */
+        break;
+      }
+
+    if (ps->value != NULL)
+      {
+      if ((rc = tcp_diswst(sock, ps->value)) ||
+          (rc = tcp_diswui(sock, (unsigned int)ps->op)))
+        break;
+      }
+    else
+      {
+      if ((rc = tcp_diswst(sock, "")) ||
+          (rc = tcp_diswui(sock, (unsigned int)ps->op)))
+        break;
+      }
+    }    /* END for (ps) */
+
+  return(rc);
+  }  /* END tcp_encode_DIS_attropl() */
+
+
+
+
 
