@@ -108,6 +108,7 @@
 #endif
 
 #include "libpbs.h"
+#include "csv.h"
 #include "dis.h"
 #include "net_connect.h"
 
@@ -137,78 +138,6 @@ static const char *pbs_destn_file = PBS_DEFAULT_FILE;
 char *pbs_server = NULL;
 
 
-/**
- * Gets the number of items in a string list.
- * @param str  The string list.
- * @return The number of items in the list.
- */
-int csv_length(char *str)
-  {
-  int  length = 0;
-  char *cp;
-
-  if (!str || *str == 0)
-    return(0);
-
-  length++;
-
-  cp = str;
-
-  while ((cp = strchr(cp, ',')))
-    {
-    cp++;
-    length++;
-    }
-
-  return(length);
-  }
-
-/**
- * Gets the nth item from a comma seperated list of names.
- * @param str  The string list.
- * @param n The item number requested (0 is the first item).
- * @return Null if str is null or empty,
- *     otherwise, a pointer to a local buffer containing the nth item.
- */
-char *csv_nth(char *str, int n)
-  {
-  int  i;
-  char *cp;
-  char *tp;
-  static char buffer[128];
-
-  if (!str || *str == 0)
-    return(0);
-
-  cp = str;
-
-  for (i = 0; i < n; i++)
-    {
-    if (!(cp = strchr(cp, ',')))
-      {
-      return(0);
-      }
-
-    cp++;
-    }
-
-  memset(buffer, 0, sizeof(buffer));
-
-  if ((tp = strchr(cp, ',')))
-    {
-    strncpy(buffer, cp, tp - cp);
-    }
-  else
-    {
-    strcpy(buffer, cp);
-    }
-
-  return(buffer);
-  }
-
-
-
-
 /**
  * Attempts to get a list of server names.  Trys first
  * to obtain the list from an envrionment variable PBS_DEFAULT.
@@ -232,6 +161,8 @@ char *pbs_get_server_list(void)
   FILE *fd;
   char *pn;
   char *server;
+  char tmp[1024];
+  int len;
 
   if (got_dflt != TRUE)
     {
@@ -252,16 +183,28 @@ char *pbs_get_server_list(void)
         return(server_list);
         }
 
-      if (fgets(server_list, sizeof(server_list), fd) == NULL)
+      if (fgets(tmp, sizeof(tmp), fd) == NULL)
         {
         fclose(fd);
 
         return(server_list);
         }
 
+      strcpy(server_list, tmp);
       if ((pn = strchr(server_list, (int)'\n')))
         * pn = '\0';
 
+      while(fgets(tmp, sizeof(tmp), fd))
+        {
+        strcat(server_list, ",");
+        strcat(server_list, tmp);
+        len = strlen(server_list);
+        if(server_list[len-1] == '\n')
+          {
+          server_list[len-1] = '\0';
+          }
+        }
+
       fclose(fd);
       }
     else
@@ -279,7 +222,6 @@ char *pbs_get_server_list(void)
 
 
 
-
 /**
  * The routine is called to get the name of the primary
  * server.  It can possibly trigger reading of the server name
@@ -292,7 +234,6 @@ char *pbs_get_server_list(void)
  */
 
 char *pbs_default(void)
-
   {
   char *cp;
 
@@ -325,7 +266,6 @@ char *pbs_default(void)
  */
 
 char *pbs_fbserver(void)
-
   {
   char *cp;
 
@@ -448,7 +388,7 @@ static int PBSD_authenticate(
 
       if ((ptr = getenv("PATH")) != NULL)
         {
-        ptr = strtok(ptr, ":");
+        ptr = strtok(ptr, ";");
 
         while (ptr != NULL)
           {
@@ -460,7 +400,7 @@ static int PBSD_authenticate(
           if (rc != -1)
             break;
 
-          ptr = strtok(NULL, ":");
+          ptr = strtok(NULL, ";");
           }  /* END while (ptr != NULL) */
         }    /* END if ((ptr = getenv("PATH")) != NULL) */
 
@@ -926,7 +866,7 @@ int pbs_disconnect(
 
   DIS_tcp_setup(sock);
 
-  if ((encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user) == 0) &&
+  if ((tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user) == 0) &&
       (DIS_tcp_wflush(sock) == 0))
     {
     int atime;
