@@ -87,11 +87,8 @@
 #include "libpbs.h"
 #include "dis.h"
 
-int pbs_orderjob(c, job1, job2, extend)
-int c;
-char *job1;
-char *job2;
-char *extend;
+int
+pbs_orderjob(int c, char *job1, char *job2, char *extend)
   {
 
   struct batch_reply *reply;
@@ -109,9 +106,9 @@ char *extend;
 
   DIS_tcp_setup(sock);
 
-  if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_OrderJob, pbs_current_user)) ||
-      (rc = encode_DIS_MoveJob(sock, job1, job2)) ||
-      (rc = encode_DIS_ReqExtend(sock, extend)))
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_OrderJob, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_MoveJob(sock, job1, job2)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
     return (pbs_errno = PBSE_PROTOCOL);
