@@ -88,10 +88,8 @@
 #include "libpbs.h"
 #include "dis.h"
 
-int pbs_rerunjob(c, jobid, extend)
-int c;
-char *jobid;
-char *extend;
+int
+pbs_rerunjob(int c, char *jobid, char *extend)
   {
   int rc;
 
@@ -107,9 +105,9 @@ char *extend;
 
   DIS_tcp_setup(sock);
 
-  if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_Rerun, pbs_current_user)) ||
-      (rc = encode_DIS_JobId(sock, jobid)) ||
-      (rc = encode_DIS_ReqExtend(sock, extend)))
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_Rerun, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_JobId(sock, jobid)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
     return (pbs_errno = PBSE_PROTOCOL);
