@@ -96,7 +96,7 @@ static int nodes_down  = 0;
 static char *resc_nodes = "nodes";
 
 /*
- * encode_DIS_resc() - encode a resource related request,
+ * tcp_encode_DIS_resc() - encode a resource related request,
  * Used by pbs_rescquery(), pbs_rescreserve() and pbs_rescfree()
  *
  * Data items are:  signed int resource handle
@@ -105,7 +105,7 @@ static char *resc_nodes = "nodes";
  *     string resource query
  */
 
-static int encode_DIS_Resc(sock, rlist, ct, rh)
+static int tcp_encode_DIS_Resc(sock, rlist, ct, rh)
 int       sock;
 char     **rlist;
 int       ct;
@@ -114,19 +114,19 @@ resource_t    rh;
   int    i;
   int    rc;
 
-  if ((rc = diswsi(sock, rh)) == 0)     /* resource reservation handle */
+  if ((rc = tcp_diswsi(sock, rh)) == 0)     /* resource reservation handle */
     {
 
     /* next send the number of resource strings */
 
-    if ((rc = diswui(sock, ct)) == 0)
+    if ((rc = tcp_diswui(sock, ct)) == 0)
       {
 
       /* now send each string (if any) */
 
       for (i = 0; i < ct; ++i)
         {
-        if ((rc = diswst(sock, *(rlist + i))) != 0)
+        if ((rc = tcp_diswst(sock, *(rlist + i))) != 0)
           break;
         }
       }
@@ -135,12 +135,17 @@ resource_t    rh;
   return rc;
   }
 
-static int PBS_resc(c, reqtype, rescl, ct, rh)
-int    c;
-int    reqtype;
-char     **rescl;
-int    ct;
-resource_t rh;
+
+/*
+ * PBS_resc() - internal common code for sending resource requests
+ *
+ * Formats and sends the requests for pbs_rescquery(), pbs_rescreserve(),
+ * and pbs_rescfree().   Note, while the request is overloaded for all
+ * three, each has its own expected reply format.
+ */
+
+static int
+PBS_resc(int c, int reqtype, char **rescl, int ct, resource_t rh)
   {
   int rc;
   int sock;
@@ -151,9 +156,9 @@ resource_t rh;
 
   DIS_tcp_setup(sock);
 
-  if ((rc = encode_DIS_ReqHdr(sock, reqtype, pbs_current_user)) ||
-      (rc = encode_DIS_Resc(sock, rescl, ct, rh)) ||
-      (rc = encode_DIS_ReqExtend(sock, (char *)0)))
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, reqtype, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_Resc(sock, rescl, ct, rh)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, (char *)0)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
     return (pbs_errno = PBSE_PROTOCOL);
@@ -233,11 +238,13 @@ int pbs_rescquery(
 
 /* pbs_reserve() - reserve resources */
 
-int pbs_rescreserve(c, rl, num_resc, prh)
-int   c;  /* connection */
-char **rl;  /* list of resources */
-int   num_resc; /* number of items in list */
-resource_t *prh; /* ptr to resource reservation handle */
+int
+pbs_rescreserve(
+  int c,  /* connection */
+  char **rl,  /* list of resources */
+  int num_resc, /* number of items in list */
+  resource_t *prh /* ptr to resource reservation handle */
+)
   {
   int rc;
 
@@ -285,9 +292,8 @@ resource_t *prh; /* ptr to resource reservation handle */
  * list is empty.
  */
 
-int pbs_rescrelease(c, rh)
-int    c;
-resource_t rh;
+int
+pbs_rescrelease(int c, resource_t rh)
   {
 
   struct batch_reply *reply;
