@@ -102,8 +102,8 @@ int pbs_runjob(
   unsigned int resch = 0;
   int sock;
 
-  /* NOTE:  routes over to req_runjob() on server side 
-       DIS_tcp_wflush  -----> wait_request()                       (net_server.c) 
+  /* NOTE:  routes over to req_runjob() on server side
+       DIS_tcp_wflush  -----> wait_request()                       (net_server.c)
                                 process_request()                  (server/process_request.c)
                                   dis_request_read()               (server/dis_read.c)
                                     decode_DIS_RunJob()            (lib/Libifl/dec_RunJob.c)
@@ -164,9 +164,9 @@ int pbs_runjob(
 
   /* send run request */
 
-  if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_RunJob, pbs_current_user)) ||
-      (rc = encode_DIS_RunJob(sock, jobid, location, resch)) ||
-      (rc = encode_DIS_ReqExtend(sock, extend)))
+  if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_RunJob, pbs_current_user)) ||
+      (rc = tcp_encode_DIS_RunJob(sock, jobid, location, resch)) ||
+      (rc = tcp_encode_DIS_ReqExtend(sock, extend)))
     {
     connection[c].ch_errtxt = strdup(dis_emsg[rc]);
 
