@@ -85,6 +85,7 @@
 #include <signal.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include <time.h>
 
 #include <sys/types.h>
@@ -133,7 +134,7 @@ struct connection svr_conn[PBS_NET_MAX_CONNECTIONS];
 
 static int max_connection = PBS_NET_MAX_CONNECTIONS;
 static int num_connections = 0;
-static fd_set readset;
+static fd_set *GlobalSocketReadSet = NULL;
 static void (*read_func[2]) A_((int));
 
 pbs_net_t pbs_server_addr;
@@ -246,6 +247,8 @@ int init_network(
   static int  initialized = 0;
   int    sock;
 
+  int MaxNumDescriptors = 0;
+
   struct sockaddr_in socname;
   enum conn_type   type;
 #ifdef ENABLE_UNIX_SOCKETS
@@ -255,6 +258,8 @@ int init_network(
   memset(&unsocname, 0, sizeof(unsocname));
 #endif
  
+  MaxNumDescriptors = get_max_num_descriptors();
+
   memset(&socname, 0, sizeof(socname));
 
   if (initialized == 0)
@@ -262,7 +267,8 @@ int init_network(
     for (i = 0;i < PBS_NET_MAX_CONNECTIONS;i++)
       svr_conn[i].cn_active = Idle;
 
-    FD_ZERO(&readset);
+    /* initialize global "read" socket FD bitmap */
+    GlobalSocketReadSet = (fd_set *)calloc(1,sizeof(char) * get_fdset_size());
 
     type = Primary;
     }
@@ -272,6 +278,8 @@ int init_network(
     }
   else
     {
+    /* FAILURE */
+
     return(-1); /* too many main connections */
     }
 
@@ -286,11 +294,13 @@ int init_network(
 
     if (sock < 0)
       {
+      /* FAILURE */
+
       return(-1);
       }
 
-    if (FD_SETSIZE < PBS_NET_MAX_CONNECTIONS)
-      max_connection = FD_SETSIZE;
+  if (MaxNumDescriptors < PBS_NET_MAX_CONNECTIONS)
+    max_connection = MaxNumDescriptors;
 
     i = 1;
 
@@ -315,17 +325,17 @@ int init_network(
 
     /* record socket in connection structure and select set */
 
-    add_conn(sock,type,(pbs_net_t)0,0,PBS_SOCK_INET,accept_conn);
+    add_conn(sock, type, (pbs_net_t)0, 0, PBS_SOCK_INET, accept_conn);
 
     /* start listening for connections */
 
-    if (listen(sock,512) < 0)
+    if (listen(sock, 512) < 0)
       {
       /* FAILURE */
 
       return(-1);
       }
-    } /* if port != 0 */
+    } /* END if (port != 0) */
 
 #ifdef ENABLE_UNIX_SOCKETS
   if (port == 0)
@@ -341,7 +351,7 @@ int init_network(
 
     unsocname.sun_family = AF_UNIX;
 
-    strncpy(unsocname.sun_path, TSOCK_PATH, sizeof(unsocname.sun_path) - 1);  
+    strncpy(unsocname.sun_path, TSOCK_PATH, 107);  /* sun_path is defined to be 108 bytes */
 
     unlink(TSOCK_PATH);  /* don't care if this fails */
 
@@ -365,11 +375,13 @@ int init_network(
 
     if (listen(unixsocket, 512) < 0)
       {
+      /* FAILURE */
+
       return(-1);
       }
     }   /* END if (port == 0) */
 
-#endif /* END ENABLE_UNIX_SOCKETS */
+#endif  /* END ENABLE_UNIX_SOCKETS */
 
   if (port != 0)
     {
@@ -403,19 +415,22 @@ int wait_request(
 
   {
   extern char *PAddrToString(pbs_net_t *);
+  void close_conn();
 
   int i;
   int n;
 
   time_t now;
 
-  fd_set selset;
+  fd_set *SelectSet = NULL;
+  int SelectSetSize = 0;
+
+  int MaxNumDescriptors = 0;
 
   char id[] = "wait_request";
   char tmpLine[1024];
 
   struct timeval timeout;
-  void close_conn();
 
   long OrigState = 0;
 
@@ -426,9 +441,15 @@ int wait_request(
 
   timeout.tv_sec  = waittime;
 
-  selset = readset;  /* readset is global */
+  SelectSetSize = sizeof(char) * get_fdset_size();
+  SelectSet = (fd_set *)calloc(1,SelectSetSize);
 
-  n = select(FD_SETSIZE, &selset, (fd_set *)0, (fd_set *)0, &timeout);
+  memcpy(SelectSet,GlobalSocketReadSet,SelectSetSize);
+ 
+  /* selset = readset;*/  /* readset is global */
+  MaxNumDescriptors = get_max_num_descriptors();
+
+  n = select(MaxNumDescriptors, SelectSet, (fd_set *)0, (fd_set *)0, &timeout);
 
   if (n == -1)
     {
@@ -442,14 +463,13 @@ int wait_request(
 
       struct stat fbuf;
 
-
       /* check all file descriptors to verify they are valid */
 
       /* NOTE:  selset may be modified by failed select() */
 
-      for (i = 0;i < (int)FD_SETSIZE;i++)
+      for (i = 0;i < MaxNumDescriptors;i++)
         {
-        if (FD_ISSET(i, &readset) == 0)
+        if (FD_ISSET(i, GlobalSocketReadSet) == 0)
           continue;
 
         if (fstat(i, &fbuf) == 0)
@@ -457,16 +477,17 @@ int wait_request(
 
         /* clean up SdList and bad sd... */
 
-        FD_CLR(i, &readset);
+        FD_CLR(i, GlobalSocketReadSet);
         }    /* END for (i) */
 
+      free(SelectSet);
       return(-1);
       }  /* END else (errno == EINTR) */
     }    /* END if (n == -1) */
 
   for (i = 0;(i < max_connection) && (n != 0);i++)
     {
-    if (FD_ISSET(i, &selset))
+    if (FD_ISSET(i, SelectSet))
       {
       /* this socket has data */
 
@@ -477,6 +498,7 @@ int wait_request(
       if (svr_conn[i].cn_active != Idle)
         {
         netcounter_incr();
+
         svr_conn[i].cn_func(i);
 
         /* NOTE:  breakout if state changed (probably received shutdown request) */
@@ -486,12 +508,8 @@ int wait_request(
         }
       else
         {
-        FD_CLR(i, &readset);
-
-        close(i);
-
-        num_connections--;  /* added by CRI - should this be here? */
-
+        FD_CLR(i, GlobalSocketReadSet);
+        close_conn(i);
         sprintf(tmpLine,"closed connection to fd %d - num_connections=%d (select bad socket)",
           i,
           num_connections);
@@ -505,6 +523,7 @@ int wait_request(
 
   if ((SState != NULL) && (OrigState != *SState))
     {
+    free(SelectSet);
     return(0);
     }
 
@@ -544,6 +563,7 @@ int wait_request(
     close_conn(i);
     }  /* END for (i) */
 
+  free(SelectSet);
   return(0);
   }  /* END wait_request() */
 
@@ -580,7 +600,6 @@ static void accept_conn(
 
   svr_conn[sd].cn_lasttime = time((time_t *)0);
 
-
   if (svr_conn[sd].cn_socktype == PBS_SOCK_INET)
     {
     fromsize = sizeof(from);
@@ -624,6 +643,8 @@ static void accept_conn(
 /*
  * add_conn - add a connection to the svr_conn array.
  * The params addr and port are in host order.
+ *
+ * NOTE:  This routine cannot fail.
  */
 
 void add_conn(
@@ -638,7 +659,7 @@ void add_conn(
   {
   num_connections++;
 
-  FD_SET(sock, &readset);
+  FD_SET(sock, GlobalSocketReadSet);
 
   svr_conn[sock].cn_active   = type;
   svr_conn[sock].cn_addr     = addr;
@@ -709,7 +730,15 @@ void close_conn(
   if (svr_conn[sd].cn_oncl != 0)
     svr_conn[sd].cn_oncl(sd);
 
-  FD_CLR(sd, &readset);
+  /* 
+   * In the case of a -t cold start, this will be called prior to
+   * GlobalSocketReadSet being initialized
+   */
+
+  if (GlobalSocketReadSet != NULL)
+  {
+    FD_CLR(sd, GlobalSocketReadSet);
+  }
 
   svr_conn[sd].cn_addr = 0;
 
@@ -889,6 +918,31 @@ int get_connecthost(
 
 
 
+/*
+** Put a human readable representation of a network address into
+** a staticly allocated string.
+*/
+char *netaddr_pbs_net_t(
+
+  pbs_net_t ipadd)
+
+  {
+  static char out[80];
+
+  if (ipadd == 0)
+    return "unknown";
+
+  sprintf(out, "%ld.%ld.%ld.%ld",
+          (ipadd & 0xff000000) >> 24,
+          (ipadd & 0x00ff0000) >> 16,
+          (ipadd & 0x0000ff00) >> 8,
+          (ipadd & 0x000000ff));
+
+  return (out);
+  }
+
+
+
 
 /* END net_server.c */
 
