@@ -417,9 +417,7 @@ static int startcom(
     ret = diswsi(stream, RM_PROTOCOL_VER);
 
     if (ret == DIS_SUCCESS)
-      {
       ret = diswsi(stream, com);
-      }
     }
 
   if (ret != DIS_SUCCESS)
@@ -502,7 +500,6 @@ static int simpleget(
   {
   int ret, num;
 
-
   num = disrsi(stream, &ret);
 
   if (ret != DIS_SUCCESS)
@@ -635,8 +632,7 @@ int configrm(
     return(-1);
     }
 
-    ret = diswcs(stream, file, len);
-
+  ret = diswcs(stream, file, len);
 
   if (ret != DIS_SUCCESS)
     {
@@ -705,7 +701,6 @@ static int doreq(
 
   ret = diswcs(op->stream, line, strlen(line));
 
-
   if (ret != DIS_SUCCESS)
     {
 #if defined(ECOMM)
@@ -883,7 +878,6 @@ char *getreq(
     op->len = -1;
     }
 
-
   startline = disrst(stream, &ret);
 
   if (ret == DIS_EOF)
@@ -1051,13 +1045,16 @@ int activereq(void)
 
   struct timeval tv;
 
-  fd_set         fdset;
+  fd_set *FDSet;
+
+  int MaxNumDescriptors = 0;
 
   pbs_errno = 0;
 
   flushreq();
 
-  FD_ZERO(&fdset);
+  MaxNumDescriptors = get_max_num_descriptors();
+  FDSet = (fd_set *)calloc(1,sizeof(char) * get_fdset_size());
 
 #if RPP
   for (try = 0;try < 3;)
@@ -1066,6 +1063,7 @@ int activereq(void)
       {
       if ((op = findout(i)) != NULL)
         {
+        free(FDSet);
         return(i);
         }
 
@@ -1075,6 +1073,7 @@ int activereq(void)
         {
         pbs_errno = errno;
 
+        free(FDSet);
         return(-1);
         }
 
@@ -1090,20 +1089,22 @@ int activereq(void)
       {
       pbs_errno = errno;
 
+      free(FDSet);
       return(-1);
       }
     else
       {
 
-      FD_SET(rpp_fd, &fdset);
+			FD_SET(rpp_fd, FDSet);
       tv.tv_sec = 5;
       tv.tv_usec = 0;
-      num = select(FD_SETSIZE, &fdset, NULL, NULL, &tv);
+			num = select(FD_SETSIZE, FDSet, NULL, NULL, &tv);
 
       if (num == -1)
         {
         pbs_errno = errno;
         DBPRT(("%s: select %d %s\n", id, pbs_errno, pbs_strerror(pbs_errno)))
+        free(FDSet);
         return -1;
         }
 
@@ -1116,6 +1117,7 @@ int activereq(void)
       }
     }
 
+  free(FDSet);
   return i;
 
 #else
@@ -1130,7 +1132,7 @@ int activereq(void)
 
     while (op)
       {
-      FD_SET(op->stream, &fdset);
+			FD_SET(op->stream, FDSet);
       op = op->next;
       }
     }
@@ -1138,16 +1140,21 @@ int activereq(void)
   tv.tv_sec = 15;
 
   tv.tv_usec = 0;
-  num = select(FD_SETSIZE, &fdset, NULL, NULL, &tv);
+
+  num = select(MaxNumDescriptors, FDSet, NULL, NULL, &tv);
 
   if (num == -1)
     {
     pbs_errno = errno;
     DBPRT(("%s: select %d %s\n", id, pbs_errno, pbs_strerror(pbs_errno)))
+    free(FDSet);
     return -1;
     }
   else if (num == 0)
-    return -2;
+    {
+    free(FDSet);
+		return -2;
+    }
 
   for (i = 0; i < HASHOUT; i++)
     {
@@ -1158,13 +1165,17 @@ int activereq(void)
 
     while (op)
       {
-      if (FD_ISSET(op->stream, &fdset))
-        return op->stream;
+			if (FD_ISSET(op->stream, FDSet))
+        {
+        free(FDSet);
+				return op->stream;
+        }
 
       op = op->next;
       }
     }
 
+  free(FDSet);
   return(-2);
 
 #endif
