@@ -99,7 +99,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "credential.h"
 #include "batch_request.h"
@@ -110,7 +110,6 @@
 #include "pbs_error.h"
 #include "pbs_proto.h"
 #include "rpp.h"
-#include "resmon.h"
 #ifdef ENABLE_CPA
 #include "pbs_cpa.h"
 #endif
@@ -125,9 +124,9 @@
 /* External Globals */
 
 extern char  *path_epilog;
-extern char             *path_epiloguser;
-extern char             *path_epilogp;
-extern char             *path_epiloguserp;
+extern char  *path_epiloguser;
+extern char  *path_epilogp;
+extern char  *path_epiloguserp;
 extern char  *path_jobs;
 extern unsigned int default_server_port;
 extern tlist_head svr_alljobs, mom_polljobs;
@@ -139,12 +138,12 @@ extern struct connection svr_conn[];
 extern int  resc_access_perm;
 extern char  *path_aux;
 
-extern int              LOGLEVEL;
+extern int   LOGLEVEL;
 
-extern char            *PJobSubState[];
-extern char             mom_host[];
-extern int              PBSNodeCheckProlog;
-extern int              PBSNodeCheckEpilog;
+extern char  *PJobSubState[];
+extern char  mom_host[];
+extern int   PBSNodeCheckProlog;
+extern int   PBSNodeCheckEpilog;
 
 
 /* external prototypes */
@@ -161,16 +160,20 @@ extern int task_recov A_((job *));
 extern void mom_server_all_update_stat(void);
 extern void check_state(int);
 extern int mom_open_socket_to_jobs_server A_((job *, char *, void (*) A_((int))));
+extern int mark_for_resend A_((job *));
+extern void checkpoint_partial(job *pjob);
+extern void mom_checkpoint_recover(job *pjob);
+extern void clear_down_mom_servers();
+extern int is_mom_server_down(pbs_net_t);
+extern void set_mom_server_down(pbs_net_t);
+extern int no_mom_servers_down();
+extern char *get_local_script_path(job *pjob, char *base);
 
 
 /* END external prototypes */
 
-
-
-
-
 /*
- * catch_child() - the signal handler for  SIGCHLD.
+ * catch_child() - the signal handler for SIGCHLD.
  *
  * To keep the signal handler simple for
  * SIGCHLD  - just indicate there was one.
@@ -214,123 +217,6 @@ hnodent *get_node(
 
 
 
-#if MOM_CHECKPOINT == 1
-/*
-** Restart each task which has exited and has TI_FLAGS_CHKPT turned on.
-** If all tasks have been restarted, turn off MOM_CHKPT_POST.
-*/
-
-void chkpt_partial(
-
-  job *pjob)
-
-  {
-  static char id[] = "chkpt_partial";
-  int  i;
-  char  namebuf[MAXPATHLEN];
-  char  *filnam;
-  task  *ptask;
-  int  texit = 0;
-  extern char task_fmt[];
-  extern char *path_checkpoint;
-
-  assert(pjob != NULL);
-
-  strcpy(namebuf, path_checkpoint);
-  strcat(namebuf, pjob->ji_qs.ji_fileprefix);
-  strcat(namebuf, JOB_CKPT_SUFFIX);
-
-  i = strlen(namebuf);
-
-  filnam = &namebuf[i];
-
-  for (ptask = (task *)GET_NEXT(pjob->ji_tasks);
-       ptask != NULL;
-       ptask = (task *)GET_NEXT(ptask->ti_jobtask))
-    {
-    /*
-    ** See if the task was marked as one of those that did
-    ** actually checkpoint.
-    */
-
-    if ((ptask->ti_flags & TI_FLAGS_CHKPT) == 0)
-      continue;
-
-    texit++;
-
-    /*
-    ** Now see if it was reaped.  We don't want to
-    ** fool with it until we see it die.
-    */
-
-    if (ptask->ti_qs.ti_status != TI_STATE_EXITED)
-      continue;
-
-    texit--;
-
-    sprintf(filnam, task_fmt,
-            ptask->ti_qs.ti_task);
-
-    if (mach_restart(ptask, namebuf) == -1)
-      goto fail;
-
-    ptask->ti_qs.ti_status = TI_STATE_RUNNING;
-
-    ptask->ti_flags &= ~TI_FLAGS_CHKPT;
-
-    task_save(ptask);
-    }
-
-  if (texit == 0)
-    {
-    char        oldname[MAXPATHLEN];
-
-    struct stat statbuf;
-
-    /*
-    ** All tasks should now be running.
-    ** Turn off MOM_CHKPT_POST flag so job is back to where
-    ** it was before the bad checkpoint attempt.
-    */
-
-    pjob->ji_flags &= ~MOM_CHKPT_POST;
-
-    /*
-    ** Get rid of incomplete checkpoint directory and
-    ** move old chkpt dir back to regular if it exists.
-    */
-
-    *filnam = '\0';
-
-    remtree(namebuf);
-
-    strcpy(oldname, namebuf);
-
-    strcat(oldname, ".old");
-
-    if (stat(oldname, &statbuf) == 0)
-      {
-      if (rename(oldname, namebuf) == -1)
-        pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_CHKPT;
-      }
-    }
-
-  return;
-
-fail:
-  pjob->ji_flags &= ~MOM_CHKPT_POST;
-
-  kill_job(pjob, SIGKILL, id, "failed to restart");
-
-  return;
-  }  /* END chkpt_partial() */
-
-#endif /* MOM_CHECKPOINT */
-
-
-
-
-
 /**
  * For all jobs in MOM
  *   ignore job if job's pbs_server is down
@@ -427,13 +313,11 @@ scan_for_exiting(void)
   u_long getsize  A_((resource *));
   task         *task_find A_((job *, tm_task_id));
   int im_compose A_((int, char *, char *, int, tm_event_t, tm_task_id));
-  pbs_net_t   down_svraddrs[PBS_MAXSERVER] = {0, 0, 0, 0};
-  int    svr_index;
 
   static int ForceObit    = -1;   /* boolean - if TRUE, ObitsAllowed will be enforced */
   static int ObitsAllowed = 1;
-  int NumSisters = 0;
 
+  int NumSisters;
 
   /*
   ** Look through the jobs.  Each one has it's tasks examined
@@ -472,7 +356,9 @@ scan_for_exiting(void)
       {
       ForceObit = 1;
       }
-    }
+    }    /* END if (ForceObit == -1) */
+
+  clear_down_mom_servers();
 
   for (pjob = (job *)GET_NEXT(svr_alljobs);pjob != NULL;pjob = nxjob)
     {
@@ -482,48 +368,51 @@ scan_for_exiting(void)
      * Bypass job if it is for a server that we know is down
      */
 
-    for (svr_index = 0; svr_index < PBS_MAXSERVER; svr_index++)
+    if (is_mom_server_down(pjob->ji_qs.ji_un.ji_momt.ji_svraddr))
       {
-      if (down_svraddrs[svr_index] == 0)
+      if (LOGLEVEL >= 3)
         {
-        break;
+        snprintf(log_buffer, 1024, "not checking job %s - server is down",
+                 pjob->ji_qs.ji_jobid);
+
+        log_record(
+          PBSEVENT_DEBUG,
+          PBS_EVENTCLASS_SERVER,
+          id,
+          log_buffer);
         }
 
-      if (down_svraddrs[svr_index] == pjob->ji_qs.ji_un.ji_momt.ji_svraddr)
-        {
-        continue;
-        }
+      continue;
       }
 
-#if MOM_CHECKPOINT == 1
-
     /*
     ** If a checkpoint with aborts is active,
     ** skip it.  We don't want to report any obits
     ** until we know that the whole thing worked.
     */
 
-    if (pjob->ji_flags & MOM_CHKPT_ACTIVE)
+    if (pjob->ji_flags & MOM_CHECKPOINT_ACTIVE)
       {
       continue;
       }
 
     /*
     ** If the job has had an error doing a checkpoint with
-    ** abort, the MOM_CHKPT_POST flag will be on.
+    ** abort, the MOM_CHECKPOINT_POST flag will be on.
     */
 
-    if (pjob->ji_flags & MOM_CHKPT_POST)
+    if (pjob->ji_flags & MOM_CHECKPOINT_POST)
       {
-      chkpt_partial(pjob);
+      checkpoint_partial(pjob);
 
       continue;
       }
 
-#endif /* MOM_CHECKPOINT */
 
     if (!(pjob->ji_wattr[(int)JOB_ATR_Cookie].at_flags & ATR_VFLAG_SET))
+      {
       continue;
+      }
 
     cookie = pjob->ji_wattr[(int)JOB_ATR_Cookie].at_val.at_str;
 
@@ -559,7 +448,7 @@ scan_for_exiting(void)
 
         if (NumSisters == 0)
           {
-          /* no sisters contacted - is this SUCCESS or FAILURE? */
+          /* no sisters contacted - should be a serial job */
 
           if (LOGLEVEL >= 3)
             {
@@ -585,7 +474,7 @@ scan_for_exiting(void)
             pjob->ji_qs.ji_jobid,
             log_buffer);
           }
-        }    /* END for (ptask) */
+        }    /* END if (ptask->ti_qs.ti_parenttask == TM_NULL_TASK) */
 
       /*
       ** process any TM client obits waiting.
@@ -629,7 +518,8 @@ scan_for_exiting(void)
 
           im_compose(
             pnode->hn_stream,
-            pjob->ji_qs.ji_jobid, cookie,
+            pjob->ji_qs.ji_jobid,
+            cookie,
             IM_ALL_OKAY,
             pobit->oe_info.fe_event,
             pobit->oe_info.fe_taskid);
@@ -667,7 +557,7 @@ scan_for_exiting(void)
     ** in any state other than EXITING continue on.
     */
 
-    if ((pjob->ji_qs.ji_substate != JOB_SUBSTATE_EXITING) && (pjob->ji_qs.ji_substate != JOB_SUBSTATE_NOTERM_REQUE))
+    if (pjob->ji_qs.ji_substate != JOB_SUBSTATE_EXITING)
       {
       if (LOGLEVEL >= 3)
         {
@@ -708,8 +598,16 @@ scan_for_exiting(void)
 
       if (stream == -1)
         {
-        if(pjob->ji_qs.ji_substate != JOB_SUBSTATE_NOTERM_REQUE)
-          kill_job(pjob, SIGKILL, id, "connection to server lost - no obit sent");
+        if (LOGLEVEL >= 3)
+          {
+          LOG_EVENT(
+            PBSEVENT_JOB,
+            PBS_EVENTCLASS_JOB,
+            pjob->ji_qs.ji_jobid,
+            "connection to server lost - no obit sent - job will be purged");
+          }
+
+        kill_job(pjob, SIGKILL, id, "connection to server lost - no obit sent");
 
         job_purge(pjob);
 
@@ -768,6 +666,7 @@ scan_for_exiting(void)
       if ((pjob->ji_wattr[(int)JOB_ATR_interactive].at_flags & ATR_VFLAG_SET) &&
           pjob->ji_wattr[(int)JOB_ATR_interactive].at_val.at_long)
         {
+
         if (run_pelog(PE_EPILOGUSER, path_epiloguserp, pjob, PE_IO_TYPE_NULL) != 0)
           {
           log_err(-1, id, "user parallel epilog failed");
@@ -780,9 +679,10 @@ scan_for_exiting(void)
         }
       else
         {
+      
         if (run_pelog(PE_EPILOGUSER, path_epiloguserp, pjob, PE_IO_TYPE_STD) != 0)
           {
-          log_err(-1, id, "user parallel epilog failed");
+          log_err(-1, id, "parallel user epilog failed");
           }
 
         if (run_pelog(PE_EPILOG, path_epilogp, pjob, PE_IO_TYPE_STD) != 0)
@@ -835,10 +735,10 @@ scan_for_exiting(void)
      * At this point, we know we are Mother Superior for this
      * job which is EXITING.  Time for it to die.
      */
+
     pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_Suspend;
 
-    if(pjob->ji_qs.ji_substate != JOB_SUBSTATE_NOTERM_REQUE)
-      kill_job(pjob, SIGKILL, id, "local task termination detected");
+    kill_job(pjob, SIGKILL, id, "local task termination detected");
 
 #ifdef ENABLE_CPA
     if (CPADestroyPartition(pjob) != 0)
@@ -873,14 +773,7 @@ scan_for_exiting(void)
        * so Mom will retry Obit when server is available
        */
 
-      for (svr_index = 0; svr_index < PBS_MAXSERVER; svr_index++)
-        {
-        if (down_svraddrs[svr_index] == 0)
-          {
-          down_svraddrs[svr_index] = pjob->ji_qs.ji_un.ji_momt.ji_svraddr;
-          break;
-          }
-        }
+      set_mom_server_down(pjob->ji_qs.ji_un.ji_momt.ji_svraddr);
 
       continue;
       }  /* END if (sock < 0) */
@@ -914,10 +807,18 @@ scan_for_exiting(void)
 
     DIS_tcp_setup(sock);
 
-    if (encode_DIS_ReqHdr(sock, PBS_BATCH_StatusJob, pbs_current_user) ||
-        encode_DIS_Status(sock, pjob->ji_qs.ji_jobid, NULL) ||
-        encode_DIS_ReqExtend(sock, NULL))
+    if (tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_StatusJob, pbs_current_user) ||
+        tcp_encode_DIS_Status(sock, pjob->ji_qs.ji_jobid, NULL) ||
+        tcp_encode_DIS_ReqExtend(sock, NULL))
       {
+      /* FAILURE */
+
+      log_record(
+        PBSEVENT_DEBUG,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        "failed creating preobit message");
+
       return;
       }
 
@@ -931,7 +832,7 @@ scan_for_exiting(void)
       }
     }  /* END for (pjob) */
 
-  if ((pjob == NULL) && (down_svraddrs[0] == 0))
+  if ((pjob == NULL) && (no_mom_servers_down()))
     {
     /* search finished */
 
@@ -945,8 +846,15 @@ scan_for_exiting(void)
 
 
 
-/* called from scan_for_terminated() */
-/* sends obit to server */
+/**
+ * Send obit to server.
+ *
+ * @see scan_for_terminated() - calls post_epilog() via ji_mompost job attribute
+ * @see mom_open_socket_to_jobs_server() - child
+ * @see obit_reply() - registered handler for obit connection
+ *
+ * @see scan_for_exiting() for Obit overview
+ */
 
 int post_epilogue(
 
@@ -972,7 +880,7 @@ int post_epilogue(
       log_buffer);
     }
 
-  /* open new connection */
+  /* open new connection - register obit_reply as handler */
 
   sock = mom_open_socket_to_jobs_server(pjob, id, obit_reply);
 
@@ -1002,6 +910,7 @@ int post_epilogue(
        * every so often to send the obit.  This would work for recovered
        * jobs also.
        */
+      mark_for_resend(pjob);
 
       return(1);
       }
@@ -1041,9 +950,9 @@ int post_epilogue(
 
   DIS_tcp_setup(sock);
 
-  if (encode_DIS_ReqHdr(sock, PBS_BATCH_JobObit, pbs_current_user) ||
-      encode_DIS_JobObit(sock, preq) ||
-      encode_DIS_ReqExtend(sock, 0))
+  if (tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_JobObit, pbs_current_user) ||
+      tcp_encode_DIS_JobObit(sock, preq) ||
+      tcp_encode_DIS_ReqExtend(sock, 0))
     {
     /* FAILURE */
 
@@ -1067,7 +976,6 @@ int post_epilogue(
 
   free_br(preq);
 
-
   /* SUCCESS */
 
   /* Who closes sock and unsets pjob->ji_momhandle?
@@ -1087,11 +995,15 @@ int post_epilogue(
 
 
 
-/*
+/**
  * preobit_reply
  *
+ * @see scan_for_exiting() - registers this routine as handler
+ * @see mom_deljob() - child
+ * @see run_pelog() - child
+ *
  * This function is a message handler that is hooked to a server connection.
- * The connection is established in scan_for_exiting where all jobs
+ * The connection is established in scan_for_exiting() where all jobs
  * are examined.  A socket connection to the server is opened, an obit
  * message is sent to the server, and then at some later time, the server
  * sends back a reply and we end up here.
@@ -1118,6 +1030,9 @@ static void preobit_reply(
   int  deletejob = 0;
   int  jobiscorrupt = 0;
 
+  char *path_epiloguserjob;
+  resource *presc;
+
   /* struct batch_status *bsp = NULL; */
 
   log_record(
@@ -1334,10 +1249,9 @@ static void preobit_reply(
       int x; /* dummy */
 
       /* do this if not interactive */
-
-      job_unlink_file(pjob, std_file_name(pjob, StdOut, &x));
-      job_unlink_file(pjob, std_file_name(pjob, StdErr, &x));
-      job_unlink_file(pjob, std_file_name(pjob, Chkpt, &x));
+      unlink(std_file_name(pjob, StdOut, &x));
+      unlink(std_file_name(pjob, StdErr, &x));
+      unlink(std_file_name(pjob, Checkpoint, &x));
       }
 
     mom_deljob(pjob);
@@ -1368,19 +1282,39 @@ static void preobit_reply(
       PBSEVENT_DEBUG,
       PBS_EVENTCLASS_JOB,
       pjob->ji_qs.ji_jobid,
-      "performing job clean-up");
+      "performing job clean-up in preobit_reply()");
     }
 
   cpid = fork_me(-1);
 
+  if (cpid < 0)
+    {
+    /* FAILURE */
+
+    log_record(
+      PBSEVENT_DEBUG,
+      PBS_EVENTCLASS_JOB,
+      pjob->ji_qs.ji_jobid,
+      "fork failed in preobit_reply");
+
+    return;
+    }
+
   if (cpid > 0)
     {
-    /* parent = mark that it is being sent */
+    /* parent - mark that job epilog subtask has been launched */
 
-    if (LOGLEVEL >= 7)
+    /* NOTE:  pjob->ji_mompost will be executed in scan_for_terminated() */
+
+    pjob->ji_qs.ji_substate = JOB_SUBSTATE_OBIT;
+    pjob->ji_momsubt = cpid;
+    pjob->ji_mompost = post_epilogue;
+    pjob->ji_momhandle = -1;
+
+    if (LOGLEVEL >= 2)
       {
       snprintf(log_buffer, 1024, "epilog subtask created with pid %d - substate set to JOB_SUBSTATE_OBIT - registered post_epilogue",
-               (int)cpid);
+               cpid);
 
       log_record(
         PBSEVENT_DEBUG,
@@ -1389,19 +1323,6 @@ static void preobit_reply(
         log_buffer);
       }
 
-    pjob->ji_qs.ji_substate = JOB_SUBSTATE_OBIT;
-
-    pjob->ji_momsubt = cpid;
-    pjob->ji_mompost = post_epilogue;
-    pjob->ji_momhandle = -1;
-
-    return;
-    }
-
-  if (cpid < 0)
-    {
-    /* FAILURE */
-
     return;
     }
 
@@ -1414,6 +1335,24 @@ static void preobit_reply(
     {
     /* job is interactive */
 
+    presc = find_resc_entry(
+          &pjob->ji_wattr[(int)JOB_ATR_resource],
+          find_resc_def(svr_resc_def, "epilogue", svr_resc_size));
+    if((presc != NULL))
+      if((presc->rs_value.at_flags & ATR_VFLAG_SET) && (presc->rs_value.at_val.at_str != NULL))
+        {
+        path_epiloguserjob = get_local_script_path(pjob, presc->rs_value.at_val.at_str);
+        if(path_epiloguserjob)
+          {
+          if (run_pelog(PE_EPILOGUSERJOB, path_epiloguserjob, pjob, PE_IO_TYPE_NULL) != 0)
+            {
+            log_err(-1, id, "user local epilog failed");
+            }
+          free(path_epiloguserjob);
+          }
+        }
+
+
     if (run_pelog(PE_EPILOGUSER, path_epiloguser, pjob, PE_IO_TYPE_NULL) != 0)
       {
       log_err(-1, id, "user epilog failed - interactive job");
@@ -1430,6 +1369,25 @@ static void preobit_reply(
 
     int rc;
 
+    presc = find_resc_entry(
+          &pjob->ji_wattr[(int)JOB_ATR_resource],
+          find_resc_def(svr_resc_def, "epilogue", svr_resc_size));
+    if((presc != NULL))
+      if((presc->rs_value.at_flags & ATR_VFLAG_SET) && (presc->rs_value.at_val.at_str != NULL))
+        {
+        path_epiloguserjob = get_local_script_path(pjob, presc->rs_value.at_val.at_str);
+        
+        if(path_epiloguserjob)
+          {
+          if (run_pelog(PE_EPILOGUSERJOB, path_epiloguserjob, pjob, PE_IO_TYPE_STD) != 0)
+            {
+            log_err(-1, id, "user local epilog failed");
+            }
+          free(path_epiloguserjob);
+          }
+        
+        }
+
     if (run_pelog(PE_EPILOGUSER, path_epiloguser, pjob, PE_IO_TYPE_STD) != 0)
       {
       log_err(-1, id, "user epilog failed");
@@ -1450,15 +1408,20 @@ static void preobit_reply(
 
 
 
+
 /*
  * obit_reply
  *
  * This function is a message handler that is hooked to a server connection.
- * The connection is established in post_epilogue.
+ * The connection is established in post_epilogue().
+ *
  * A socket connection to the server is opened, a job obiturary notice
  * message is sent to the server, and then at some later time, the server
  * sends back a reply and we end up here.
  *
+ * On success, this routine sets the job's substate to EXITED
+ *
+ * @see post_epilogue() - registers obit_reply via add_conn()
  */
 
 
@@ -1520,19 +1483,19 @@ static void obit_reply(
 
           /* normal ack, mark job as exited */
 
-          if (LOGLEVEL >= 7)
-            {
-            log_record(
-              PBSEVENT_ERROR,
-              PBS_EVENTCLASS_JOB,
-              pjob->ji_qs.ji_jobid,
-              "setting job substate to EXITED");
-            }
-
           pjob->ji_qs.ji_substate = JOB_SUBSTATE_EXITED;
 
           job_save(pjob, SAVEJOB_QUICK);
 
+          if (LOGLEVEL >= 4)
+            {
+            LOG_EVENT(
+              PBSEVENT_ERROR,
+              PBS_EVENTCLASS_JOB,
+              pjob->ji_qs.ji_jobid,
+              "job obit acknowledge received - substate set to JOB_SUBSTATE_EXITED");
+            }
+
           break;
 
         case PBSE_ALRDYEXIT:
@@ -1566,9 +1529,9 @@ static void obit_reply(
             {
             /* do this if not interactive */
 
-            job_unlink_file(pjob, std_file_name(pjob, StdOut, &x));
-            job_unlink_file(pjob, std_file_name(pjob, StdErr, &x));
-            job_unlink_file(pjob, std_file_name(pjob, Chkpt, &x));
+            unlink(std_file_name(pjob, StdOut, &x));
+            unlink(std_file_name(pjob, StdErr, &x));
+            unlink(std_file_name(pjob, Checkpoint, &x));
             }
 
           mom_deljob(pjob);
@@ -1666,7 +1629,7 @@ static void obit_reply(
  * init_abort_jobs - on mom initialization, recover all running jobs.
  *
  * Called on initialization
- *    If the -p option was given (recover = 2), Mom will allow the jobs
+ *    If the -p option was given (default) (recover = 2), Mom will allow the jobs
  *    to continue to run.   She depends on detecting when they terminate
  *    via the slow poll method rather than SIGCHLD.
  *
@@ -1674,8 +1637,8 @@ static void obit_reply(
  *      running system and the session id of the jobs should be valid;
  *    the jobs are killed.
  *
- *    If -r was not given (recover = 0), it is assumed that the whole
- *    system, not just MOM, is comming up, the session ids are not valid;
+ *    If -q was given (recover = 0), it is assumed that the whole
+ *    system, not just MOM, is coming up, the session ids are not valid;
  *    so no attempt is made to kill the job processes.  But the jobs are
  *    terminated and requeued.
  */
@@ -1697,12 +1660,6 @@ void init_abort_jobs(
   char  *job_suffix = JOB_FILE_SUFFIX;
   int            job_suf_len = strlen(job_suffix);
   char  *psuffix;
-#if MOM_CHECKPOINT == 1
-  char           path[MAXPATHLEN + 1];
-  char           oldp[MAXPATHLEN + 1];
-  /*  struct stat    statbuf; */
-  extern char   *path_checkpoint;
-#endif
 
   if (LOGLEVEL >= 6)
     {
@@ -1783,40 +1740,8 @@ void init_abort_jobs(
         log_buffer);
       }
 
-#if MOM_CHECKPOINT == 1
-    /*
-    ** Check to see if a checkpoint.old dir exists.
-    ** If so, remove the regular checkpoint dir
-    ** and rename the old to the regular name.
-    */
 
-    strcpy(path, path_checkpoint);
-
-    strcat(path, pj->ji_qs.ji_fileprefix);
-
-    strcat(path, JOB_CKPT_SUFFIX);
-
-    strcpy(oldp, path);
-
-    strcat(oldp, ".old");
-
-#if 0
-    /*
-     * This is if 0'ed.
-     * If the directory exists it is fine.
-     * Checkpoint names have a time suffix and can occupy
-     * the same directory space.
-     */
-    if (stat(oldp, &statbuf) == 0)
-      {
-      remtree(path);
-
-      if (rename(oldp, path) == -1)
-        remtree(oldp);
-      }
-
-#endif
-#endif  /* END MOM_CHECKPOINT == 1 */
+    mom_checkpoint_recover(pj);
 
     /*
      * make sure we trust connections from sisters in case we get an
@@ -1859,7 +1784,6 @@ void init_abort_jobs(
          (pj->ji_qs.ji_substate == JOB_SUBSTATE_PRERUN) ||
          (pj->ji_qs.ji_substate == JOB_SUBSTATE_SUSPEND) ||
          (pj->ji_qs.ji_substate == JOB_SUBSTATE_EXITED) ||
-         (pj->ji_qs.ji_substate == JOB_SUBSTATE_NOTERM_REQUE) ||
          (pj->ji_qs.ji_substate == JOB_SUBSTATE_EXITING)))
       {
       if (LOGLEVEL >= 2)
@@ -1922,13 +1846,13 @@ void init_abort_jobs(
         }
 
       /* set exit status to:
-       *   JOB_EXEC_INITABT - init abort and no chkpt
-       *   JOB_EXEC_INITRST - init and chkpt, no mig
-       *   JOB_EXEC_INITRMG - init and chkpt, migrate
+       *   JOB_EXEC_INITABT - init abort and no checkpoint
+       *   JOB_EXEC_INITRST - init and checkpoint, no mig
+       *   JOB_EXEC_INITRMG - init and checkpoint, migrate
        * to indicate recovery abort
        */
 
-      if (pj->ji_qs.ji_svrflags & (JOB_SVFLG_CHKPT | JOB_SVFLG_ChkptMig))
+      if (pj->ji_qs.ji_svrflags & (JOB_SVFLG_CHECKPOINT_FILE | JOB_SVFLG_CHECKPOINT_MIGRATEABLE))
         {
 #if PBS_CHKPT_MIGRATE
 
@@ -1959,10 +1883,7 @@ void init_abort_jobs(
         continue;
         }
 
-      /* If mom was initialized with a -r any running processes have already
-         been killed. We set substate to JOB_SUBSTATE_NOTERM_REQUE so scan_for_exiting
-         will not try to kill the running processes for this job */
-      pj->ji_qs.ji_substate = JOB_SUBSTATE_NOTERM_REQUE;
+      pj->ji_qs.ji_substate = JOB_SUBSTATE_EXITING;
 
       job_save(pj, SAVEJOB_QUICK);
 
