@@ -20,17 +20,6 @@
 * are permitted provided that all of the following conditions are met.
 * After December 31, 2001, only conditions 3-6 must be met:
 *
-* 1. Commercial and/or non-commercial use of the Software is permitted
-*    provided a current software registration is on file at www.OpenPBS.org.
-*    If use of this software contributes to a publication, product, or
-*    service, proper attribution must be given; see www.OpenPBS.org/credit.html
-*
-* 2. Redistribution in any form is only permitted for non-commercial,
-*    non-profit purposes.  There can be no charge for the Software or any
-*    software incorporating the Software.  Further, there can be no
-*    expectation of revenue generated as a consequence of redistributing
-*    the Software.
-*
 * 3. Any Redistribution of source code must retain the above copyright notice
 *    and the acknowledgment contained in paragraph 6, this list of conditions
 *    and the disclaimer contained in paragraph 7.
@@ -105,6 +94,7 @@
 #include <syscall.h>
 #include <ctype.h>
 #include <string.h>
+#include <csv.h>
 
 #ifdef Q_6_5_QUOTAON
 /* remap dqblk for SUSE 9.0 */
@@ -124,7 +114,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "mom_func.h"
@@ -169,12 +159,9 @@ extern char *ret_string;
 extern char extra_parm[];
 extern char no_parm[];
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern  int     LOGLEVEL;
-extern  char    checkpoint_script_name[1024];
-extern  char    restart_script_name[1024];
 extern  char    PBSNodeMsgBuf[1024];
 
 #define TBL_INC 200            /* initial proc table */
@@ -186,28 +173,34 @@ static int            max_proc = 0;
 /*
 ** external functions and data
 */
-
-extern struct config  *search A_((struct config *, char *));
-
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct	config		*search A_((struct config *,char *));
+extern struct	rm_attribute	*momgetattr A_((char *));
 extern int                      rm_errno;
-extern double cputfactor;
-extern double wallfactor;
-extern long system_ncpus;
-extern  int     ignwalltime;
-extern  int     ignvmem;
+extern double	cputfactor;
+extern double	wallfactor;
+extern long     system_ncpus;
+extern int      ignwalltime;
+extern int      igncput;
+extern int      ignvmem;
+extern int      ignmem;
 
 /*
 ** local functions and data
 */
-static char *resi  A_((struct rm_attribute *));
-static char *totmem  A_((struct rm_attribute *));
+static char *resi     A_((struct rm_attribute *));
+static char *totmem   A_((struct rm_attribute *));
 static char *availmem A_((struct rm_attribute *));
-static char *physmem A_((struct rm_attribute *));
-static char *ncpus  A_((struct rm_attribute *));
+static char *physmem  A_((struct rm_attribute *));
+static char *ncpus    A_((struct rm_attribute *));
 static char *walltime A_((struct rm_attribute *));
-static char *quota  A_((struct rm_attribute *));
-static char     *netload        A_((struct rm_attribute *));
+static char *quota    A_((struct rm_attribute *));
+static char *netload  A_((struct rm_attribute *));
+
+#ifndef mbool_t
+#define mbool_t char
+#endif /* mbool_t */
+
+mbool_t ProcIsChild(char *,char *,char *);
 
 extern char *loadave A_((struct rm_attribute *));
 extern char *nullproc A_((struct rm_attribute *));
@@ -389,7 +382,7 @@ proc_stat_t *get_proc_stat(
 
   lastbracket++;
 
-  if (sscanf(readbuf, "%d (%[^\n]", &ps.pid, path) != 2)
+  if (sscanf(readbuf,"%d (%[^\n]",&ps.pid,path) != 2) 
     {
     /* FAILURE */
 
@@ -399,19 +392,20 @@ proc_stat_t *get_proc_stat(
     }
 
   /* see stat_str[] value for mapping 'stat' format */
-  if (sscanf(lastbracket, stat_str,
-             &ps.state,     /* state (one of RSDZTW) */
-             &ps.ppid,      /* ppid */
-             &ps.pgrp,      /* pgrp */
-             &ps.session,   /* session id */
-             &ps.flags,     /* flags - kernel flags of the process, see the PF_* in <linux/sched.h> */
-             &ps.utime,     /* utime - jiffies that this process has been scheduled in user mode */
-             &ps.stime,     /* stime - jiffies that this process has been scheduled in kernel mode */
-             &ps.cutime,    /* cutime - jiffies that this process’s waited-for children have been scheduled in user mode */
-             &ps.cstime,    /* cstime - jiffies that this process’s waited-for children have been scheduled in kernel mode */
-             &jstarttime,   /* starttime */
-             &ps.vsize,     /* vsize */
-             &ps.rss) != 12)   /* rss */
+
+  if (sscanf(lastbracket,stat_str, 
+        &ps.state,     /* state (one of RSDZTW) */
+        &ps.ppid,      /* ppid */
+        &ps.pgrp,      /* pgrp */
+        &ps.session,   /* session id */
+        &ps.flags,     /* flags - kernel flags of the process, see the PF_* in <linux/sched.h> */
+        &ps.utime,     /* utime - jiffies that this process has been scheduled in user mode */
+        &ps.stime,     /* stime - jiffies that this process has been scheduled in kernel mode */
+        &ps.cutime,    /* cutime - jiffies that this process’s waited-for children have been scheduled in user mode */
+        &ps.cstime,    /* cstime - jiffies that this process’s waited-for children have been scheduled in kernel mode */
+        &jstarttime,   /* starttime */
+        &ps.vsize,     /* vsize */
+        &ps.rss) != 12)   /* rss */
     {
     /* FAILURE */
 
@@ -1078,28 +1072,14 @@ int error(
   int   value)
 
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);  /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   fprintf(stderr, msg_momsetlim, string, message);
@@ -1204,59 +1184,64 @@ int mom_set_limits(
 
     if (!strcmp(pname, "cput"))
       {
-      /* cpu time - check, if less than pcput use it */
-
-      retval = gettime(pres, &value);
-
-      if (retval != PBSE_NONE)
+      if (igncput == FALSE)
         {
-        sprintf(log_buffer, "cput gettime failed in %s",
-                id);
-
-        return(error(pname, retval));
-        }
-      }
-    else if (!strcmp(pname, "pcput"))
-      {
-      if (set_mode == SET_LIMIT_SET)
-        {
-        /* process cpu time - set */
+        /* cpu time - check, if less than pcput use it */
 
         retval = gettime(pres, &value);
 
         if (retval != PBSE_NONE)
           {
-          sprintf(log_buffer, "pcput gettime failed in %s",
-                  id);
+          sprintf(log_buffer, "cput gettime failed in %s",id);
 
           return(error(pname, retval));
           }
-
-        reslim.rlim_cur = reslim.rlim_max = (unsigned long)((double)value / cputfactor);
-
-        if (LOGLEVEL >= 2)
+        }
+      }
+    else if (!strcmp(pname, "pcput"))
+      {
+      if (igncput == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
           {
-          sprintf(log_buffer, "setting cpu time limit to %ld for job %s",
-                  (long int)reslim.rlim_cur,
-                  pjob->ji_qs.ji_jobid);
+          /* process cpu time - set */
 
-          log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
+          retval = gettime(pres, &value);
 
-          log_buffer[0] = '\0';
-          }
+          if (retval != PBSE_NONE)
+            {
+            sprintf(log_buffer, "pcput gettime failed in %s",id);
 
-        /* NOTE: some versions of linux have a bug which causes the parent
-                 process to receive a SIGKILL if the child's cpu limit is exceeded */
+            return(error(pname, retval));
+            }
 
-        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-          {
-          sprintf(log_buffer, "setrlimit for RLIMIT_CPU failed in %s, errno=%d (%s)",
-                  id,
-                  errno, strerror(errno));
+          reslim.rlim_cur = reslim.rlim_max =
+            (unsigned long)((double)value / cputfactor);
 
-          return(error("RLIMIT_CPU", PBSE_SYSTEM));
-          }
-        }    /* END if (set_mode == SET_LIMIT_SET) */
+          if (LOGLEVEL >= 2)
+            {
+            sprintf(log_buffer, "setting cpu time limit to %ld for job %s",
+              (long int)reslim.rlim_cur,
+              pjob->ji_qs.ji_jobid);
+
+            log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
+
+            log_buffer[0] = '\0';
+            }
+
+          /* NOTE: some versions of linux have a bug which causes the parent
+                   process to receive a SIGKILL if the child's cpu limit is exceeded */
+
+          if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+            {
+            sprintf(log_buffer, "setrlimit for RLIMIT_CPU failed in %s, errno=%d (%s)",
+              id,
+              errno, strerror(errno));
+
+            return(error("RLIMIT_CPU", PBSE_SYSTEM));
+            }
+          }    /* END if (set_mode == SET_LIMIT_SET) */
+        }
       }
     else if (!strcmp(pname, "file"))
       {
@@ -1308,53 +1293,58 @@ int mom_set_limits(
       }
     else if (!strcmp(pname, "vmem"))
       {
-      /* check */
-
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
+      if (ignvmem == FALSE)
         {
-        sprintf(log_buffer, "getsize() failed for vmem in %s",
-                id);
+        /* check */
 
-        return(error(pname, retval));
-        }
-
-      if ((vmem_limit == 0) || (value < vmem_limit))
-        vmem_limit = value;
-      }
-    else if (!strcmp(pname, "pvmem"))
-      {
-      /* set */
-
-      if (set_mode == SET_LIMIT_SET)
-        {
         retval = getsize(pres, &value);
 
         if (retval != PBSE_NONE)
           {
-          sprintf(log_buffer, "getsize() failed for pvmem in %s",
-                  id);
+          sprintf(log_buffer, "getsize() failed for vmem in %s",id);
 
           return(error(pname, retval));
           }
 
-        if (value > ULONG_MAX)
-          {
-          log_buffer[0] = '\0';
-
-          sprintf(log_buffer, "invalid value returned by getsize() for pvmem in %s",
-                  id);
-
-          return(error(pname, PBSE_BADATVAL));
-          }
-
         if ((vmem_limit == 0) || (value < vmem_limit))
           vmem_limit = value;
         }
       }
-    else if ((!strcmp(pname, "mem") && (pjob->ji_numnodes != 1)) ||
-             !strcmp(pname, "mppmem"))
+    else if (!strcmp(pname, "pvmem"))
+      {
+      if (ignvmem == FALSE)
+        {
+        /* set */
+
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            {
+            sprintf(log_buffer, "getsize() failed for pvmem in %s",
+              id);
+
+            return(error(pname, retval));
+            }
+
+          if (value > ULONG_MAX)
+            {
+            log_buffer[0] = '\0';
+
+            sprintf(log_buffer, "invalid value returned by getsize() for pvmem in %s",
+              id);
+
+            return(error(pname, PBSE_BADATVAL));
+            }
+
+          if ((vmem_limit == 0) || (value < vmem_limit))
+            vmem_limit = value;
+          }
+        }
+      }
+    else if ((!strcmp(pname,"mem") && (pjob->ji_numnodes != 1)) ||
+              !strcmp(pname,"mppmem"))
       {
       /* ignore. If we ever get rid of support for the UNICOS OS then we can
          remove the ATR_DFLAG_MOM | ATR_DFLAG_ALTRUN flags from mppmem */
@@ -1362,80 +1352,83 @@ int mom_set_limits(
     else if ((!strcmp(pname, "mem") && (pjob->ji_numnodes == 1)) ||
              !strcmp(pname, "pmem"))
       {
-      /* set */
-
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
         {
-        retval = getsize(pres, &value);
+        /* set */
 
-        if (retval != PBSE_NONE)
+        if (set_mode == SET_LIMIT_SET)
           {
-          sprintf(log_buffer, "getsize() failed for mem/pmem in %s",
-                  id);
+          retval = getsize(pres, &value);
 
-          return(error(pname, retval));
-          }
+          if (retval != PBSE_NONE)
+            {
+            sprintf(log_buffer, "getsize() failed for mem/pmem in %s",
+              id);
 
-        reslim.rlim_cur = reslim.rlim_max = value;
+            return(error(pname, retval));
+            }
 
-        if (setrlimit(RLIMIT_DATA, &reslim) < 0)
-          {
-          sprintf(log_buffer, "cannot set data limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
-                  reslim.rlim_max,
-                  pjob->ji_qs.ji_jobid,
-                  errno,
-                  strerror(errno));
+          reslim.rlim_cur = reslim.rlim_max = value;
 
-          return(error("RLIMIT_DATA", PBSE_SYSTEM));
-          }
+          if (setrlimit(RLIMIT_DATA, &reslim) < 0)
+            {
+            sprintf(log_buffer, "cannot set data limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
+              (long int)reslim.rlim_max,
+              pjob->ji_qs.ji_jobid,
+              errno,
+              strerror(errno));
 
-        if (setrlimit(RLIMIT_RSS, &reslim) < 0)
-          {
-          sprintf(log_buffer, "cannot set RSS limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
-                  reslim.rlim_max,
-                  pjob->ji_qs.ji_jobid,
-                  errno,
-                  strerror(errno));
+            return(error("RLIMIT_DATA", PBSE_SYSTEM));
+            }
 
-          return(error("RLIMIT_RSS", PBSE_SYSTEM));
-          }
+          if (setrlimit(RLIMIT_RSS, &reslim) < 0)
+            {
+            sprintf(log_buffer, "cannot set RSS limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
+              (long int)reslim.rlim_max,
+              pjob->ji_qs.ji_jobid,
+              errno,
+              strerror(errno));
+
+            return(error("RLIMIT_RSS", PBSE_SYSTEM));
+            }
 
 #ifdef __GATECH
-        /* NOTE:  best patch may be to change to 'vmem_limit = value;' */
+          /* NOTE:  best patch may be to change to 'vmem_limit = value;' */
 
-        if (setrlimit(RLIMIT_STACK, &reslim) < 0)
-          {
-          sprintf(log_buffer, "cannot set stack limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
-                  reslim.rlim_max,
-                  pjob->ji_qs.ji_jobid,
-                  errno,
-                  strerror(errno));
+          if (setrlimit(RLIMIT_STACK, &reslim) < 0)
+            {
+            sprintf(log_buffer, "cannot set stack limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
+              (long int)reslim.rlim_max,
+              pjob->ji_qs.ji_jobid,
+              errno,
+              strerror(errno));
 
-          return(error("RLIMIT_STACK", PBSE_SYSTEM));
-          }
+            return(error("RLIMIT_STACK", PBSE_SYSTEM));
+            }
 
-        /* set address space */
+          /* set address space */
 
-        if (setrlimit(RLIMIT_AS, &reslim) < 0)
-          {
-          sprintf(log_buffer, "cannot set AS limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
-                  reslim.rlim_max,
-                  pjob->ji_qs.ji_jobid,
-                  errno,
-                  strerror(errno));
+          if (setrlimit(RLIMIT_AS, &reslim) < 0)
+            {
+            sprintf(log_buffer, "cannot set AS limit to %ld for job %s (setrlimit failed w/errno=%d (%s) - check default user limits)",
+              (long int)reslim.rlim_max,
+              pjob->ji_qs.ji_jobid,
+              errno,
+              strerror(errno));
 
-          return(error("RLIMIT_AS", PBSE_SYSTEM));
-          }
+            return(error("RLIMIT_AS", PBSE_SYSTEM));
+            }
 
 #endif /* __GATECH */
 
-        mem_limit = value;
+          mem_limit = value;
+  
+          if (getrlimit(RLIMIT_STACK, &reslim) >= 0)
+            {
+            /* NOTE:  mem_limit no longer used with UMU patch in place */
 
-        if (getrlimit(RLIMIT_STACK, &reslim) >= 0)
-          {
-          /* NOTE:  mem_limit no longer used with UMU patch in place */
-
-          mem_limit = value + reslim.rlim_cur;
+            mem_limit = value + reslim.rlim_cur;
+            }
           }
         }
       }    /* END else if (!strcmp(pname,"mem") && ... */
@@ -1478,6 +1471,12 @@ int mom_set_limits(
 
       /* NO-OP */
       }
+    else if(!strcmp(pname, "prologue"))
+      {
+      }
+    else if(!strcmp(pname, "epilogue"))
+      {
+      }
     else if ((pres->rs_defin->rs_flags & ATR_DFLAG_RMOMIG) == 0)
       {
       /* don't recognize and not marked as ignore by mom */
@@ -1658,7 +1657,6 @@ mom_open_poll(void)
 
 
 
-
 /*
  * Declare start of polling loop.
  *
@@ -1672,7 +1670,7 @@ mom_open_poll(void)
  * This function is called from the main MOM loop once every "check_poll_interval"
  * seconds.
  *
- * @see get_proc_stat()
+ * @see get_proc_stat() - child
  * @see mom_set_use() - Aggregates data collected here
  *
  * NOTE:  populates global 'proc_array[]' variable.
@@ -1807,7 +1805,7 @@ int mom_over_limit(
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1823,7 +1821,7 @@ int mom_over_limit(
         return(TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "pcput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -1873,10 +1871,10 @@ int mom_over_limit(
         return(TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
-      /* no need to check walltime on sisters, MS will get it */
 
+      /* no need to check walltime on sisters, MS will get it */
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
 
@@ -1894,10 +1892,7 @@ int mom_over_limit(
                 num,
                 value);
 
-        if (ignwalltime == 0)
-          {
-          return(TRUE);
-          }
+        return(TRUE);
         }
       }
     }  /* END for (pres) */
@@ -1921,12 +1916,12 @@ int mom_over_limit(
  * stats gathered by the mom_get_sample() function. This function
  * is often called by "im_request()" as a result of POLL_JOB query
  * from the mother superior.
- *
- * @return An error code if something goes wrong.
- *
+ * 
  * @see im_request() - parent - respond to poll_job request from mother superior
  * @see examine_all_running_jobs() - parent - update local use on mother superior
  * @see TMomFinalizeJob1() - parent - update serial job immediately at job start
+ *
+ * @return An error code if something goes wrong.
  */
 
 int mom_set_use(
@@ -2033,7 +2028,6 @@ int mom_set_use(
   assert(pres != NULL);
 
   /* NOTE: starting jobs can come through here before stime is recorded */
-
   if (pjob->ji_qs.ji_stime == 0)
     pres->rs_value.at_val.at_long = 0;
   else
@@ -2063,15 +2057,18 @@ int mom_set_use(
 
 
 
-/*
+/**
  * Kill a task session.
  * Call with the task pointer and a signal number.
- *   return number of tasks signalled (0 = failure)
+ *
+ * @return number of tasks signalled (0 = failure) 
+ *
+ * @see kill_job() - parent
+ *
+ * NOTE:  should support killpg() or killpidtree() - (NYI)
+ *        may be required for suspend/resume 
  */
 
-/* NOTE:  should support killpg() or killpidtree() (NYI)
-          may be required for suspend resume */
-
 int kill_task(
 
   task *ptask,  /* I */
@@ -2085,7 +2082,7 @@ int kill_task(
   int            NumProcessesFound = 0; /* number of processes found with session ID */
 
   struct dirent *dent;
-  proc_stat_t *ps;
+  proc_stat_t   *ps;
   int            sesid;
   pid_t          mompid;
 
@@ -2095,10 +2092,10 @@ int kill_task(
   if (LOGLEVEL >= 5)
     {
     sprintf(log_buffer, "%s: sending signal %d to task %d, session %d",
-            id,
-            sig,
-            ptask->ti_qs.ti_task,
-            sesid);
+      id,
+      sig,
+      ptask->ti_qs.ti_task,
+      sesid);
 
     log_record(
       PBSEVENT_JOB,
@@ -2112,7 +2109,7 @@ int kill_task(
     if (LOGLEVEL >= 3)
       {
       sprintf(log_buffer, "cannot send signal %d to task (no session id)",
-              sig);
+        sig);
 
       log_record(
         PBSEVENT_ERROR,
@@ -2146,13 +2143,15 @@ int kill_task(
         sprintf(log_buffer, "%s: get_proc_stat",
                 dent->d_name);
 
-        log_err(errno, id, log_buffer);
+        log_err(errno,id,log_buffer);
         }
 
       continue;
       }
 
-    if (sesid == ps->session)
+    if ((sesid == ps->session) ||
+        (ProcIsChild(procfs,dent->d_name,ptask->ti_job->ji_qs.ji_jobid) == TRUE))
+
       {
       NumProcessesFound++;
 
@@ -2201,6 +2200,17 @@ int kill_task(
               log_buffer);
             }
 
+          if (LOGLEVEL >= 3)
+            {
+            sprintf(log_buffer, "%s: not killing process %d. Avoid sending signal because child task still has MOM's session id", id, ps->pid);
+
+            log_record(
+              PBSEVENT_JOB,
+              PBS_EVENTCLASS_JOB,
+              ptask->ti_job->ji_qs.ji_jobid,
+              log_buffer);
+            }
+
           continue;
           }  /* END if (ps->pid == mompid) */
 
@@ -2211,7 +2221,7 @@ int kill_task(
           req.tv_sec = 0;
           req.tv_nsec = 250000000;  /* .25 seconds */
 
-          /* give the process some time to quit gracefully first (up to 5 seconds) */
+          /* give the process some time to quit gracefully first (up to .25*20=5 seconds) */
 
           sprintf(log_buffer, "%s: killing pid %d task %d gracefully with sig %d",
                   id,
@@ -2277,6 +2287,8 @@ int kill_task(
               {
               /* kill process hard */
 
+              /* why is this not killing with SIGKILL? */
+
               sprintf(log_buffer, "%s: killing pid %d task %d with sig %d",
                       id,
                       ps->pid,
@@ -2294,14 +2306,17 @@ int kill_task(
               else
                 killpg(ps->pid, sig);
               }
-            }
-          }    /* END if (i >= 20) */
+            }    /* END if ((ps = get_proc_stat(ps->pid)) != NULL) */
+          }      /* END if (i >= 20) */
 
         ++ct;
         }  /* END else ((ps->state == 'Z') || (ps->pid == 0)) */
       }    /* END if (sesid == ps->session) */
     }      /* END while ((dent = readdir(pdir)) != NULL) */
 
+  /* NOTE:  to fix bad state situations resulting from a hard crash, the logic
+            below should be triggered any time no processes are found (NYI) */ 
+            
   if (IS_ADOPTED_TASK(ptask->ti_qs.ti_task) && (NumProcessesFound == 0))
     {
     /* no process was found, but for an adopted task this is OK (we don't find
@@ -2412,22 +2427,16 @@ mom_close_poll(void)
 
 
 
-
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
+ *
+ * @returns CST values as described in resmon.h.
  */
 
 int
-mom_does_chkpnt(void)
-
+mom_does_checkpoint(void)
   {
-  if (checkpoint_script_name[0] != '\0')
-    {
-    return(1);
-    }
-
-  return(0);
+  return(CST_BLCR); /* Use the BLCR checkpointing system. */
   }
 
 /*
@@ -2438,76 +2447,11 @@ mom_does_chkpnt(void)
 
 int mach_checkpoint(
 
-  task *ptask,
-  char *file,
+  task *ptask,  /* I */
+  char *file,  /* I */
   int  abort)  /* I */
 
   {
-  char *id = "mach_checkpoint";
-  int   pid;
-  char  sid[20];
-  char  *arg[20];
-  char  buf[1024];
-  char  **ap;
-
-#define SET_ARG(x) (((x) == NULL) || (*(x) == 0))?"-":(x)
-
-  /* if a checkpoint script is defined launch it */
-
-  if (checkpoint_script_name[0] == '\0')
-    {
-    log_err(-1, id, "No checkpoint script defined");
-    }
-  else
-    {
-    /* launch the script and return success */
-
-    pid = fork();
-
-    if (pid > 0)
-      {
-      /* parent: pid = child's pid */
-
-      /* NO-OP, but may need to waitpid() the child (NYI) */
-
-      return(0);
-      }
-    else if (pid == 0)
-      {
-      /* child: execv the script */
-
-      sprintf(sid, "%ld",
-              ptask->ti_job->ji_wattr[(int)JOB_ATR_session_id].at_val.at_long);
-
-      arg[0] = checkpoint_script_name;
-      arg[1] = sid;
-      arg[2] = SET_ARG(ptask->ti_job->ji_qs.ji_jobid);
-      arg[3] = SET_ARG(ptask->ti_job->ji_wattr[(int)JOB_ATR_euser].at_val.at_str);
-      arg[4] = SET_ARG(ptask->ti_job->ji_wattr[(int)JOB_ATR_chkptdir].at_val.at_str);
-      arg[5] = SET_ARG(ptask->ti_job->ji_wattr[(int)JOB_ATR_chkptname].at_val.at_str);
-      arg[6] = (abort) ? "15" /*abort*/ : "0" /*run/continue*/;
-      arg[7] = NULL;
-
-      strcpy(buf, "checkpoint args:");
-
-      for (ap = arg; *ap; ap++)
-        {
-        strcat(buf, " ");
-        strcat(buf, *ap);
-        }
-
-      log_err(-1, id, buf);
-
-      execv(arg[0], arg);
-
-      /* NOTE: The right way to do this is to put the job into some sort
-       *       of waiting state before returning, and the monitor the
-       *       the child to see what it's exit status is.  We are delaying
-       *       the full implementation for now.  NYI
-       */
-      }  /* END if (pid == 0) */
-    }
-
   return(-1);
   }  /* END mach_checkpoint() */
 
@@ -2527,57 +2471,6 @@ long mach_restart(
   char *file)
 
   {
-  char *id = "mach_restart";
-  int   pid;
-  char  sid[20];
-  char  *arg[20];
-
-
-  /* if a restart script is defined launch it */
-
-  if (restart_script_name[0] == '\0')
-    {
-    log_record(PBSEVENT_DEBUG, 0, id, "No restart script defined");
-    }
-  else
-    {
-    /* launch the script and return success */
-
-    pid = fork();
-
-    if (pid > 0)
-      {
-      /* parent: pid = child's pid */
-
-      /* NO-OP, but may need to waitpid() the child (NYI) */
-
-      return(0);
-      }
-
-    if (pid == 0)
-      {
-      /* child: execv the script */
-
-      sprintf(sid, "%ld",
-              ptask->ti_job->ji_wattr[(int)JOB_ATR_session_id].at_val.at_long);
-
-      arg[0] = restart_script_name;
-      arg[1] = sid;
-      arg[2] = ptask->ti_job->ji_qs.ji_jobid;
-      arg[3] = ptask->ti_job->ji_wattr[(int)JOB_ATR_euser].at_val.at_str;
-      arg[4] = NULL;
-
-      execv(arg[0], arg);
-
-      /* NOTE: The right way to do this is to put the job into some sort
-       *       of waiting state before returning, and the monitor the
-       *       the child to see what it's exit status is.  We are delaying
-       *       the full implementation for now.  NYI
-       */
-      }  /* END if (pid == 0) */
-    }
-
-
   return(-1);
   }
 
@@ -2643,7 +2536,8 @@ char *cput_job(
     }
 
   sprintf(ret_string, "%.2f",
-    cputime * cputfactor);
+
+          cputime * cputfactor);
 
   return(ret_string);
   }  /* END cput_job() */
@@ -2944,7 +2838,7 @@ static char *resi_proc(
   pid_t pid)
 
   {
-  char  *id = "resi_proc";
+  char        *id = "resi_proc";
   proc_stat_t *ps;
 
   if ((ps = get_proc_stat(pid)) == NULL)
@@ -3074,7 +2968,7 @@ char *sessions(
     if ((jobid = ps->session) == 0)
       continue;
 
-    if (LOGLEVEL >= 7)
+    if (LOGLEVEL >= 6)
       {
       sprintf(log_buffer, "%s[%d]: pid %d sid %d",
               id,
@@ -3247,7 +3141,7 @@ char *pids(
     {
     ps = &proc_array[i];
 
-    if (LOGLEVEL >= 7)
+    if (LOGLEVEL >= 6)
       {
       DBPRT(("%s[%d]: pid: %d  sid: %d\n",
              id,
@@ -3320,7 +3214,7 @@ char *nusers(
     if ((uid = ps->uid) == 0)
       continue;
 
-    if (LOGLEVEL >= 7)
+    if (LOGLEVEL >= 6)
       {
       sprintf(log_buffer, "%s[%d]: pid %d uid %d",
               id,
@@ -4468,8 +4362,8 @@ static char *netload(
       /*
       if (strncmp(interfaceName[interface],"eth",3) == 0)
         {
-          rc = sscanf(interfaceName[interface],"eth%d",
-            &ethNum);
+        rc = sscanf(interfaceName[interface],"eth%d",
+          &ethNum);
         }
       */
 
@@ -4490,6 +4384,20 @@ static char *netload(
   return(ret_string);
   }  /* END netload() */
 
+
+
+
+
+mbool_t ProcIsChild(
+
+  char *Dir,    /* I */
+  char *PID,    /* I */
+  char *JobID)  /* I */
+
+  {
+  return(FALSE);
+  }  /* END ProcIsChild() */
+
 /* END mom_mach.c */
 
 
