@@ -99,7 +99,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
@@ -116,6 +116,7 @@ extern char     *AllocParCmd;
 
 
 /* Private variables */
+
 #define TMAX_TJCACHESIZE 128
 job *TJCache[TMAX_TJCACHESIZE];
 
@@ -135,7 +136,7 @@ job *TJCache[TMAX_TJCACHESIZE];
 int set_job(
 
   job                 *pjob,  /* I (not used) */
-  struct startjob_rtn *sjr)   /* I (modified) */
+  struct startjob_rtn *sjr)   /* I (modified,optional) */
 
   {
   char id[] = "set_job";
@@ -145,14 +146,20 @@ int set_job(
 
   int   rc;
 
+  long  sid;
+
 #ifdef __XTTEST
   char  tmpLine[1024];
 #endif /* __ XTTEST */
 
-  sjr->sj_session = setsid();
+  sid = setsid();
+
+  if (sjr != NULL)
+    sjr->sj_session = sid;
 
 #ifdef __XTTEST
   PPtr = get_job_envvar(pjob, "BATCH_PARTITION_ID");
+
   CPtr = get_job_envvar(pjob, "BATCH_ALLOC_COOKIE");
 
   sprintf(tmpLine, "echo \"P:'%s' C:'%s'\" >> /tmp/dog",
@@ -181,17 +188,30 @@ int set_job(
     if (AllocParCmd == NULL)
       AllocParCmd = strdup("/opt/moab/default/tools/partition.create.xt4.pl");
 
-    snprintf(tmpLine, sizeof(tmpLine), "%s --confirm -p %s -j %s -a %ld",
+#ifdef ENABLE_CSA
+
+    if (pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_flags & ATR_VFLAG_SET)
+      {
+      snprintf(tmpLine, sizeof(tmpLine), "%s --confirm -p %s -j %s -a %lld",
+               AllocParCmd,
+               PPtr,
+               pjob->ji_qs.ji_jobid,
+               pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll);
+      }
+    else
+#endif
+      {
+      snprintf(tmpLine, sizeof(tmpLine), "%s --confirm -p %s -j %s -a %ld",
              AllocParCmd,
              PPtr,
              pjob->ji_qs.ji_jobid,
-             (long)sjr->sj_session);
+             sid);
+      }
 
-    log_ext(
+    log_err(
       -1,
       id,
-      tmpLine,
-      LOG_DEBUG);
+      tmpLine);
 
     rc = system(tmpLine);
 
@@ -199,18 +219,21 @@ int set_job(
       {
       snprintf(log_buffer, 1024, "cannot create alloc partition");
 
-      sjr->sj_session = -3;
+      sid = -3;
+
+      if (sjr != NULL)
+        sjr->sj_session = sid;
 
       log_err(
         -1,
         id,
         log_buffer);
 
-      return(sjr->sj_session);
+      return(sid);
       }
     }    /* END if (((PPtr = get_job_envvar(pjob,"BATCH_PARTITION_ID")) != NULL) && ...) */
 
-  return(sjr->sj_session);
+  return(sid);
   }  /* END set_job() */
 
 
@@ -306,31 +329,28 @@ char *set_shell(
 
 
 
-/*
+/**
  * scan_for_terminated - scan the list of running jobs for one whose
  * session id matches that of a terminated child pid.  Mark that
  * job as Exiting.
  *
- * NOTE: called by finish_loop() by main pbs_mom thread
+ * @see finish_loop() - parent
+ * @see scan_for_exiting() - peer - called later to harvest jobs with exiting tasks
  *
  */
 
-void
-scan_for_terminated(void)
+void scan_for_terminated(void)
 
   {
   static char id[] = "scan_for_terminated";
+
   int  exiteval = 0;
   pid_t  pid;
   job *pjob;
   task *ptask = NULL;
-  int statloc;
+  int  statloc;
 
-#ifdef CACHEOBITFAILURES
-  int tjcindex;
-
-  int TJCIndex = 0;
-#endif
+  int    tcount;
 
   if (LOGLEVEL >= 7)
     {
@@ -358,75 +378,26 @@ scan_for_terminated(void)
       }
     }
 
-#ifdef CACHEOBITFAILURES
-  /* process cached obit failures */
-
-  for (TJCIndex = 0;TJCIndex < TMAX_TJCACHESIZE;TJCIndex++)
-    {
-    if (TJCache[TJCIndex] == NULL)
-      break;
-
-    if (TJCache[TJCIndex] == (job *)1)
-      continue;
-
-    /* attempt to send obit again */
-
-    pjob = TJCache[TJCIndex];
-
-    if (LOGLEVEL >= 7)
-      {
-      LOG_EVENT(
-        PBSEVENT_DEBUG,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        "Retrying send of OBIT");
-      }
-
-    if (pjob->ji_mompost(pjob, exiteval) != 0)
-      {
-      /* attempt failed again */
-
-      termin_child = 1;
-
-      continue;
-      }
-
-    /* success */
-
-    if (LOGLEVEL >= 7)
-      {
-      LOG_EVENT(
-        PBSEVENT_DEBUG,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        "OBIT resent successfully");
-      }
-
-    pjob->ji_mompost = NULL;
-
-    /* clear mom sub-task */
-
-    pjob->ji_momsubt = 0;
-
-    job_save(pjob, SAVEJOB_QUICK);
-    TJCache[TJCIndex] = ((job *)1);
-    }  /* END for (TJIndex) */
-
-#endif /* CACHEOBITFAILURES */
-
   /* Now figure out which task(s) have terminated (are zombies) */
 
+  /* NOTE:  does a job's tasks include its epilog? */
+
   while ((pid = waitpid(-1, &statloc, WNOHANG)) > 0)
     {
     pjob = (job *)GET_PRIOR(svr_alljobs);
 
     while (pjob != NULL)
       {
+      /*
+       * see if process was a child doing a special
+       * function for MOM
+       */
+
       if (LOGLEVEL >= 7)
         {
         snprintf(log_buffer, 1024, "checking job w/subtask pid=%d (child pid=%d)",
-                 pjob->ji_momsubt,
-                 pid);
+          pjob->ji_momsubt,
+          pid);
 
         LOG_EVENT(
           PBSEVENT_DEBUG,
@@ -435,13 +406,22 @@ scan_for_terminated(void)
           log_buffer);
         }
 
-      /*
-      ** see if process was a child doing a special
-      ** function for MOM
-      */
-
       if (pid == pjob->ji_momsubt)
+        {
+        if (LOGLEVEL >= 7)
+          {
+          snprintf(log_buffer, 1024, "found match with job subtask for pid=%d",
+            pid);
+
+          LOG_EVENT(
+            PBSEVENT_DEBUG,
+            PBS_EVENTCLASS_JOB,
+            pjob->ji_qs.ji_jobid,
+            log_buffer);
+          }
+
         break;
+        }
 
       /* look for task */
 
@@ -449,19 +429,40 @@ scan_for_terminated(void)
 
       /* locate task with associated process id */
 
+      tcount = 0;
+
       while (ptask != NULL)
         {
         if ((ptask->ti_qs.ti_sid == pid) &&
             (ptask->ti_qs.ti_status != TI_STATE_EXITED))
           {
+          if (LOGLEVEL >= 7)
+            {
+            snprintf(log_buffer, 1024, "found match with job task %d for pid=%d",
+              tcount,
+              pid);
+
+            LOG_EVENT(
+              PBSEVENT_DEBUG,
+              PBS_EVENTCLASS_JOB,
+              pjob->ji_qs.ji_jobid,
+              log_buffer);
+            }
+
           break;
           }
 
         ptask = (task *)GET_NEXT(ptask->ti_jobtask);
+
+        tcount++;
         }  /* END while (ptask) */
 
       if (ptask != NULL)
+        {
+        /* pid match located - break out of job loop */
+
         break;
+        }
 
       pjob = (job *)GET_PRIOR(pjob->ji_alljobs);
       }  /* END while (pjob != NULL) */
@@ -478,9 +479,9 @@ scan_for_terminated(void)
       if (LOGLEVEL >= 1)
         {
         sprintf(log_buffer, "pid %d not tracked, statloc=%d, exitval=%d",
-                pid,
-                statloc,
-                exiteval);
+          pid,
+          statloc,
+          exiteval);
 
         log_record(
           PBSEVENT_JOB,
@@ -496,11 +497,8 @@ scan_for_terminated(void)
       {
       /* PID matches job mom subtask */
 
-      log_record(
-        PBSEVENT_JOB,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        "checking job post-processing routine");
+      /* NOTE:  both ji_momsubt and ji_mompost normally set in routine
+                preobit_reply() after epilog child is successfully forked */
 
       if (pjob->ji_mompost != NULL)
         {
@@ -511,45 +509,14 @@ scan_for_terminated(void)
           pjob->ji_mompost = NULL;
           }
 
-#ifdef CACHEOBITFAILURES
-        else
-          {
-          for (tjcindex = 0;tjcindex < TMAX_TJCACHESIZE;tjcindex++)
-            {
-            if ((TJCache[tjcindex] == NULL) || (TJCache[tjcindex] == (job *)1))
-              {
-              if (LOGLEVEL >= 7)
-                {
-                LOG_EVENT(
-                  PBSEVENT_DEBUG,
-                  PBS_EVENTCLASS_JOB,
-                  pjob->ji_qs.ji_jobid,
-                  "Caching OBIT for resend");
-                }
-
-              TJCache[tjcindex] = pjob;
-
-              termin_child = 1;
-
-              break;
-              }
-            }    /* END for (tjcindex) */
-
-          continue;
-          }
-
-#endif /* CACHEOBITFAILURES */
-        }
+        }  /* END if (pjob->ji_mompost != NULL) */
       else
         {
-        if (LOGLEVEL >= 7)
-          {
-          LOG_EVENT(
-            PBSEVENT_DEBUG,
-            PBS_EVENTCLASS_JOB,
-            pjob->ji_qs.ji_jobid,
-            "No post processing routine for job");
-          }
+        log_record(
+          PBSEVENT_JOB,
+          PBS_EVENTCLASS_JOB,
+          pjob->ji_qs.ji_jobid,
+          "job has no postprocessing routine registered");
         }
 
       /* clear mom sub-task */
@@ -565,10 +532,10 @@ scan_for_terminated(void)
 
     if (LOGLEVEL >= 2)
       {
-      sprintf(log_buffer, "for job %s, task %d, pid=%d, exitcode=%d",
+      sprintf(log_buffer, "pid %d harvested for job %s, task %d, exitcode=%d",
+              pid,
               pjob->ji_qs.ji_jobid,
               ptask->ti_qs.ti_task,
-              pid,
               exiteval);
 
       log_record(
@@ -583,7 +550,9 @@ scan_for_terminated(void)
     kill_task(ptask, SIGKILL, 0);
 
     ptask->ti_qs.ti_exitstat = exiteval;
+
     ptask->ti_qs.ti_status   = TI_STATE_EXITED;
+
     task_save(ptask);
 
     sprintf(log_buffer, "%s: job %s task %d terminated, sid=%d",
@@ -606,35 +575,6 @@ scan_for_terminated(void)
 
 
 
-/**
- * Removes any cached obits relating to the given job.
- */
-void remove_job_from_obit_cache(
-
-  job *pjob)  /* I */
-
-  { 
-#ifdef CACHEOBITFAILURES
-  int TJCIndex;
-
-  /* remove any reference to this job in the obit cache */
-
-  for (TJCIndex = 0;TJCIndex < TMAX_TJCACHESIZE;TJCIndex++)
-    {
-    if (TJCache[TJCIndex] == NULL)
-      break;
-
-    if (TJCache[TJCIndex] == (job *)1)
-      continue;
-
-    if (TJCache[TJCIndex] == pjob)
-      TJCache[TJCIndex] = (job *)1;  /* clear slot */
-    }
-#endif /* CACHEOBITFAILURES */
-  }  /* END remove_job_from_obit_cache() */
-
-
-
 
 /* SNL patch to use openpty() system call rather than search /dev */
 
