@@ -93,7 +93,7 @@
 #include "list_link.h"
 #include "server_limits.h"
 #include "attribute.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "mom_func.h"
@@ -123,6 +123,12 @@ static int   run_exit;
 extern int pe_input A_((char *));
 extern int TTmpDirName A_((job *, char *));
 extern void encode_used A_((job *, tlist_head *));
+#ifdef ENABLE_CSA
+extern void add_wkm_end(uint64_t, int64_t, char *);
+
+extern char             *path_epiloguser;
+#endif /* ENABLE_CSA */
+
 
 /* END extern prototypes */
 
@@ -234,6 +240,10 @@ static char *resc_to_string(
 
 /*
  * pelog_err - record error for run_pelog()
+ *
+ * @see run_pelog() - parent
+ *
+ * @return (parameter 'n')
  */
 
 static int pelog_err(
@@ -244,15 +254,15 @@ static int pelog_err(
   char *text)  /* I */
 
   {
-  sprintf(log_buffer, "prolog/epilog failed, file: %s, exit: %d, %s",
-          file,
-          n,
-          text);
+  sprintf(log_buffer,"prolog/epilog failed, file: %s, exit: %d, %s",
+    file,
+    n,
+    text);
 
-  sprintf(PBSNodeMsgBuf, "ERROR: %s",
-          log_buffer);
+  sprintf(PBSNodeMsgBuf,"ERROR: %s",
+    log_buffer);
 
-  log_err(-1, "run_pelog", log_buffer);
+  log_err(-1,"run_pelog",log_buffer);
 
   return(n);
   }  /* END pelog_err() */
@@ -274,7 +284,7 @@ static void pelogalm(
 
   errno = 0;
 
-  kill(child, SIGKILL);
+  kill(child,SIGKILL);
 
   run_exit = -4;
 
@@ -301,11 +311,23 @@ static void pelogalm(
  *   - argv[7] is the list of resources used
  *   - argv[8] is the queue in which the job resides
  *   - argv[9] is the account under which the job run
- *   - argv[10] is the job's exit status 
+ *   - argv[10] is the job's exit status
  * The prologue also has:
  *   - argv[5] is the list of resource limits specified
  *   - argv[6] is the queue in which the job resides
  *   - argv[7] is the account under which the job is run
+ * 
+ * @see TMomFinalizeChild() - parent
+ * @see pelog_err() - child
+ *
+ * @return = 0 - SUCCESS - file does not exist or execution successful
+ * @return < 0 - FAILURE - general internal failure 
+ *   -1 file permission issue
+ *   -2 no pro/epi input file
+ *   -3 child wait interrupted
+ *   -4 prolog/epilog timeout occurred, child cleaned up
+ *   -5 prolog/epilog timeout occurred, cannot kill child
+ * @return > 0 - FAILURE - system failure (rc = errno)
  */
 
 int run_pelog(
@@ -319,7 +341,7 @@ int run_pelog(
   char *id = "run_pelog";
 
   struct sigaction act, oldact;
-  char  *arg[12];
+  char *arg[12];
   int   fds1 = 0;
   int   fds2 = 0;
   int   fd_input;
@@ -376,13 +398,11 @@ int run_pelog(
     rc = stat(pelog,&sbuf);
     }
 
-  printf("pelog: %s\n", pelog);
-
   if (rc == -1)
     {
     if (errno == ENOENT || errno == EBADF)
       {
-      /* prolog script does not exist */
+      /* epilog/prolog script does not exist */
 
       if (LOGLEVEL >= 5)
         {
@@ -393,15 +413,36 @@ int run_pelog(
           (pelog != NULL) ? pelog : "NULL",
           (pjob != NULL) ? pjob->ji_qs.ji_jobid : "NULL",
           getcwd(tmpBuf, sizeof(tmpBuf)),
-          (int)getpid());
+          getpid());
 
         log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
         }
 
+#ifdef ENABLE_CSA
+      if ((which == PE_EPILOGUSER) && (!strcmp(pelog, path_epiloguser)))
+        {
+        /*
+          * Add a workload management end record
+        */
+        if (LOGLEVEL >= 8)
+          {
+          sprintf(log_buffer, "%s calling add_wkm_end from run_pelog() - no user epilog",
+            pjob->ji_qs.ji_jobid);
+
+          log_err(-1, id, log_buffer);
+          }
+
+        add_wkm_end(pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll,
+
+                    pjob->ji_qs.ji_un.ji_momt.ji_exitstat, pjob->ji_qs.ji_jobid);
+        }
+
+#endif /* ENABLE_CSA */
+
       return(0);
       }
 
-    return(pelog_err(pjob, pelog, errno, "cannot stat"));
+    return(pelog_err(pjob,pelog,errno,"cannot stat"));
     }
 
   if (LOGLEVEL >= 5)
@@ -417,12 +458,22 @@ int run_pelog(
   /* script must be owned by root, be regular file, read and execute by user *
    * and not writeable by group or other */
 
-  if ((sbuf.st_uid != 0) ||
+  if(which == PE_PROLOGUSERJOB || which == PE_EPILOGUSERJOB)
+    {
+    if ((sbuf.st_uid != pjob->ji_qs.ji_un.ji_momt.ji_exuid) ||
+        (!S_ISREG(sbuf.st_mode)) ||
+        ((sbuf.st_mode & (S_IRUSR | S_IXUSR)) != (S_IRUSR | S_IXUSR)) ||
+        (sbuf.st_mode & (S_IWGRP | S_IWOTH)))
+      {
+      return(pelog_err(pjob,pelog,-1,"permission Error"));
+      }
+    }
+  else if ((sbuf.st_uid != 0) ||
       (!S_ISREG(sbuf.st_mode)) ||
       ((sbuf.st_mode & (S_IRUSR | S_IXUSR)) != (S_IRUSR | S_IXUSR)) ||
       (sbuf.st_mode & (S_IWGRP | S_IWOTH)))
     {
-    return(pelog_err(pjob, pelog, -1, "permission Error"));
+    return(pelog_err(pjob,pelog,-1,"permission Error"));
     }
 
   if ((which == PE_PROLOGUSER) || (which == PE_EPILOGUSER))
@@ -515,6 +566,26 @@ int run_pelog(
       }    /* END while (wait(&waitst) < 0) */
 
     /* epilog/prolog child completed */
+#ifdef ENABLE_CSA
+    if ((which == PE_EPILOGUSER) && (!strcmp(pelog, path_epiloguser)))
+      {
+      /*
+       * Add a workload management end record
+      */
+      if (LOGLEVEL >= 8)
+        {
+        sprintf(log_buffer, "%s calling add_wkm_end from run_pelog() - after user epilog",
+                pjob->ji_qs.ji_jobid);
+
+        log_err(-1, id, log_buffer);
+        }
+
+      add_wkm_end(pjob->ji_wattr[(int)JOB_ATR_pagg_id].at_val.at_ll,
+
+                  pjob->ji_qs.ji_un.ji_momt.ji_exitstat, pjob->ji_qs.ji_jobid);
+      }
+
+#endif /* ENABLE_CSA */
 
     alarm(0);
 
@@ -545,13 +616,14 @@ int run_pelog(
 
     net_close(-1);
 
-    if ((which == PE_PROLOGUSER) || (which == PE_EPILOGUSER))
+    if ((which == PE_PROLOGUSER) || (which == PE_EPILOGUSER) || (which == PE_PROLOGUSERJOB) || which == PE_EPILOGUSERJOB)
       {
       if (setgroups(
-           pjob->ji_grpcache->gc_ngroup,
-           (gid_t *)pjob->ji_grpcache->gc_groups) != 0)
+          pjob->ji_grpcache->gc_ngroup,
+          (gid_t *)pjob->ji_grpcache->gc_groups) != 0)
         {
-        snprintf(log_buffer,sizeof(log_buffer),"setgroups() for UID = %lu failed: %s\n",
+        snprintf(log_buffer,sizeof(log_buffer),
+          "setgroups() for UID = %lu failed: %s\n",
           (unsigned long)pjob->ji_qs.ji_un.ji_momt.ji_exuid,
           strerror(errno));
 
@@ -562,7 +634,8 @@ int run_pelog(
 
       if (setgid(pjob->ji_qs.ji_un.ji_momt.ji_exgid) != 0)
         {
-        snprintf(log_buffer,sizeof(log_buffer),"setgid(%lu) for UID = %lu failed: %s\n",
+        snprintf(log_buffer,sizeof(log_buffer),
+          "setgid(%lu) for UID = %lu failed: %s\n",
           (unsigned long)pjob->ji_qs.ji_un.ji_momt.ji_exgid,
           (unsigned long)pjob->ji_qs.ji_un.ji_momt.ji_exuid,
           strerror(errno));
@@ -574,7 +647,8 @@ int run_pelog(
 
       if (setuid(pjob->ji_qs.ji_un.ji_momt.ji_exuid) != 0)
         {
-        snprintf(log_buffer,sizeof(log_buffer),"setuid(%lu) failed: %s\n",
+        snprintf(log_buffer,sizeof(log_buffer),
+          "setuid(%lu) failed: %s\n",
           (unsigned long)pjob->ji_qs.ji_un.ji_momt.ji_exuid,
           strerror(errno));
 
@@ -597,8 +671,8 @@ int run_pelog(
       {
       /* no output, force to /dev/null */
 
-      fds1 = open("/dev/null",O_WRONLY,0600);
-      fds2 = open("/dev/null",O_WRONLY,0600);
+      fds1 = open("/dev/null", O_WRONLY, 0600);
+      fds2 = open("/dev/null", O_WRONLY, 0600);
       }
     else if (pe_io_type == PE_IO_TYPE_STD)
       {
@@ -624,11 +698,8 @@ int run_pelog(
 
         case 1:
 
-          fds1 = open_std_file(
-            pjob, 
-            StdOut, 
-            O_WRONLY | O_APPEND,
-            pjob->ji_qs.ji_un.ji_momt.ji_exgid);
+          fds1 = open_std_file(pjob, StdOut, O_WRONLY | O_APPEND,
+                               pjob->ji_qs.ji_un.ji_momt.ji_exgid);
 
           fds2 = dup(fds1);
 
@@ -668,18 +739,19 @@ int run_pelog(
         }
       }
 
-    if ((which == PE_PROLOGUSER) || (which == PE_EPILOGUSER))
+    if ((which == PE_PROLOGUSER) || (which == PE_EPILOGUSER) || (which == PE_PROLOGUSERJOB) || (which == PE_EPILOGUSERJOB))
       {
       if (chdir(pjob->ji_grpcache->gc_homedir) != 0)
         {
         /* warn only, no failure */
 
-        sprintf(log_buffer,"PBS: chdir to %s failed: %s (running user %s in current directory)",
+        sprintf(log_buffer,
+          "PBS: chdir to %s failed: %s (running user %s in current directory)",
           pjob->ji_grpcache->gc_homedir,
           strerror(errno),
           which == PE_PROLOGUSER ? "prologue" : "epilogue");
 
-        if (write(2,log_buffer,strlen(log_buffer)) == -1) {}
+        if (write(2, log_buffer, strlen(log_buffer)) == -1) {}
 
         fsync(2);
         }
@@ -708,7 +780,7 @@ int run_pelog(
 
     /* NOTE:  inside child */
 
-    if (which == PE_EPILOG || which == PE_EPILOGUSER)
+    if (which == PE_EPILOG)
       {
       /* for epilog only */
 
@@ -782,7 +854,7 @@ int run_pelog(
 
     r = find_resc_entry(
           &pjob->ji_wattr[(int)JOB_ATR_resource],
-          find_resc_def(svr_resc_def,"gres",svr_resc_size));
+          find_resc_def(svr_resc_def, "gres", svr_resc_size));
 
     if (r != NULL)
       {
@@ -806,7 +878,7 @@ int run_pelog(
         }
       }  /* END if (r != NULL) */
 
-    if (TTmpDirName(pjob,buf))
+    if (TTmpDirName(pjob, buf))
       {
       const char *envname = "TMPDIR=";
       char *envstr;
@@ -833,7 +905,7 @@ int run_pelog(
       char *envval;
       char *envstr;
 
-      if ((envval = get_job_envvar(pjob,envname)) != NULL)
+      if ((envval = get_job_envvar(pjob, envname)) != NULL)
         {
         envstr = malloc((strlen(envname) + strlen(envval) + 2) * sizeof(char));
 
@@ -853,7 +925,7 @@ int run_pelog(
       char *envname = "PBS_NODENUM";
       char *envstr;
 
-      sprintf(buf,"%d",
+      sprintf(buf, "%d",
         pjob->ji_nodeid);
 
       envstr = malloc((strlen(envname) + strlen(buf) + 2) * sizeof(char));
@@ -889,33 +961,33 @@ int run_pelog(
       }
 
     /* Set PBS_NODEFILE */
-
-    {
-    char *envname = "PBS_NODEFILE";
-    char *envstr;
-
-    if (pjob->ji_flags & MOM_HAS_NODEFILE)
       {
-      sprintf(buf, "%s/%s",
-        path_aux,
-        pjob->ji_qs.ji_jobid);
+      char *envname = "PBS_NODEFILE";
+      char *envstr;
 
-      envstr = malloc((strlen(envname) + strlen(buf) + 2) * sizeof(char));
-
-      if (envstr != NULL)
+      if (pjob->ji_flags & MOM_HAS_NODEFILE)
         {
-        sprintf(envstr,"%s=%s",
-          envname,
-          buf);
+        sprintf(buf, "%s/%s",
+          path_aux,
+          pjob->ji_qs.ji_jobid);
 
-        putenv(envstr);
+        envstr = malloc((strlen(envname) + strlen(buf) + 2) * sizeof(char));
+
+        if (envstr != NULL)
+          {
+          sprintf(envstr,"%s=%s",
+            envname,
+            buf);
+
+          putenv(envstr);
+          }
         }
       }
-    }
 
     /* SET BEOWULF_JOB_MAP */
 
       {
+
       struct array_strings *vstrs;
 
       int VarIsSet = 0;
@@ -940,7 +1012,7 @@ int run_pelog(
         {
         char *envstr;
 
-        envstr = malloc((strlen(vstrs->as_string[j]) + 1) * sizeof(char));
+        envstr = malloc((strlen(vstrs->as_string[j])) * sizeof(char));
 
         if (envstr != NULL)
           {
@@ -957,21 +1029,24 @@ int run_pelog(
       pelog,
       strerror(errno));
 
-    if (write(2,log_buffer,strlen(log_buffer)) == -1) 
+    if (write(2, log_buffer, strlen(log_buffer)) == -1) 
       {
-      /* FAILURE */
+      /* cannot write message to stderr */
+
+      /* NO-OP */
       }
-    
+
     fsync(2);
 
     exit(255);
     }  /* END else () */
 
   switch (run_exit)
-
     {
     case 0:
 
+      /* SUCCESS */
+
       /* NO-OP */
 
       break;
