@@ -102,15 +102,14 @@
 #include <sys/procfs.h>
 #include <sys/proc.h>
 #include <sys/resource.h>
-#include <ctype.h>
-#include <signal.h>
+
 #include "pbs_error.h"
 #include "portability.h"
 #include "list_link.h"
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
@@ -137,7 +136,7 @@
 **  loadave  current load average
 */
 
-static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3390 $";
+static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 3151 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -161,7 +160,9 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
+extern  int     ignmem;
 
 /*
 ** local functions and data
@@ -189,7 +190,6 @@ static long page_size;
 
 #define TBL_INC 20
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 
 extern char extra_parm[];
@@ -258,9 +258,8 @@ dep_cleanup(void)
  *  sizeof(word) = sizeof(int)
  */
 
-static int getsize(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getsize(resource *pres, unsigned long *ret)
   {
   unsigned long value;
 
@@ -295,9 +294,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -347,15 +345,15 @@ pid_t sid;
  * consumed for all tasks executed by the job, in seconds.
  * The "real" time is adjusted by "cputfactor"
  */
-static unsigned long cput_sum(pjob)
-job   *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_sum";
   ulong   cputime, addtime;
   int   i;
   int   nps = 0;
   prstatus_t  *ps;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
 
   cputime = 0;
 
@@ -371,8 +369,8 @@ job   *pjob;
     if (pi->pr_state == SZOMB)
       {
       cputime += tv(pi->pr_time);
-      DBPRT(("%s: ses %d pid %d (zombie) cputime %ld\n",
-             id, (int)pi->pr_sid, (int)pi->pr_pid, cputime))
+      DBPRT(("%s: ses %d pid %d (zombie) cputime %d\n",
+             id, pi->pr_sid, pi->pr_pid, cputime))
       continue;
       }
 
@@ -382,8 +380,8 @@ job   *pjob;
               tv(ps->pr_cutime) + tv(ps->pr_cstime);
 
     cputime += addtime;
-    DBPRT(("%s: ses %d pid %d cputime %ld\n",
-           id, (int)pi->pr_sid, (int)ps->pr_pid, cputime))
+    DBPRT(("%s: ses %d pid %d cputime %d\n",
+           id, pi->pr_sid, ps->pr_pid, cputime))
     }
 
   if (nps == 0)
@@ -398,10 +396,10 @@ job   *pjob;
  * Return TRUE if any process in the job is over limit for cputime usage
  * adjusted by cputfactor.
  */
-static int overcput_proc(pjob, limit)
-job   *pjob;
-unsigned long limit;
+static int
+overcput_proc(job *pjob, unsigned long limit)
   {
+  char  *id = "overcput_proc";
   ulong  memsize;
   ulong  cputime;
   int  i;
@@ -433,12 +431,13 @@ unsigned long limit;
  * Returns the total number of bytes of address
  * space consumed by all current tasks within the session.
  */
-static unsigned long mem_sum(pjob)
-job   *pjob;
+static unsigned long
+mem_sum(job *pjob)
   {
+  char  *id = "mem_sum";
   ulong  memsize;
   int  i;
-  prpsinfo_t *pi = NULL;
+  prpsinfo_t *pi;
 
   memsize = 0;
 
@@ -458,12 +457,13 @@ job   *pjob;
 /*
  * Internal session mem (workingset) size function.
  */
-static unsigned long resi_sum(pjob)
-job   *pjob;
+static unsigned long
+resi_sum(job *pjob)
   {
+  char  *id = "resi_sum";
   ulong  resisize;
   int  i;
-  prpsinfo_t *pi = NULL;
+  prpsinfo_t *pi;
 
   resisize = 0;
 
@@ -488,31 +488,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
- 
-  message = ident; /* this is done only to supress a compiler warning which complains
-                      ident is defined but not used */
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -543,9 +526,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -578,24 +563,30 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
 
     if (strcmp(pname, "cput") == 0)   /* cpu time - check */
       {
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      reslim.rlim_cur = reslim.rlim_max =
-                          (unsigned long)((double)value / cputfactor);
+        reslim.rlim_cur = reslim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit(RLIMIT_CPU, &reslim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit(RLIMIT_CPU, &reslim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -617,14 +608,54 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "mem") == 0)    /* check */
       {
-      retval = getsize(pres, &value);
+      if (ignmem == FALSE)
+        {
+        retval = getsize(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
+        {
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &value);
+
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
+
+          if (value > ULONG_MAX)
+            return (error(pname, PBSE_BADATVAL));
+
+          reslim.rlim_cur = reslim.rlim_max = value;
+
+          if (setrlimit(RLIMIT_DATA, &reslim) < 0)
+            return (error("RLIMIT_DATA", PBSE_SYSTEM));
+
+          if (setrlimit(RLIMIT_STACK, &reslim) < 0)
+            return (error("RLIMIT_STACK", PBSE_SYSTEM));
+          }
+        }
+      }
+    else if (strcmp(pname, "vmem") == 0)   /* check */
+      {
+      if (ignvmem == FALSE)
+        {
+        retval = getsize(pres, &value);
+
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
+        }
+      }
+    else if (strcmp(pname, "pvmem") == 0)   /* set */
+      {
+      if (ignvmem == FALSE) 
         {
         retval = getsize(pres, &value);
 
@@ -634,38 +665,10 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
         if (value > ULONG_MAX)
           return (error(pname, PBSE_BADATVAL));
 
-        reslim.rlim_cur = reslim.rlim_max = value;
-
-        if (setrlimit(RLIMIT_DATA, &reslim) < 0)
-          return (error("RLIMIT_DATA", PBSE_SYSTEM));
-
-        if (setrlimit(RLIMIT_STACK, &reslim) < 0)
-          return (error("RLIMIT_STACK", PBSE_SYSTEM));
+        if ((mem_limit == 0) || (value < mem_limit))
+          mem_limit = value;
         }
       }
-    else if (strcmp(pname, "vmem") == 0)   /* check */
-      {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
-    else if (strcmp(pname, "pvmem") == 0)   /* set */
-      {
-      retval = getsize(pres, &value);
-
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if (value > ULONG_MAX)
-        return (error(pname, PBSE_BADATVAL));
-
-      if ((mem_limit == 0) || (value < mem_limit))
-        mem_limit = value;
-      }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
       {
       retval = gettime(pres, &value);
@@ -714,8 +717,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -783,7 +786,7 @@ mom_get_sample(void)
   struct dirent  *dent;
   char   procname[100];
   prstatus_t  *ps;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
 
   DBPRT(("%s: entered\n", id))
   rewinddir(pdir);
@@ -854,8 +857,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *id = "mom_over_limit";
   char  *pname;
@@ -877,7 +880,7 @@ job   *pjob;
     assert(pname != NULL);
     assert(*pname != '\0');
 
-    if (strcmp(pname, "cput") == 0)
+    if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -892,7 +895,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "pcput") == 0))
       {
       retval = gettime(pres, &value);
 
@@ -922,7 +925,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -937,11 +940,9 @@ job   *pjob;
       if (num > value)
         {
         sprintf(log_buffer,
-                "walltime %ld exceeded limit %ld",
+                "walltime %d exceeded limit %d",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -958,9 +959,10 @@ job   *pjob;
  *
  * Assumes that the session ID attribute has already been set.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
+  char   *id = "mom_set_use";
   resource  *pres;
   attribute  *at;
   resource_def  *rd;
@@ -1043,13 +1045,12 @@ job   *pjob;
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int   sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
+  char  *id = "kill_task";
   int  ct = 0;
-  prpsinfo_t *pi = NULL;
+  prpsinfo_t *pi;
   int  i, sesid;
 
   sesid = ptask->ti_qs.ti_sid;
@@ -1104,14 +1105,13 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
-  return (0);
+  return(CST_NONE);
   }
 
 /*
@@ -1120,10 +1120,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
   return (-1);
   }
@@ -1134,9 +1132,8 @@ int  abort;
  * Return -1 on error or sid if okay.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
   return (-1);
   }
@@ -1148,6 +1145,7 @@ int
 getprocs(void)
   {
   static unsigned int lastproc = 0;
+  static char  id[] = "getprocs";
 
   if (lastproc == reqnum)  /* don't need new proc table */
     return 1;
@@ -1164,7 +1162,7 @@ double
 dsecs(t)
 timestruc_t     *t;
   {
-  DBPRT(("\tsecs: %d\tnsecs: %ld\n", (int)t->tv_sec, t->tv_nsec))
+  DBPRT(("\tsecs: %d\tnsecs: %d\n", t->tv_sec, t->tv_nsec))
   return ((double)t->tv_sec + ((double)t->tv_nsec * 1.0e-9));
   }
 
@@ -1203,7 +1201,7 @@ pid_t jobid;
     cputime += addtime;
 
     DBPRT(("%s: total %.2f pid %d %.2f\n", id, cputime,
-           (int)ps->pr_pid, addtime))
+           ps->pr_pid, addtime))
 
     }
 
@@ -1222,9 +1220,10 @@ char *
 cput_proc(pid)
 pid_t pid;
   {
+  char   *id = "cput_pid";
   double   cputime;
   int   i;
-  prstatus_t  *ps = NULL;
+  prstatus_t  *ps;
 
   if (getprocs() == 0)
     {
@@ -1304,7 +1303,7 @@ pid_t jobid;
   int   memsize;
   int   i;
   int   found = 0;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
 
   if (getprocs() == 0)
     {
@@ -1325,13 +1324,13 @@ pid_t jobid;
 
     memsize += pi->pr_size;
 
-    DBPRT(("%s: total %ld pid %d %ld\n", id, memsize*page_size,
-           (int)pi->pr_pid, pi->pr_size*page_size))
+    DBPRT(("%s: total %d pid %d %d\n", id, memsize*page_size,
+           pi->pr_pid, pi->pr_size*page_size))
     }
 
   if (found)
     {
-    sprintf(ret_string, "%ldkb", (memsize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ukb", (memsize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1344,7 +1343,8 @@ char *
 mem_proc(pid)
 pid_t pid;
   {
-  prpsinfo_t  *pi = NULL;
+  char   *id = "mem_proc";
+  prpsinfo_t  *pi;
   int   i;
 
   if (getprocs() == 0)
@@ -1367,7 +1367,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", (pi->pr_size * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ukb", (pi->pr_size * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1415,10 +1415,11 @@ static char *
 resi_job(jobid)
 pid_t jobid;
   {
+  char   *id = "resi_job";
   int   resisize;
   int   i;
   int   found = 0;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
 
   if (getprocs() == 0)
     {
@@ -1442,7 +1443,7 @@ pid_t jobid;
 
   if (found)
     {
-    sprintf(ret_string, "%ldkb", (resisize*page_size) >> 10); /* KB */
+    sprintf(ret_string, "%ukb", (resisize*page_size) >> 10); /* KB */
     return ret_string;
     }
 
@@ -1455,7 +1456,8 @@ static char *
 resi_proc(pid)
 pid_t pid;
   {
-  prpsinfo_t  *pi = NULL;
+  char   *id = "resi_proc";
+  prpsinfo_t  *pi;
   int   i;
 
   if (getprocs() == 0)
@@ -1478,7 +1480,7 @@ pid_t pid;
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", (pi->pr_rssize * page_size) >> 10); /* KB */
+  sprintf(ret_string, "%ukb", (pi->pr_rssize * page_size) >> 10); /* KB */
 
   return ret_string;
   }
@@ -1527,7 +1529,7 @@ sessions(struct rm_attribute *attrib)
   {
   char   *id = "sessions";
   int   i, j;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
   char   *fmt;
   int   njids = 0;
   pid_t   *jids, *hold;
@@ -1568,7 +1570,7 @@ sessions(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d sid %d\n",
-           id, (int)njids, (int)pi->pr_pid, (int)jobid))
+           id, njids, pi->pr_pid, jobid))
 
     for (j = 0; j < njids; j++)
       {
@@ -1642,8 +1644,8 @@ pids(struct rm_attribute *attrib)
   {
   char  *id = "pids";
   pid_t  jobid;
-  int  i;
-  prpsinfo_t *pi = NULL;
+  int  i, j;
+  prpsinfo_t *pi;
   char  *fmt;
   int  num_pids;
 
@@ -1693,12 +1695,12 @@ pids(struct rm_attribute *attrib)
     pi = &proc_info[i];
 
     DBPRT(("%s[%d]: pid: %d sid %d\n",
-           id, num_pids, (int)pi->pr_pid, (int)pi->pr_sid))
+           id, num_pids, pi->pr_pid, pi->pr_sid))
 
     if (jobid != pi->pr_sid)
       continue;
 
-    sprintf(fmt, "%d ", (int)pi->pr_pid);
+    sprintf(fmt, "%d ", pi->pr_pid);
 
     fmt += strlen(fmt);
 
@@ -1719,7 +1721,7 @@ nusers(struct rm_attribute *attrib)
   {
   char   *id = "nusers";
   int   i, j;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
   int   nuids = 0;
   uid_t   *uids, *hold;
   static  int maxuid = 200;
@@ -1753,7 +1755,7 @@ nusers(struct rm_attribute *attrib)
       continue;
 
     DBPRT(("%s[%d]: pid %d uid %d\n",
-           id, nuids, (int)pi->pr_pid, (int)uid))
+           id, nuids, pi->pr_pid, uid))
 
     for (j = 0; j < nuids; j++)
       {
@@ -1801,7 +1803,7 @@ ncpus(struct rm_attribute *attrib)
     return NULL;
     }
 
-  sprintf(ret_string, "%ld", sysconf(_SC_NPROCESSORS_ONLN));
+  sprintf(ret_string, "%d", sysconf(_SC_NPROCESSORS_ONLN));
 
   system_ncpus = sysconf(_SC_NPROCESSORS_ONLN);
   return ret_string;
@@ -1830,6 +1832,9 @@ char *
 size_fs(char *param)
   {
   char  *id = "size_fs";
+  FILE  *mf;
+
+  struct mntent *mp;
 
   struct statvfs fsbuf;
 
@@ -1878,7 +1883,7 @@ size_file(char *param)
     return NULL;
     }
 
-  sprintf(ret_string, "%ldkb", sbuf.st_size >> 10); /* KB */
+  sprintf(ret_string, "%ukb", sbuf.st_size >> 10); /* KB */
 
   return ret_string;
   }
@@ -1993,7 +1998,7 @@ walltime(struct rm_attribute *attrib)
   int   i;
   int   value, job, found = 0;
   time_t   now, start;
-  prpsinfo_t  *pi = NULL;
+  prpsinfo_t  *pi;
 
   if (attrib == NULL)
     {
@@ -2079,17 +2084,14 @@ get_la(double *rv)
   char *id = "get_la";
   kvm_t *kd;
   long load;
-  char *avenrun = "avenrun";
-  static struct nlist nl[2];
 
-  nl[0].n_name = avenrun;
-  nl[0].n_value = 0;
-  nl[0].n_scnum = 0;
-  nl[0].n_type = 0;
-  nl[0].n_sclass = NULL;
-  nl[0].n_numaux = NULL;
+  static struct nlist nl[] =
+    {
+      { "avenrun"
+      },
 
-  nl[1].n_name = NULL;
+    { "" }
+    };
 
   kd = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL);
 
