@@ -93,11 +93,11 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 3390 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
 
 /* Global Variables */
 
@@ -118,10 +118,8 @@ extern int  termin_child;
  *  -2 - if other, message in log_buffer
  */
 
-int set_job(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+int
+set_job(job *pjob, struct startjob_rtn *sjr)
   {
   return (sjr->sj_session = setsid());
   }
@@ -130,10 +128,7 @@ struct startjob_rtn *sjr;
 ** set_globid - set the global id for a machine type.
 */
 void
-set_globid(pjob, sjr)
-job *pjob;
-
-struct startjob_rtn *sjr;
+set_globid(job *pjob, struct startjob_rtn *sjr)
   {
   extern char noglobid[];
 
@@ -146,18 +141,16 @@ struct startjob_rtn *sjr;
  */
 
 int
-set_mach_vars(pjob, vtab)
-job      *pjob;    /* pointer to the job */
-
-struct var_table *vtab;    /* pointer to variable table */
+set_mach_vars(
+  job *pjob,    /* pointer to the job */
+  struct var_table *vtab    /* pointer to variable table */
+)
   {
   return 0;
   }
 
-char *set_shell(pjob, pwdp)
-job       *pjob;
-
-struct passwd *pwdp;
+char *
+set_shell(job *pjob, struct passwd *pwdp)
   {
   char *cp;
   int   i;
@@ -208,8 +201,8 @@ scan_for_terminated(void)
   static char id[] = "scan_for_terminated";
   int  exiteval;
   pid_t  pid;
-  job  *pjob = NULL;
-  task  *ptask = NULL;
+  job  *pjob;
+  task  *ptask;
   int  statloc;
 
   /* update the latest intelligence about the running jobs;         */
@@ -273,7 +266,7 @@ scan_for_terminated(void)
     if (pjob == NULL)
       {
       DBPRT(("%s: pid %d not tracked, exit %d\n",
-             id, (int)pid, exiteval))
+             id, pid, exiteval))
       continue;
       }
 
@@ -292,8 +285,8 @@ scan_for_terminated(void)
       }
 
     DBPRT(("%s: task %d pid %d exit value %d\n", id,
-           ptask->ti_qs.ti_task, (int)pid, exiteval))
 
+           ptask->ti_qs.ti_task, pid, exiteval))
     kill_task(ptask, SIGKILL, 0);
     ptask->ti_qs.ti_exitstat = exiteval;
     ptask->ti_qs.ti_status = TI_STATE_EXITED;
@@ -327,9 +320,6 @@ open_master(
   static char ptcchar2[] = "0123456789abcdef";
   static char pty_name[PTY_SIZE+1]; /* "/dev/[pt]tyXY" */
 
-  pc1 = ident; /* This is here to stop a compiler warning because
-                  ident is defined but not used */
-
   (void)strncpy(pty_name, "/dev/ptyXY", PTY_SIZE);
 
   for (pc1 = ptcchar1; *pc1 != '\0'; ++pc1)
