@@ -99,7 +99,7 @@
 #include "list_link.h"
 #include "attribute.h"
 #include "server_limits.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "queue.h"
 #include "log.h"
 #include "acct.h"
@@ -408,7 +408,6 @@ int acct_open(
   time_t now;
 
   struct tm *ptm;
-
   struct tm tmpPtm;
 
   if (filename == NULL)
@@ -417,7 +416,7 @@ int acct_open(
 
     now = time(0);
 
-    ptm = localtime_r(&now, &tmpPtm);
+    ptm = localtime_r(&now,&tmpPtm);
 
     sprintf(filen, "%s%04d%02d%02d",
             path_acct,
@@ -507,7 +506,6 @@ void account_record(
   {
 
   struct tm *ptm;
-
   struct tm tmpPtm;
 
   if (acct_opened == 0)
@@ -517,7 +515,7 @@ void account_record(
     return;
     }
 
-  ptm = localtime_r(&time_now, &tmpPtm);
+  ptm = localtime_r(&time_now,&tmpPtm);
 
   /* Do we need to switch files */
 
