@@ -104,8 +104,6 @@
 
 /* External Global Data */
 
-extern char *msg_nosupport;
-
 extern int       LOGLEVEL;
 
 
@@ -136,7 +134,7 @@ int dis_request_read(
 
   /* Decode the Request Header, that will tell the request type */
 
-  if ((rc = decode_DIS_ReqHdr(sfds, request, &proto_type, &proto_ver)))
+  if ((rc = tcp_decode_DIS_ReqHdr(sfds, request, &proto_type, &proto_ver)))
     {
     if (rc == DIS_EOF)
       {
@@ -167,7 +165,7 @@ int dis_request_read(
     return(PBSE_DISPROTO);
     }
 
-  if ((request->rq_type < 0) || (request->rq_type > PBS_BATCH_Disconnect))
+  if ((request->rq_type < 0) || (request->rq_type >= PBS_BATCH_CEILING))
     {
     sprintf(log_buffer, "invalid request type: %d",
             request->rq_type);
@@ -195,6 +193,7 @@ int dis_request_read(
 
   switch (request->rq_type)
     {
+
     case PBS_BATCH_Disconnect:
 
       return(-1);  /* set EOF return */
@@ -207,13 +206,13 @@ int dis_request_read(
 
       CLEAR_HEAD(request->rq_ind.rq_queuejob.rq_attr);
 
-      rc = decode_DIS_QueueJob(sfds, request);
+      rc = tcp_decode_DIS_QueueJob(sfds, request);
 
       break;
 
     case PBS_BATCH_JobCred:
 
-      rc = decode_DIS_JobCred(sfds, request);
+      rc = tcp_decode_DIS_JobCred(sfds, request);
 
       break;
 
@@ -221,7 +220,7 @@ int dis_request_read(
 
     case PBS_BATCH_MvJobFile:
 
-      rc = decode_DIS_JobFile(sfds, request);
+      rc = tcp_decode_DIS_JobFile(sfds, request);
 
       break;
 
@@ -231,7 +230,7 @@ int dis_request_read(
 
     case PBS_BATCH_Rerun:
 
-      rc = decode_DIS_JobId(sfds, request->rq_ind.rq_commit);
+      rc = tcp_decode_DIS_JobId(sfds, request->rq_ind.rq_commit);
 
       break;
 
@@ -239,33 +238,37 @@ int dis_request_read(
 
     case PBS_BATCH_HoldJob:
 
+    case PBS_BATCH_CheckpointJob:
+
     case PBS_BATCH_ModifyJob:
 
-      rc = decode_DIS_Manage(sfds, request);
+    case PBS_BATCH_AsyModifyJob:
+
+      rc = tcp_decode_DIS_Manage(sfds, request);
 
       break;
 
     case PBS_BATCH_MessJob:
 
-      rc = decode_DIS_MessageJob(sfds, request);
+      rc = tcp_decode_DIS_MessageJob(sfds, request);
 
       break;
 
     case PBS_BATCH_Shutdown:
 
-      rc = decode_DIS_ShutDown(sfds, request);
+      rc = tcp_decode_DIS_ShutDown(sfds, request);
 
       break;
 
     case PBS_BATCH_SignalJob:
 
-      rc = decode_DIS_SignalJob(sfds, request);
+      rc = tcp_decode_DIS_SignalJob(sfds, request);
 
       break;
 
     case PBS_BATCH_StatusJob:
 
-      rc = decode_DIS_Status(sfds, request);
+      rc = tcp_decode_DIS_Status(sfds, request);
 
       break;
 
@@ -273,7 +276,7 @@ int dis_request_read(
 
     case PBS_BATCH_LocateJob:
 
-      rc = decode_DIS_JobId(sfds, request->rq_ind.rq_locate);
+      rc = tcp_decode_DIS_JobId(sfds, request->rq_ind.rq_locate);
 
       break;
 
@@ -281,7 +284,7 @@ int dis_request_read(
 
     case PBS_BATCH_ReleaseJob:
 
-      rc = decode_DIS_Manage(sfds, request);
+      rc = tcp_decode_DIS_Manage(sfds, request);
 
       break;
 
@@ -289,7 +292,7 @@ int dis_request_read(
 
     case PBS_BATCH_OrderJob:
 
-      rc = decode_DIS_MoveJob(sfds, request);
+      rc = tcp_decode_DIS_MoveJob(sfds, request);
 
       break;
 
@@ -299,7 +302,7 @@ int dis_request_read(
 
     case PBS_BATCH_StageIn:
 
-      rc = decode_DIS_RunJob(sfds, request);
+      rc = tcp_decode_DIS_RunJob(sfds, request);
 
       break;
 
@@ -309,7 +312,7 @@ int dis_request_read(
 
       CLEAR_HEAD(request->rq_ind.rq_select);
 
-      rc = decode_DIS_svrattrl(sfds, &request->rq_ind.rq_select);
+      rc = tcp_decode_DIS_svrattrl(sfds, &request->rq_ind.rq_select);
 
       break;
 
@@ -320,13 +323,13 @@ int dis_request_read(
     case PBS_BATCH_StatusSvr:
       /* DIAGTODO: add PBS_BATCH_StatusDiag */
 
-      rc = decode_DIS_Status(sfds, request);
+      rc = tcp_decode_DIS_Status(sfds, request);
 
       break;
 
     case PBS_BATCH_TrackJob:
 
-      rc = decode_DIS_TrackJob(sfds, request);
+      rc = tcp_decode_DIS_TrackJob(sfds, request);
 
       break;
 
@@ -336,25 +339,25 @@ int dis_request_read(
 
     case PBS_BATCH_ReleaseResc:
 
-      rc = decode_DIS_Rescl(sfds, request);
+      rc = tcp_decode_DIS_Rescl(sfds, request);
 
       break;
 
     case PBS_BATCH_RegistDep:
 
-      rc = decode_DIS_Register(sfds, request);
+      rc = tcp_decode_DIS_Register(sfds, request);
 
       break;
 
     case PBS_BATCH_AuthenUser:
 
-      rc = decode_DIS_Authen(sfds, request);
+      rc = tcp_decode_DIS_Authen(sfds, request);
 
       break;
 
     case PBS_BATCH_JobObit:
 
-      rc = decode_DIS_JobObit(sfds, request);
+      rc = tcp_decode_DIS_JobObit(sfds, request);
 
       break;
 
@@ -362,11 +365,16 @@ int dis_request_read(
 
       /* pbs_mom services */
 
+    case PBS_BATCH_ReturnFiles:
+      rc = tcp_decode_DIS_ReturnFiles(sfds, request);
+
+      break;
+
     case PBS_BATCH_CopyFiles:
 
     case PBS_BATCH_DelFiles:
 
-      rc = decode_DIS_CopyFiles(sfds, request);
+      rc = tcp_decode_DIS_CopyFiles(sfds, request);
 
       break;
 
@@ -375,7 +383,7 @@ int dis_request_read(
     default:
 
       sprintf(log_buffer, "%s: %d from %s",
-              msg_nosupport,
+              pbse_to_txt(PBSE_NOSUP),
               request->rq_type,
               request->rq_user);
 
@@ -394,7 +402,7 @@ int dis_request_read(
     {
     /* Decode the Request Extension, if present */
 
-    if ((rc = decode_DIS_ReqExtend(sfds, request)))
+    if ((rc = tcp_decode_DIS_ReqExtend(sfds, request)))
       {
       sprintf(log_buffer, "req extension bad, dis error %d (%s), type=%s",
               rc,
@@ -446,7 +454,7 @@ int DIS_reply_read(
   {
   DIS_tcp_setup(sock);
 
-  return(decode_DIS_replySvr(sock, preply));
+  return(tcp_decode_DIS_replySvr(sock, preply));
   }
 
 /* END dis_read.c */
