@@ -134,6 +134,8 @@ int issue_to_svr A_((char *, struct batch_request *, void (*f)(struct work_task
  *
  * Unlike issue_to_svr(), a failed connection is not retried.
  * The calling routine typically handles this problem.
+ *
+ * @see XXX() - routine which processes request on the MOM
  */
 
 int relay_to_mom(
@@ -143,8 +145,6 @@ int relay_to_mom(
   void (*func) A_((struct work_task *)))
 
   {
-  extern char *PAddrToString(pbs_net_t *);
-
   char *id = "relay_to_mom";
 
   int conn; /* a client style connection handle */
@@ -163,7 +163,7 @@ int relay_to_mom(
   if (LOGLEVEL >= 7)
     {
     sprintf(log_buffer, "momaddr=%s",
-            PAddrToString(&momaddr));
+            netaddr_pbs_net_t(momaddr));
 
     log_record(
       PBSEVENT_SCHED,
@@ -200,6 +200,7 @@ int relay_to_mom(
 
 
 
+
 /*
  * reissue_to_svr - recall issue_to_svr() after a delay to retry sending
  * a request that failed for a temporary reason
@@ -347,7 +348,7 @@ void release_req(
  * issue_request - issue a batch request to another server or to a MOM
  * or even to ourself!
  *
- * If the request is meant for this every server, then
+ * If the request is meant for this very server, then
  *  Set up work-task of type WORK_Deferred_Local with a dummy
  *  connection handle (PBS_LOCAL_CONNECTION).
  *
@@ -371,10 +372,10 @@ void release_req(
 
 int issue_Drequest(
 
-  int        conn,
+  int          conn,
   struct batch_request *request,
   void (*func) A_((struct work_task *)),
-  struct work_task  **ppwt)
+  struct work_task    **ppwt)
 
   {
 
@@ -467,6 +468,19 @@ int issue_Drequest(
 
       break;
 
+    case PBS_BATCH_CheckpointJob:
+
+      rc = PBSD_mgr_put(
+             conn,
+             PBS_BATCH_CheckpointJob,
+             MGR_CMD_SET,
+             MGR_OBJ_JOB,
+             request->rq_ind.rq_hold.rq_orig.rq_objname,
+             NULL,
+             NULL);
+
+      break;
+
     case PBS_BATCH_MessJob:
 
       rc = PBSD_msg_put(
@@ -480,6 +494,8 @@ int issue_Drequest(
 
     case PBS_BATCH_ModifyJob:
 
+    case PBS_BATCH_AsyModifyJob:
+
       attrl_fixlink(&request->rq_ind.rq_modify.rq_attr);
 
       patrl = (struct attropl *) & ((struct svrattrl *)GET_NEXT(
@@ -487,7 +503,7 @@ int issue_Drequest(
 
       rc = PBSD_mgr_put(
              conn,
-             PBS_BATCH_ModifyJob,
+             request->rq_type,
              MGR_CMD_SET,
              MGR_OBJ_JOB,
              request->rq_ind.rq_modify.rq_objname,
@@ -498,13 +514,13 @@ int issue_Drequest(
 
     case PBS_BATCH_Rerun:
 
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_Rerun, msg_daemonname)))
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_Rerun, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_JobId(sock, request->rq_ind.rq_rerun)))
+      if ((rc = tcp_encode_DIS_JobId(sock, request->rq_ind.rq_rerun)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
@@ -513,13 +529,13 @@ int issue_Drequest(
 
     case PBS_BATCH_RegistDep:
 
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_RegistDep, msg_daemonname)))
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_RegistDep, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_Register(sock, request)))
+      if ((rc = tcp_encode_DIS_Register(sock, request)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
@@ -527,29 +543,49 @@ int issue_Drequest(
       break;
 
     case PBS_BATCH_SignalJob:
-      rc =  PBSD_sig_put(conn,
-                         request->rq_ind.rq_signal.rq_jid,
-                         request->rq_ind.rq_signal.rq_signame,
-                         (char *)0);
+
+      rc = PBSD_sig_put(
+             conn,
+             request->rq_ind.rq_signal.rq_jid,
+             request->rq_ind.rq_signal.rq_signame,
+             NULL);
 
       break;
 
     case PBS_BATCH_StatusJob:
-      rc =  PBSD_status_put(conn,
-                            PBS_BATCH_StatusJob,
-                            request->rq_ind.rq_status.rq_id,
-                            (struct attrl *)0, (char *)0);
+
+      rc = PBSD_status_put(
+             conn,
+             PBS_BATCH_StatusJob,
+             request->rq_ind.rq_status.rq_id,
+             NULL,
+             NULL);
 
       break;
 
     case PBS_BATCH_TrackJob:
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_TrackJob, msg_daemonname)))
+
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_TrackJob, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_TrackJob(sock, request)))
+      if ((rc = tcp_encode_DIS_TrackJob(sock, request)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
+        break;
+
+      rc = DIS_tcp_wflush(sock);
+
+      break;
+
+    case PBS_BATCH_ReturnFiles:
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_ReturnFiles, msg_daemonname)))
+        break;
+
+      if ((rc = tcp_encode_DIS_ReturnFiles(sock, request)))
+        break;
+
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
@@ -558,13 +594,13 @@ int issue_Drequest(
 
     case PBS_BATCH_CopyFiles:
 
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_CopyFiles, msg_daemonname)))
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_CopyFiles, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_CopyFiles(sock, request)))
+      if ((rc = tcp_encode_DIS_CopyFiles(sock, request)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
@@ -573,13 +609,13 @@ int issue_Drequest(
 
     case PBS_BATCH_DelFiles:
 
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_DelFiles, msg_daemonname)))
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_DelFiles, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_CopyFiles(sock, request)))
+      if ((rc = tcp_encode_DIS_CopyFiles(sock, request)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
@@ -592,13 +628,13 @@ int issue_Drequest(
 
       /* who is sending obit request? */
 
-      if ((rc = encode_DIS_ReqHdr(sock, PBS_BATCH_JobObit, msg_daemonname)))
+      if ((rc = tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_JobObit, msg_daemonname)))
         break;
 
-      if ((rc = encode_DIS_JobObit(sock, request)))
+      if ((rc = tcp_encode_DIS_JobObit(sock, request)))
         break;
 
-      if ((rc = encode_DIS_ReqExtend(sock, 0)))
+      if ((rc = tcp_encode_DIS_ReqExtend(sock, 0)))
         break;
 
       rc = DIS_tcp_wflush(sock);
