@@ -7,7 +7,7 @@
 * ---------------------------------------------------------------------------
 * For a license to use or redistribute the OpenPBS software under conditions
 * other than those described below, or to purchase support for this software,
-* Please contact Veridian Systems, PBS Products Department ("Licensor") at:
+* please contact Veridian Systems, PBS Products Department ("Licensor") at:
 *
 *    www.OpenPBS.org  +1 650 967-4675                  sales@OpenPBS.org
 *                        877 902-4PBS (US toll-free)
@@ -103,7 +103,7 @@
 #include "pbs_nodes.h"
 #include "list_link.h"
 #include "attribute.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "server.h"
 #include "credential.h"
 #include "batch_request.h"
@@ -111,6 +111,7 @@
 #include "log.h"
 #include "svrfunc.h"
 #include "pbs_proto.h"
+#include "csv.h"
 
 #ifndef PBS_MOM
 #include "array.h"
@@ -142,7 +143,6 @@ extern tlist_head svr_newjobs;
 extern time_t    time_now;
 extern char  *msg_err_noqueue;
 extern char  *msg_err_malloc;
-extern char  *msg_reqbadhost;
 extern char  *msg_request;
 #ifndef PBS_MOM
 extern char            server_name[];
@@ -175,6 +175,7 @@ void req_rdytocommit(struct batch_request *preq);
 void req_commit(struct batch_request *preq);
 void req_deletejob(struct batch_request *preq);
 void req_holdjob(struct batch_request *preq);
+void req_checkpointjob(struct batch_request *preq);
 void req_messagejob(struct batch_request *preq);
 void req_modifyjob(struct batch_request *preq);
 #ifndef PBS_MOM
@@ -195,6 +196,8 @@ void req_jobobit(struct batch_request *preq);
 void req_stagein(struct batch_request *preq);
 
 void req_deletearray(struct batch_request *preq);
+void req_holdarray(struct batch_request *preq);
+
 #endif
 
 /* END request processing prototypes */
@@ -408,7 +411,7 @@ void process_request(
     char tmpLine[1024];
 
     sprintf(log_buffer, "%s: %lu",
-            msg_reqbadhost,
+            pbse_to_txt(PBSE_BADHOST),
             get_connectaddr(sfds));
 
     LOG_EVENT(PBSEVENT_DEBUG, PBS_EVENTCLASS_REQUEST, "", log_buffer);
@@ -541,7 +544,54 @@ void process_request(
       return;
       }
 
-    request->rq_perm = svr_get_privilege(request->rq_user, request->rq_host);
+    /*
+     * pbs_mom and checkpoint restart scripts both need the authority to do
+     * alters and releases on checkpointable jobs.  Allow manager permission
+     * for root on the jobs execution node.
+     */
+     
+    if (((request->rq_type == PBS_BATCH_ModifyJob) ||
+        (request->rq_type == PBS_BATCH_ReleaseJob)) &&
+        (strcmp(request->rq_user, PBS_DEFAULT_ADMIN) == 0))
+      {
+      job *pjob;
+      char *dptr;
+      int skip = FALSE;
+      char short_host[PBS_MAXHOSTNAME+1];
+
+      /* make short host name */
+
+      strcpy(short_host, request->rq_host);
+      if ((dptr = strchr(short_host, '.')) != NULL)
+        {
+        *dptr = '\0';
+        }
+      
+      if (((pjob = find_job(request->rq_ind.rq_modify.rq_objname)) != (job *)0) &&
+          (pjob->ji_qs.ji_state == JOB_STATE_RUNNING))
+        {
+
+        if ((pjob->ji_wattr[(int)JOB_ATR_checkpoint].at_flags & ATR_VFLAG_SET) &&
+          ((csv_find_string(pjob->ji_wattr[(int)JOB_ATR_checkpoint].at_val.at_str, "s") != NULL) ||
+          (csv_find_string(pjob->ji_wattr[(int)JOB_ATR_checkpoint].at_val.at_str, "c") != NULL) ||
+          (csv_find_string(pjob->ji_wattr[(int)JOB_ATR_checkpoint].at_val.at_str, "enabled") != NULL)) &&
+          (strstr(pjob->ji_wattr[(int)JOB_ATR_exec_host].at_val.at_str, short_host) != NULL))
+          {
+
+          request->rq_perm = svr_get_privilege(request->rq_user, server_host);
+          skip = TRUE;
+
+          }
+        }
+      if (!skip)
+        {
+        request->rq_perm = svr_get_privilege(request->rq_user, request->rq_host);
+        }
+      }
+    else
+      {
+      request->rq_perm = svr_get_privilege(request->rq_user, request->rq_host);
+      }
     }  /* END else (svr_conn[sfds].cn_authen == PBS_NET_CONN_FROM_PRIVIL) */
 
   /* if server shutting down, disallow new jobs and new running */
@@ -550,19 +600,12 @@ void process_request(
     {
     switch (request->rq_type)
       {
-
       case PBS_BATCH_AsyrunJob:
-
       case PBS_BATCH_JobCred:
-
       case PBS_BATCH_MoveJob:
-
       case PBS_BATCH_QueueJob:
-
       case PBS_BATCH_RunJob:
-
       case PBS_BATCH_StageIn:
-
       case PBS_BATCH_jobscript:
 
         req_reject(PBSE_SVRDOWN, 0, request, NULL, NULL);
@@ -599,7 +642,7 @@ void process_request(
 
     if (!tfind(svr_conn[sfds].cn_addr, &okclients))
       {
-      sprintf(log_buffer,"request type %s from host %s rejected (host not authorized)",
+      sprintf(log_buffer, "request type %s from host %s rejected (host not authorized)",
         reqtype_to_txt(request->rq_type),
         request->rq_host);
 
@@ -609,7 +652,7 @@ void process_request(
         id,
         log_buffer);
 
-      req_reject(PBSE_BADHOST,0,request,NULL,"request not authorized");
+      req_reject(PBSE_BADHOST, 0, request, NULL, "request not authorized");
 
       close_client(sfds);
 
@@ -648,7 +691,7 @@ void process_request(
    * the request struture.
    */
 
-  dispatch_request(sfds,request);
+  dispatch_request(sfds, request);
 
   return;
   }  /* END process_request() */
@@ -747,9 +790,26 @@ void dispatch_request(
       break;
 
     case PBS_BATCH_HoldJob:
-
+#ifdef PBS_MOM
       req_holdjob(request);
 
+#else
+      if (is_array(request->rq_ind.rq_hold.rq_orig.rq_objname))
+        {
+        req_holdarray(request);
+        }
+      else
+        {
+        req_holdjob(request);
+        }
+
+#endif
+      break;
+
+    case PBS_BATCH_CheckpointJob:
+
+      req_checkpointjob(request);
+
       break;
 
 #ifndef PBS_MOM
@@ -774,6 +834,8 @@ void dispatch_request(
 
       break;
 
+    case PBS_BATCH_AsyModifyJob:
+
     case PBS_BATCH_ModifyJob:
 
       req_modifyjob(request);
@@ -836,7 +898,12 @@ void dispatch_request(
 
     case PBS_BATCH_SelStat:
 
-      req_selectjobs(request);
+      /* handle special 'truncated' keyword */
+
+      if (!strncasecmp(request->rq_ind.rq_status.rq_id, "truncated", strlen("truncated")))
+        req_stat_job(request);
+      else
+        req_selectjobs(request);
 
       break;
 
@@ -922,6 +989,12 @@ void dispatch_request(
 
 #else /* MOM only functions */
 
+    case PBS_BATCH_ReturnFiles:
+
+      req_returnfiles(request);
+
+      break;
+
     case PBS_BATCH_CopyFiles:
 
       req_cpyfile(request);
@@ -1019,9 +1092,7 @@ struct batch_request *alloc_br(
   req->rq_orgconn = -1;  /* indicate not connected */
   req->rq_time = time_now;
   req->rq_reply.brp_choice = BATCH_REPLY_CHOICE_NULL;
-#ifdef AUTORUN_JOBS
-  req->rq_noreply = FALSE;
-#endif
+  req->rq_noreply = FALSE;  /* indicate reply is needed */
 
   append_link(&svr_requests, &req->rq_link, req);
 
@@ -1120,7 +1191,6 @@ void free_br(
 
   switch (preq->rq_type)
     {
-
     case PBS_BATCH_QueueJob:
 
       free_attrlist(&preq->rq_ind.rq_queuejob.rq_attr);
@@ -1149,6 +1219,12 @@ void free_br(
 
       break;
 
+    case PBS_BATCH_CheckpointJob:
+
+      freebr_manage(&preq->rq_ind.rq_manager);
+
+      break;
+
     case PBS_BATCH_MessJob:
 
       if (preq->rq_ind.rq_message.rq_text)
@@ -1158,6 +1234,8 @@ void free_br(
 
     case PBS_BATCH_ModifyJob:
 
+    case PBS_BATCH_AsyModifyJob:
+
       freebr_manage(&preq->rq_ind.rq_modify);
 
       break;
