@@ -90,6 +90,7 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <signal.h>
+#include <ctype.h>
 #include "libpbs.h"
 #include "server_limits.h"
 #include "list_link.h"
@@ -98,7 +99,7 @@
 #include "server.h"
 #include "credential.h"
 #include "batch_request.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "queue.h"
 #include "pbs_error.h"
 #include "acct.h"
@@ -111,10 +112,9 @@
 extern char *msg_deletejob;
 extern char *msg_delrunjobsig;
 extern char *msg_manager;
-extern char *msg_unkjobid;
 extern char *msg_permlog;
 extern char *msg_badstate;
-extern tlist_head	svr_alljobs;   /* list of all jobs in server       */
+tlist_head	svr_alljobs;           /* list of all jobs in server       */
 
 extern struct server server;
 extern time_t time_now;
@@ -134,6 +134,7 @@ static void purge_completed_jobs A_((struct batch_request *));
 
 struct work_task *apply_job_delete_nanny A_((struct job *, int));
 int has_job_delete_nanny A_((struct job *));
+void change_restart_comment_if_needed A_((struct job *));
 
 /* Private Data Items */
 
@@ -270,7 +271,7 @@ void req_deletejob(
 
   /* The way this is implemented, if the user enters the command "qdel -p <jobid>",
    * they can then delete jobs other than their own since the authorization
-   * checks are made below in chk_job_request. This should be fixed.
+   * checks are made below in chk_job_request. This should probably be fixed.
    */
 
   if (forced_jobpurge(preq) != 0)
@@ -489,6 +490,13 @@ jump:
       }
     }
 
+  if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHECKPOINT_FILE) != 0)
+    {
+    /* job has restart file at mom, change restart comment if failed */
+
+    change_restart_comment_if_needed(pjob);
+    }
+
   if (pjob->ji_qs.ji_state == JOB_STATE_RUNNING)
     {
     /*
@@ -531,10 +539,10 @@ jump:
     return;
     }  /* END if (pjob->ji_qs.ji_state == JOB_STATE_RUNNING) */
 
-  if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHKPT) != 0)
+  if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHECKPOINT_FILE) != 0)
     {
     /* job has restart file at mom, do end job processing */
-
+    
     svr_setjobstate(pjob, JOB_STATE_EXITING, JOB_SUBSTATE_EXITING);
 
     pjob->ji_momhandle = -1;
@@ -560,11 +568,31 @@ jump:
     {
     /*
      * the job is not transitting (though it may have been) and
-     * is not running, so abort it.
+     * is not running, so put in into a complete state.
      */
 
-    job_abt(&pjob, Msg);
-    }  /* END else if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHKPT) != 0) */
+    struct work_task *ptask;
+    struct pbs_queue *pque;
+    int  KeepSeconds = 0;
+
+    svr_setjobstate(pjob, JOB_STATE_COMPLETE, JOB_SUBSTATE_COMPLETE);
+
+    if ((pque = pjob->ji_qhdr) && (pque != NULL))
+      {
+      pque->qu_numcompleted++;
+      }
+
+    KeepSeconds = attr_ifelse_long(
+                    &pque->qu_attr[(int)QE_ATR_KeepCompleted],
+                    &server.sv_attr[(int)SRV_ATR_KeepCompleted],
+                    0);
+    ptask = set_task(WORK_Timed, time_now + KeepSeconds, on_job_exit, pjob);
+
+    if (ptask != NULL)
+      {
+      append_link(&pjob->ji_svrtask, &ptask->wt_linkobj, ptask);
+      }
+    }  /* END else if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHECKPOINT_FILE) != 0) */
 
   reply_ack(preq);
 
@@ -573,6 +601,52 @@ jump:
 
 
 
+/*
+ * change_restart_comment_if_needed - If job has restarted then the checkpoint
+ * restart status attribute is used in on_job_exit() to reque/hold job on failure.
+ * If we are deleting then we change the first charcter to lower case so
+ * it does normal processing in on_job_exit().
+ */
+
+void change_restart_comment_if_needed(
+
+  struct job *pjob)
+
+  {
+  if ((pjob->ji_wattr[(int)JOB_ATR_start_count].at_val.at_long > 1) &&
+    (pjob->ji_wattr[(int)JOB_ATR_checkpoint_restart_status].at_flags & ATR_VFLAG_SET))
+    {
+      char *token1 = NULL;
+      char *token2 = NULL;
+      char commentMsg[25];
+      char *ptr;
+      
+      strncpy(commentMsg,
+        pjob->ji_wattr[(int)JOB_ATR_checkpoint_restart_status].at_val.at_str, 24);
+      
+      token1 = strtok(commentMsg," ");
+      if (token1 != NULL)
+        token2 = strtok(NULL," ");
+      
+      if ((token2 != NULL) && 
+        ((memcmp(token2,"failure",7) == 0) || (memcmp(token2,"restarted",9) == 0)))
+        {
+        ptr = pjob->ji_wattr[(int)JOB_ATR_checkpoint_restart_status].at_val.at_str;
+        if (isupper(*ptr))
+          {
+            *ptr = tolower(*ptr);
+            pjob->ji_wattr[(int)JOB_ATR_checkpoint_restart_status].at_flags
+              |= ATR_VFLAG_SET;
+            pjob->ji_modified = 1;
+          }
+        }
+    }
+
+  return;
+  }
+
+
+ 
 
 
 /*
@@ -763,7 +837,7 @@ static int forced_jobpurge(
       PBSEVENT_DEBUG,
       PBS_EVENTCLASS_JOB,
       preq->rq_ind.rq_delete.rq_objname,
-      msg_unkjobid);
+      pbse_to_txt(PBSE_UNKJOBID));
 
     req_reject(PBSE_UNKJOBID, 0, preq, NULL, NULL);
 
@@ -860,12 +934,6 @@ void remove_job_delete_nanny(
 
   struct work_task *pwtiter, *pwtdel;
 
-  if (pjob->ji_svrtask.ll_next == NULL)
-    {
-    /* no nanny, nothing to delete */
-    return;
-    }
-
   pwtiter = (struct work_task *)GET_NEXT(pjob->ji_svrtask);
 
   while (pwtiter != NULL)
@@ -1164,8 +1232,8 @@ void purge_completed_jobs(
       }
     }
 
-  reply_ack(preq);
 
+  reply_ack(preq);
   return;
   } /* END purge_completed_jobs() */
 
