@@ -86,7 +86,7 @@
 #include "attribute.h"
 #include "server_limits.h"
 #include "server.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "credential.h"
 #include "batch_request.h"
 #include "pbs_error.h"
@@ -99,9 +99,7 @@
 extern struct credential conn_credent[PBS_NET_MAX_CONNECTIONS];
 extern char *pbs_o_host;
 extern char  server_host[];
-extern char *msg_badstate;
 extern char *msg_permlog;
-extern char *msg_unkjobid;
 extern time_t time_now;
 
 extern char *PJobState[];
@@ -188,10 +186,13 @@ int svr_authorize_jobreq(
   get_jobowner(pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str, owner);
 
   return svr_authorize_req(preq, owner, get_variable(pjob, pbs_o_host));
-
   }  /* END svr_authorize_jobreq() */
 
 
+
+
+
+
 int svr_authorize_req(
 
   struct batch_request *preq,
@@ -224,6 +225,9 @@ int svr_authorize_req(
   }
 
 
+
+
+
 /*
  * svr_get_privilege - get privilege level of a user.
  *
@@ -241,93 +245,38 @@ int svr_authorize_req(
  * attribute.h.
  */
 
-
 int svr_get_privilege(
 
   char *user,  /* I */
   char *host)  /* I */
 
   {
-  char  id[] = "svr_get_privilege";
   int   is_root = 0;
   int   priv = (ATR_DFLAG_USRD | ATR_DFLAG_USWR);
   int   num_host_chars;
   char  uh[PBS_MAXUSER + PBS_MAXHOSTNAME + 2];
-  char  host_no_port[PBS_MAXHOSTNAME+1];
-  char *colon_loc = NULL;
+  char  host_no_port[1024];
 
-  if(!user)
-    {
-
-    sprintf(log_buffer, "Invalid user: %s", "null");
-
-    log_record(
-      PBSEVENT_SECURITY,
-      PBS_EVENTCLASS_SERVER,
-      id,
-      log_buffer);
-
-
-    return(0);
-    }
-
-  /* user name cannot be longer than PBS_MAXUSER*/
-  if(strlen(user) > PBS_MAXUSER)
-    {
-    sprintf(log_buffer, "Invalid user: %s", user);
-
-    log_record(
-      PBSEVENT_SECURITY,
-      PBS_EVENTCLASS_SERVER,
-      id,
-      log_buffer);
-     
-    return(0);
-    }
-
-  if(!host)
-    return(0);
-
-  colon_loc = strchr(host, ':');
+  char *colon_loc = strchr(host, ':');
 
   /* if the request host has port information in it, we want to strip it out */
 
   if (colon_loc == NULL) 
     {
     /* no colon found */
-    num_host_chars = strlen(host);
-
-    sprintf(host_no_port, "%s", host);
+    num_host_chars = sizeof(host_no_port);
     }
   else
     {
     num_host_chars = colon_loc - host;
-
-    /* actually remove the colon for host_no_port */
-    *colon_loc = '\0';
-    sprintf(host_no_port,"%s",host);
-    *colon_loc = ':';
     }
 
-  /* num_host_chars cannot be more than PBS_MAXHOSTNAME */
-  if (num_host_chars > PBS_MAXHOSTNAME)
-    {
-    snprintf(log_buffer, LOG_BUF_SIZE, "Invalid host: %s", host);
-    /* log_buffer is big but just in case host was really long we need to
-       null terminate the last byte. strncpy will copy LOG_BUF_SIZE but
-       not null terminate the array if host is larger. */
-    log_buffer[LOG_BUF_SIZE - 1] = 0;
+  strcpy(uh, user);
+  strcat(uh, "@");
+  strcat(uh, host);
 
-    log_record(
-      PBSEVENT_SECURITY,
-      PBS_EVENTCLASS_SERVER,
-      id,
-      log_buffer);
-
-    return(0);
-    }
-
-  sprintf(uh, "%s@%s", user, host);
+  strncpy(host_no_port,host,num_host_chars);
+  host_no_port[num_host_chars] = 0;
 
   /* NOTE:  enable case insensitive host check (CRI) */
 
@@ -367,6 +316,7 @@ int svr_get_privilege(
 
 
 
+
 /*
  * authenticate_user - authenticate user by checking name against credential
  *         provided on connection via Authenticate User request.
@@ -477,7 +427,7 @@ job *chk_job_request(
       PBSEVENT_DEBUG,
       PBS_EVENTCLASS_JOB,
       jobid,
-      msg_unkjobid);
+      pbse_to_txt(PBSE_UNKJOBID));
 
     req_reject(PBSE_UNKJOBID, 0, preq, NULL, "cannot locate job");
 
@@ -525,7 +475,7 @@ job *chk_job_request(
         char tmpLine[1024];
 
         sprintf(log_buffer, "%s %s",
-                msg_badstate,
+                pbse_to_txt(PBSE_BADSTATE),
                 PJobState[pjob->ji_qs.ji_state]);
 
         log_event(
