@@ -141,8 +141,6 @@ int svr_connect(
   enum conn_type cntype)
 
   {
-  extern char *PAddrToString(pbs_net_t *);
-
   char         EMsg[1024];
 
   static char *id = "svr_connect";
@@ -157,7 +155,7 @@ int svr_connect(
     {
     sprintf(log_buffer, "attempting connect to %s %s port %d",
             (hostaddr == pbs_server_addr) ? "server" : "host",
-            ((int)hostaddr != 0) ? PAddrToString(&hostaddr) : "localhost",
+            ((int)hostaddr != 0) ? netaddr_pbs_net_t(hostaddr) : "localhost",
             port);
 
     log_event(
@@ -198,7 +196,7 @@ int svr_connect(
     return(PBS_NET_RC_RETRY);
     }
 
-  /* establish UDP socket connection to specified host */
+  /* establish socket connection to specified host */
 
   sock = client_to_svr(hostaddr, port, 1, EMsg);
 
@@ -314,7 +312,7 @@ void svr_disconnect(
 
     DIS_tcp_setup(sock);
 
-    if ((encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user) == 0) &&
+    if ((tcp_encode_DIS_ReqHdr(sock, PBS_BATCH_Disconnect, pbs_current_user) == 0) &&
         (DIS_tcp_wflush(sock) == 0))
       {
       /* wait for other server to close connection */
@@ -372,13 +370,9 @@ int socket_to_handle(
       continue;
 
     connection[i].ch_stream = 0;
-
     connection[i].ch_inuse  = 1;
-
     connection[i].ch_errno  = 0;
-
     connection[i].ch_socket = sock;
-
     connection[i].ch_errtxt = 0;
 
     /* SUCCESS - save handle for later close */
