@@ -89,15 +89,14 @@
  * job_set_wait()     - set event for when job's wait time ends
  * get_variable()     - get value of a single environ variable of a job
  * prefix_std_file()  - build the fully prefixed default name for std e/o
- * add_std_filename() - add the default name for std e/o
  * get_jobowner()     - get job owner name without @host suffix
  * set_resc_deflt()   - set unspecified resource_limit to default values
  * set_statechar()    - set the job state attribute character value
  *
  * Private functions
  * chk_svr_resc_limit() - check job requirements againt queue/server limits
- * default_std()    - make the default name for standard out/error
- * eval_chkpnt()    - insure job checkpoint .ge. queues min. time
+ * default_std()      - make the default name for standard out/error
+ * eval_checkpoint()  - insure job checkpoint .ge. queues min. time
  * set_deflt_resc()   - set unspecified resource_limit to default values
  * job_wait_over()    - event handler for job_set_wait()
  */
@@ -119,7 +118,7 @@
 #include "resource.h"
 #include "server.h"
 #include "queue.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "work_task.h"
 #include "pbs_error.h"
 #include "log.h"
@@ -132,7 +131,7 @@
 /* Private Functions */
 
 static void default_std A_((job *, int key, char * to));
-static void eval_chkpnt A_((attribute *j, attribute *q));
+static void eval_checkpoint A_((attribute *j, attribute *q));
 
 /* Global Data Items: */
 
@@ -250,6 +249,13 @@ const char *PJobSubState[] =
   "RERUN1",                 /* job is rerun, stageout phase */
   "RERUN2",                 /* job is rerun, delete files stage */
   "RERUN3",                 /* job is rerun, mom delete job */
+  "SUBSTATE64",
+  "SUBSTATE65",
+  "SUBSTATE66",
+  "SUBSTATE67",
+  "SUBSTATE68",
+  "SUBSTATE69",
+  "RETURNSTD",             /* returning stderr/stdout files to server spool */
   NULL
   };
 
@@ -285,7 +291,7 @@ int svr_enquejob(
   /* add job to server's 'all job' list and update server counts */
 
 #ifndef NDEBUG
-  sprintf(log_buffer,"enqueuing into %s, state %x hop %ld",
+  sprintf(log_buffer, "enqueuing into %s, state %x hop %ld",
     pque->qu_qs.qu_name,
     pjob->ji_qs.ji_state,
     pjob->ji_wattr[(int)JOB_ATR_hopcount].at_val.at_long);
@@ -320,8 +326,8 @@ int svr_enquejob(
     /* link after 'current' job in server's list */
 
     insert_link(
-      &pjcur->ji_alljobs, 
-      &pjob->ji_alljobs, 
+      &pjcur->ji_alljobs,
+      &pjob->ji_alljobs,
       pjob,
       LINK_INSET_AFTER);
     }
@@ -349,13 +355,13 @@ int svr_enquejob(
     {
     /* link first in list */
 
-    insert_link(&pque->qu_jobs,&pjob->ji_jobque,pjob,LINK_INSET_AFTER);
+    insert_link(&pque->qu_jobs, &pjob->ji_jobque, pjob, LINK_INSET_AFTER);
     }
   else
     {
     /* link after 'current' job in list */
 
-    insert_link(&pjcur->ji_jobque,&pjob->ji_jobque,pjob,LINK_INSET_AFTER);
+    insert_link(&pjcur->ji_jobque, &pjob->ji_jobque, pjob, LINK_INSET_AFTER);
     }
 
   /* update counts: queue and queue by state */
@@ -386,10 +392,10 @@ int svr_enquejob(
 
     /* issue enqueued accounting record */
 
-    sprintf(log_buffer,"queue=%s",
+    sprintf(log_buffer, "queue=%s",
       pque->qu_qs.qu_name);
 
-    account_record(PBS_ACCT_QUEUE,pjob,log_buffer);
+    account_record(PBS_ACCT_QUEUE, pjob, log_buffer);
     }
 
   /*
@@ -397,7 +403,7 @@ int svr_enquejob(
    * first with queue defaults, then with server defaults
    */
 
-  set_resc_deflt(pjob,NULL);
+  set_resc_deflt(pjob, NULL);
 
   /* See if we need to do anything special based on type of queue */
 
@@ -414,9 +420,9 @@ int svr_enquejob(
 
     /* check the job checkpoint against the queue's min */
 
-    eval_chkpnt(
-      &pjob->ji_wattr[(int)JOB_ATR_chkpnt],
-      &pque->qu_attr[(int)QE_ATR_ChkptMim]);
+    eval_checkpoint(
+      &pjob->ji_wattr[(int)JOB_ATR_checkpoint],
+      &pque->qu_attr[(int)QE_ATR_checkpoint_min]);
 
     /* do anything needed doing regarding job dependencies */
 
@@ -765,6 +771,48 @@ char *get_variable(
 
 
 
+/*
+ * get_resource - find a resource (value) entry in the queue or server list
+ *
+ * Returns: pointer to struct resource or NULL
+ */
+
+resource *get_resource(
+
+  attribute    *p_queattr,  /* I */
+  attribute    *p_svrattr,  /* I */
+  resource_def *rscdf,      /* I */
+  int          *fromQueue)  /* O */
+
+  {
+  resource *pr;
+
+  pr = find_resc_entry(p_queattr, rscdf);
+
+  if ((pr == NULL) || ((pr->rs_value.at_flags & ATR_VFLAG_SET) == 0))
+    {
+    /* queue limit not set, check server's */
+
+    pr = find_resc_entry(p_svrattr, rscdf);
+
+    if ((pr != NULL) && (pr->rs_value.at_flags & ATR_VFLAG_SET))
+      {
+      *fromQueue = 0;
+      }
+    }
+  else
+    {
+    /* queue limit is set, use it */
+
+    *fromQueue = 1;
+    }
+
+  return(pr);
+  }  /* END get_resource() */
+
+
+
+
 /*
  * compare the job resource limit against the system limit
  * unless a queue limit exists, it takes priority
@@ -776,9 +824,8 @@ char *get_variable(
 static void chk_svr_resc_limit(
 
   attribute *jobatr, /* I */
-  attribute *queatr, /* I */
-  attribute *svratr, /* I */
-  int      qtype,  /* I */
+  pbs_queue *pque,   /* I */
+  int       qtype,   /* I */
   char      *EMsg)   /* O (optional,minsize=1024) */
 
   {
@@ -800,10 +847,16 @@ static void chk_svr_resc_limit(
   int       MPPWidth = 0;
   int       PPN = 0;
 
+  long      mpp_nppn = 0;
+  long      mpp_width = 0;
+  long      mpp_nodect = 0;
+  resource  *mppnodect_resource = NULL;
+
   static resource_def *noderesc     = NULL;
   static resource_def *needresc     = NULL;
   static resource_def *nodectresc   = NULL;
   static resource_def *mppwidthresc = NULL;
+  static resource_def *mppnppn      = NULL;
 
   static time_t UpdateTime = 0;
   static time_t now;
@@ -821,10 +874,11 @@ static void chk_svr_resc_limit(
 
     /* NOTE:  to optimize, only update once per 30 seconds */
 
-    noderesc     = find_resc_def(svr_resc_def,"nodes",     svr_resc_size);
-    needresc     = find_resc_def(svr_resc_def,"neednodes", svr_resc_size);
-    nodectresc   = find_resc_def(svr_resc_def,"nodect",    svr_resc_size);
-    mppwidthresc = find_resc_def(svr_resc_def,"mppwidth",  svr_resc_size);
+    noderesc     = find_resc_def(svr_resc_def, "nodes",     svr_resc_size);
+    needresc     = find_resc_def(svr_resc_def, "neednodes", svr_resc_size);
+    nodectresc   = find_resc_def(svr_resc_def, "nodect",    svr_resc_size);
+    mppwidthresc = find_resc_def(svr_resc_def, "mppwidth",  svr_resc_size);
+    mppnppn      = find_resc_def(svr_resc_def, "mppnppn",   svr_resc_size);
 
     SvrNodeCt = 0;
 
@@ -866,29 +920,22 @@ static void chk_svr_resc_limit(
 
     if ((jbrc->rs_value.at_flags & (ATR_VFLAG_SET | ATR_VFLAG_DEFLT)) == ATR_VFLAG_SET)
       {
-      qurc = find_resc_entry(queatr, jbrc->rs_defin);
+      qurc = find_resc_entry(&pque->qu_attr[QA_ATR_ResourceMax], jbrc->rs_defin);
 
-      LimitIsFromQueue = 0;
       LimitName = jbrc->rs_defin->rs_name;
 
-      if ((qurc == NULL) || ((qurc->rs_value.at_flags & ATR_VFLAG_SET) == 0))
+      cmpwith = get_resource(&pque->qu_attr[QA_ATR_ResourceMax],
+          &server.sv_attr[SRV_ATR_ResourceMax],
+          jbrc->rs_defin,
+          &LimitIsFromQueue);
+
+      if (strcmp(LimitName,"mppnppn") == 0)
         {
-        /* queue limit not set, check server's */
-
-        svrc = find_resc_entry(svratr, jbrc->rs_defin);
-
-        if ((svrc != NULL) && (svrc->rs_value.at_flags & ATR_VFLAG_SET))
-          {
-          cmpwith = svrc;
-          }
+        mpp_nppn = jbrc->rs_value.at_val.at_long;
         }
-      else
+      if (strcmp(LimitName,"mppwidth") == 0)
         {
-        /* queue limit is set, use it */
-
-        LimitIsFromQueue = 1;
-
-        cmpwith = qurc;
+        mpp_width = jbrc->rs_value.at_val.at_long;
         }
 
       if ((jbrc->rs_defin == noderesc) && (qtype == QTYPE_Execution))
@@ -908,6 +955,18 @@ static void chk_svr_resc_limit(
         }
 
 #endif /* NERSCDEV */
+      else if ((strcmp(LimitName,"mppnodect") == 0)
+          && (jbrc->rs_value.at_val.at_long == -1))
+        {
+        /*
+         * mppnodect is a special attrtibute,  It gets set based upon the
+         * values of mppwidth and mppnppn. -1 signifies the case where mppwidth
+         * and mppnppn were not both specified for the job. We will need to
+         * check mppnodect limits against queue/server defaults, if any.
+         */
+         
+        mppnodect_resource = jbrc;
+        }
       else if ((cmpwith != NULL) && (jbrc->rs_defin != needresc))
         {
         /* don't check neednodes */
@@ -922,14 +981,24 @@ static void chk_svr_resc_limit(
           }
         else if (rc < 0)
           {
-          if ((EMsg != NULL) && (EMsg[0] == '\0'))
+          /* only record if:
+           *     is_transit flag is not set
+           * or  is_transit is set, but not to true
+           * or  the value comes from queue limit
+           */
+          if ((!(pque->qu_attr[(int)QE_ATR_is_transit].at_flags & ATR_VFLAG_SET)) ||
+              (!pque->qu_attr[(int)QE_ATR_is_transit].at_val.at_long) ||
+              (LimitIsFromQueue))
             {
-            sprintf(EMsg,"cannot satisfy %s max %s requirement",
-              (LimitIsFromQueue == 1) ? "queue" : "server",
-              (LimitName != NULL) ? LimitName : "resource");
-            }
+            if ((EMsg != NULL) && (EMsg[0] == '\0'))
+              {
+              sprintf(EMsg, "cannot satisfy %s max %s requirement",
+                      (LimitIsFromQueue == 1) ? "queue" : "server",
+                      (LimitName != NULL) ? LimitName : "resource");
+              }
 
-          comp_resc_lt++;
+              comp_resc_lt++;
+            }
           }
         }
       }    /* END if () */
@@ -937,6 +1006,127 @@ static void chk_svr_resc_limit(
     jbrc = (resource *)GET_NEXT(jbrc->rs_link);
     }  /* END while (jbrc != NULL) */
 
+  if (mppnodect_resource != NULL)
+    {
+    /*
+     * special case where mppnodect was not specified for the job, we need to
+     * check max against recalculated value using queue/server resources_defaults
+     */
+     
+    if (mpp_nppn == 0)
+      {     
+      /* get queue/server default value */
+      
+      if (mppnppn != NULL)
+        {
+        cmpwith = get_resource(&pque->qu_attr[QA_ATR_ResourceDefault],
+            &server.sv_attr[SRV_ATR_resource_deflt],
+            mppnppn,
+            &LimitIsFromQueue);
+          
+        if (cmpwith != NULL)
+          {
+          mpp_nppn = cmpwith->rs_value.at_val.at_long;
+          }
+        }
+      }
+
+    if (mpp_width == 0)
+      {
+      /* get queue/server default value */
+
+      if (mppwidthresc != NULL)
+        {
+        cmpwith = get_resource(&pque->qu_attr[QA_ATR_ResourceDefault],
+            &server.sv_attr[SRV_ATR_resource_deflt],
+            mppwidthresc,
+            &LimitIsFromQueue);
+          
+        if (cmpwith != NULL)
+          {
+          mpp_width = cmpwith->rs_value.at_val.at_long;
+          }
+        }
+      }
+
+    /* Uses same way of calculating as set_mppnodect */
+    /* Check for width less than a node */
+
+    if ((mpp_width) && (mpp_width < mpp_nppn))
+      {
+      mpp_nppn = mpp_width;
+      }
+
+    /* Compute an estimate for the number of nodes needed */
+
+    mpp_nodect = mpp_width;
+    if (mpp_nppn > 1)
+      {
+      mpp_nodect = (mpp_nodect + mpp_nppn - 1) / mpp_nppn;
+      }
+
+    LimitIsFromQueue = 0;
+    LimitName = mppnodect_resource->rs_defin->rs_name;
+    
+    cmpwith = get_resource(&pque->qu_attr[QA_ATR_ResourceMax],
+        &server.sv_attr[SRV_ATR_ResourceMax],
+        mppnodect_resource->rs_defin,
+        &LimitIsFromQueue);
+
+    if (cmpwith != NULL)
+      {
+      long nodect_orig;
+
+      if (LOGLEVEL >= 7)
+        {
+        sprintf(log_buffer,
+            "chk_svr_resc_limit: comparing calculated mppnodect %ld, %s limit %s %ld\n",
+            mpp_nodect,
+            (LimitIsFromQueue == 1) ? "queue" : "server",
+            LimitName,
+            cmpwith->rs_value.at_val.at_long);
+
+        log_event(PBSEVENT_DEBUG, PBS_EVENTCLASS_SERVER, msg_daemonname,
+                  log_buffer);
+        }
+
+      nodect_orig = mppnodect_resource->rs_value.at_val.at_long;
+      mppnodect_resource->rs_value.at_val.at_long = mpp_nodect;
+      
+      rc = mppnodect_resource->rs_defin->rs_comp(
+              &cmpwith->rs_value,
+              &mppnodect_resource->rs_value);
+
+      mppnodect_resource->rs_value.at_val.at_long = nodect_orig;
+
+      if (rc > 0)
+        {
+        comp_resc_gt++;
+        }
+      else if (rc < 0)
+        {
+        /* only record if:
+         *     is_transit flag is not set
+         * or  is_transit is set, but not to true
+         * or  the value comes from queue limit
+         */
+        if ((!(pque->qu_attr[(int)QE_ATR_is_transit].at_flags & ATR_VFLAG_SET)) ||
+            (!pque->qu_attr[(int)QE_ATR_is_transit].at_val.at_long) ||
+            (LimitIsFromQueue))
+          {
+          if ((EMsg != NULL) && (EMsg[0] == '\0'))
+            {
+            sprintf(EMsg, "cannot satisfy %s max %s requirement",
+                    (LimitIsFromQueue == 1) ? "queue" : "server",
+                    (LimitName != NULL) ? LimitName : "resource");
+            }
+
+          comp_resc_lt++;
+          }
+        }
+      }
+    }  /* END if (mppnodect_resource != NULL) */
+
   if (jbrc_nodes != NULL)
     {
     int tmpI;
@@ -974,10 +1164,18 @@ static void chk_svr_resc_limit(
             &dummy,
             &dummy) == -1)
         {
-        if ((EMsg != NULL) && (EMsg[0] == '\0'))
-          strcpy(EMsg, "cannot locate feasible nodes");
+        /* only record if:
+         *     is_transit flag is not set
+         * or  is_transit is set, but not to true
+         */
+        if ((!(pque->qu_attr[(int)QE_ATR_is_transit].at_flags & ATR_VFLAG_SET)) ||
+            (!pque->qu_attr[(int)QE_ATR_is_transit].at_val.at_long))
+          {
+          if ((EMsg != NULL) && (EMsg[0] == '\0'))
+            strcpy(EMsg, "cannot locate feasible nodes");
 
-        comp_resc_lt++;
+          comp_resc_lt++;
+          }
         }
       }
     }    /* END if (jbrc_nodes != NULL) */
@@ -1037,8 +1235,7 @@ int chk_resc_limits(
 
   chk_svr_resc_limit(
     pattr,
-    &pque->qu_attr[QA_ATR_ResourceMax],
-    &server.sv_attr[SRV_ATR_ResourceMax],
+    pque,
     pque->qu_qs.qu_type,
     EMsg);
 
@@ -1217,6 +1414,44 @@ int svr_chkque(
 
           return(PBSE_NONONRERUNABLE);
           }
+        if (strcmp(Q_DT_fault_tolerant,
+                   pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0
+            && ((pjob->ji_wattr[(int)JOB_ATR_fault_tolerant].at_flags & ATR_VFLAG_SET) &&
+                pjob->ji_wattr[(int)JOB_ATR_fault_tolerant].at_val.at_long != 0))
+          {
+          if (EMsg)
+            snprintf(EMsg, 1024,
+              "fault_tolerant jobs are not allowed for queue: user %s, queue %s",
+              pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+              pque->qu_qs.qu_name);
+
+          return(PBSE_NOFAULTTOLERANT);
+          }
+          
+        if (strcmp(Q_DT_fault_intolerant,
+                   pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0
+            && (!(pjob->ji_wattr[(int)JOB_ATR_fault_tolerant].at_flags & ATR_VFLAG_SET) ||
+                pjob->ji_wattr[(int)JOB_ATR_fault_tolerant].at_val.at_long == 0))
+          {
+          if (EMsg)
+            snprintf(EMsg, 1024,
+              "only fault_tolerant jobs are allowed for queue: user %s, queue %s",
+              pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+              pque->qu_qs.qu_name);
+
+          return(PBSE_NOFAULTINTOLERANT);
+          }
+        if (strcmp(Q_DT_job_array,
+                   pque->qu_attr[QA_ATR_DisallowedTypes].at_val.at_arst->as_string[i]) == 0
+            && (pjob->ji_wattr[(int)JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET))
+          {
+          if (EMsg)
+            snprintf(EMsg, 1024,
+              "job arrays are not allowed for queue: queue %s",
+              pque->qu_qs.qu_name);
+          return(PBSE_NOJOBARRAYS);
+          }
+          
         }
       }    /* END if (pque->qu_attr[QA_ATR_DisallowedTypes].at_flags & ATR_VFLAG_SET) */
 
@@ -1324,10 +1559,11 @@ int svr_chkque(
 
     if (pque->qu_attr[QA_ATR_Enabled].at_val.at_long == 0)
       {
-      if (EMsg) snprintf(EMsg, 1024,
-                           "queue is disabled: user %s, queue %s",
-                           pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
-                           pque->qu_qs.qu_name);
+      if (EMsg)
+        snprintf(EMsg, 1024,
+          "queue is disabled: user %s, queue %s",
+          pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
+          pque->qu_qs.qu_name);
 
       return(PBSE_QUNOENB);
       }
@@ -1335,7 +1571,7 @@ int svr_chkque(
     if ((pque->qu_attr[QA_ATR_MaxJobs].at_flags & ATR_VFLAG_SET) &&
         ((pque->qu_numjobs - pque->qu_numcompleted) >= pque->qu_attr[QA_ATR_MaxJobs].at_val.at_long))
       {
-      if (EMsg) 
+      if (EMsg)
         snprintf(EMsg, 1024,
           "total number of jobs in queue exceeds the queue limit: "
           "user %s, queue %s",
@@ -1349,10 +1585,12 @@ int svr_chkque(
         (pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long >= 0))
       {
       /* count number of jobs user has in queue */
+
       user_jobs = 0;
+
       pj = (job *)GET_NEXT(pque->qu_jobs);
 
-      while (pj)
+      while (pj != NULL)
         {
         if ((pj->ji_qs.ji_state <= JOB_STATE_RUNNING) &&
             (!strcmp(pj->ji_wattr[JOB_ATR_job_owner].at_val.at_str,
@@ -1366,7 +1604,7 @@ int svr_chkque(
 
       if (user_jobs >= pque->qu_attr[QA_ATR_MaxUserJobs].at_val.at_long)
         {
-        if (EMsg) 
+        if (EMsg)
           snprintf(EMsg, 1024,
             "total number of current user's jobs exceeds the queue limit: "
             "user %s, queue %s",
@@ -1384,7 +1622,7 @@ int svr_chkque(
       {
       if (mtype == MOVE_TYPE_Move)  /* ok if not plain user */
         {
-        if (EMsg) 
+        if (EMsg)
           snprintf(EMsg, 1024,
             "queue accepts only routed jobs, no direct submission: "
             "user %s, queue %s",
@@ -1406,11 +1644,11 @@ int svr_chkque(
       {
       if (acl_check(&pque->qu_attr[QA_ATR_AclHost], hostname, ACL_Host) == 0)
         {
-        if (EMsg) 
+        if (EMsg)
           snprintf(EMsg, 1024,
             "host ACL rejected the submitting host: user %s, queue %s, host %s",
             pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
-            pque->qu_qs.qu_name, 
+            pque->qu_qs.qu_name,
             hostname);
 
         return(PBSE_BADHOST);
@@ -1441,8 +1679,7 @@ int svr_chkque(
         else
           {
           /* no group acl, fail immediately */
-
-          if (EMsg) 
+          if (EMsg)
             snprintf(EMsg, 1024,
               "user ACL rejected the submitting user: user %s, queue %s",
               pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str,
@@ -1691,6 +1928,30 @@ char *prefix_std_file(
 
   if (qsubhost != NULL)
     {
+
+    /* If just the host name portion was specified
+     * then we use it instead of qsubhost
+     */
+    
+    if ((key == (int)'e') &&
+        (pjob->ji_wattr[(int)JOB_ATR_errpath].at_flags & ATR_VFLAG_SET) &&
+        (pjob->ji_wattr[(int)JOB_ATR_errpath].at_val.at_str[strlen(pjob->ji_wattr[(int)JOB_ATR_errpath].at_val.at_str) - 1] == ':'))
+      {
+      
+      pjob->ji_wattr[(int)JOB_ATR_errpath].at_val.at_str[strlen(pjob->ji_wattr[(int)JOB_ATR_errpath].at_val.at_str) - 1] = '\0';
+      qsubhost = pjob->ji_wattr[(int)JOB_ATR_errpath].at_val.at_str;
+      
+      }
+    else if ((key == (int)'o') && 
+        (pjob->ji_wattr[(int)JOB_ATR_outpath].at_flags & ATR_VFLAG_SET) &&
+        (pjob->ji_wattr[(int)JOB_ATR_outpath].at_val.at_str[strlen(pjob->ji_wattr[(int)JOB_ATR_outpath].at_val.at_str) - 1] == ':'))
+      {
+      
+      pjob->ji_wattr[(int)JOB_ATR_outpath].at_val.at_str[strlen(pjob->ji_wattr[(int)JOB_ATR_outpath].at_val.at_str) - 1] = '\0';
+      qsubhost = pjob->ji_wattr[(int)JOB_ATR_outpath].at_val.at_str;
+      
+      }
+
     len = strlen(qsubhost) +
           strlen(pjob->ji_wattr[(int)JOB_ATR_jobname].at_val.at_str) +
           PBS_MAXSEQNUM +
@@ -1758,7 +2019,6 @@ char *add_std_filename(
 
 
 
-
 /*
  * get_jobowner - copy the basic job owner's name, without the @host suffix.
  * The "to" buffer must be large enought (PBS_MAXUSER+1).
@@ -1887,22 +2147,22 @@ void set_resc_deflt(
 
   /* apply queue defaults first since they take precedence */
 
-  set_deflt_resc(ja,&pque->qu_attr[(int)QA_ATR_ResourceDefault]);
+  set_deflt_resc(ja, &pque->qu_attr[(int)QA_ATR_ResourceDefault]);
 
   /* server defaults will only be applied to attributes which have
      not yet been set */
 
-  set_deflt_resc(ja,&server.sv_attr[(int)SRV_ATR_resource_deflt]);
+  set_deflt_resc(ja, &server.sv_attr[(int)SRV_ATR_resource_deflt]);
 
   /* apply queue max limits first since they take precedence */
 
 #ifndef RESOURCEMAXNOTDEFAULT
-  set_deflt_resc(ja,&pque->qu_attr[(int)QA_ATR_ResourceMax]);
+  set_deflt_resc(ja, &pque->qu_attr[(int)QA_ATR_ResourceMax]);
 
   /* server max limits will only be applied to attributes which have
      not yet been set */
 
-  set_deflt_resc(ja,&server.sv_attr[(int)SRV_ATR_ResourceMax]);
+  set_deflt_resc(ja, &server.sv_attr[(int)SRV_ATR_ResourceMax]);
 
 #endif
 
@@ -1912,7 +2172,7 @@ void set_resc_deflt(
 
     if ((pjob->ji_wattr[i].at_flags & ATR_VFLAG_SET) && (pdef->at_action))
       {
-      if ((rc = pdef->at_action(&pjob->ji_wattr[i],pjob,ATR_ACTION_NEW)) != 0)
+      if ((rc = pdef->at_action(&pjob->ji_wattr[i], pjob, ATR_ACTION_NEW)) != 0)
         {
         /* FIXME: return an actual error */
 
@@ -1969,12 +2229,12 @@ void set_statechar(
 
 
 /*
- * eval_chkpnt - if the job's checkpoint attribute is "c=nnnn" and
+ * eval_checkpoint - if the job's checkpoint attribute is "c=nnnn" and
  *  nnnn is less than the queue' minimum checkpoint time, reset
  * to the queue min time.
  */
 
-static void eval_chkpnt(
+static void eval_checkpoint(
 
   attribute *jobckp, /* job's checkpoint attribute */
   attribute *queckp) /* queue's checkpoint attribute */
@@ -2011,7 +2271,7 @@ static void eval_chkpnt(
     }
 
   return;
-  }  /* END eval_chkpnt() */
+  }  /* END eval_checkpoint() */
 
 
 
@@ -2052,7 +2312,7 @@ static void correct_ct(
     server.sv_jobstates[i] = 0;
     }
 
-  if (pqj)
+  if (pqj != NULL)
     {
     pc = log_buffer + strlen(log_buffer);
 
@@ -2074,7 +2334,8 @@ static void correct_ct(
 
             log_buffer);
 
-  for (pque = (pbs_queue *)GET_NEXT(svr_queues);pque;
+  for (pque = (pbs_queue *)GET_NEXT(svr_queues);
+       pque != NULL;
        pque = (pbs_queue *)GET_NEXT(pque->qu_link))
     {
     pque->qu_numjobs = 0;
@@ -2084,7 +2345,8 @@ static void correct_ct(
       pque->qu_njstate[i] = 0;
     }
 
-  for (pjob = (job *)GET_NEXT(svr_alljobs);pjob != NULL;
+  for (pjob = (job *)GET_NEXT(svr_alljobs);
+       pjob != NULL;
        pjob = (job *)GET_NEXT(pjob->ji_alljobs))
     {
     server.sv_qs.sv_numjobs++;
